@@ -1,7 +1,7 @@
 ;;; Lepton EDA library - Scheme API
 ;;; Copyright (C) 2010 Peter Brett
 ;;; Copyright (C) 2010-2014 gEDA Contributors
-;;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;;; Copyright (C) 2017-2021 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -22,19 +22,21 @@
 ;; be used in new code.
 
 (define-module (geda deprecated)
+ #:use-module (rnrs bytevectors)
+ #:use-module (system foreign)
+
  ;; Import C procedures
- #:use-module (lepton core deprecated)
  #:use-module (lepton core gettext)
  #:use-module (lepton core rc)
 
  #:use-module (lepton attrib)
+ #:use-module (lepton ffi)
  #:use-module (lepton log)
  #:use-module (lepton object)
+ #:use-module (lepton object type)
  #:use-module (lepton page)
  #:use-module (lepton rc)
 
- #:re-export (OBJ_LINE OBJ_PATH OBJ_BOX OBJ_PICTURE OBJ_CIRCLE OBJ_NET
-              OBJ_BUS OBJ_COMPLEX OBJ_TEXT OBJ_PIN OBJ_ARC)
  ;; Re-export procedures and variables from (lepton rc).
  #:re-export (build-path
               geda-data-path
@@ -55,7 +57,36 @@
                   new-modname)
           "")))
 
-(define-public get-line-width %get-line-width)
+(define (lepton-var->char var-name)
+  (integer->char
+   (bytevector-uint-ref (pointer->bytevector (dynamic-pointer var-name
+                                                              liblepton)
+                                             (sizeof uint8))
+                        0
+                        (native-endianness)
+                        (sizeof uint8))))
+
+(define-public OBJ_LINE (lepton-var->char "_OBJ_LINE"))
+(define-public OBJ_PATH (lepton-var->char "_OBJ_PATH"))
+(define-public OBJ_BOX (lepton-var->char "_OBJ_BOX"))
+(define-public OBJ_PICTURE (lepton-var->char "_OBJ_PICTURE"))
+(define-public OBJ_CIRCLE (lepton-var->char "_OBJ_CIRCLE"))
+(define-public OBJ_NET (lepton-var->char "_OBJ_NET"))
+(define-public OBJ_BUS (lepton-var->char "_OBJ_BUS"))
+(define-public OBJ_COMPLEX (lepton-var->char "_OBJ_COMPONENT"))
+(define-public OBJ_TEXT (lepton-var->char "_OBJ_TEXT"))
+(define-public OBJ_PIN (lepton-var->char "_OBJ_PIN"))
+(define-public OBJ_ARC (lepton-var->char "_OBJ_ARC"))
+(define-public OBJ_PLACEHOLDER (lepton-var->char "_OBJ_PLACEHOLDER"))
+
+
+(define-public (get-line-width object)
+  "Returns the line width used to draw OBJECT. Deprecated because it
+doesn't respect type restrictions, unlike the object-stroke
+function in (lepton object)."
+  (define pointer (geda-object->pointer* object 1))
+
+  (lepton_object_get_stroke_width pointer))
 
 (define-public get-attribute-name-value parse-attrib)
 
