@@ -1,6 +1,6 @@
 ;;; Lepton EDA library - Scheme API
 ;;; Copyright (C) 2011 Peter Brett <peter@peter-b.co.uk>
-;;; Copyright (C) 2019-2020 Lepton EDA Contributors
+;;; Copyright (C) 2019-2021 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -18,37 +18,97 @@
 
 
 (define-module (lepton os)
-  #:use-module (srfi srfi-1)
   #:use-module (ice-9 regex)
-  ;; Import C procedures and variables
-  #:use-module (lepton core os))
+  #:use-module (srfi srfi-1)
+  #:use-module (system foreign)
 
-(define-public platform %platform)
+  #:use-module (lepton ffi)
 
-(define-public (platform? x)
+  #:export (expand-env-variables
+            sys-config-dirs
+            sys-data-dirs
+            user-cache-dir
+            user-config-dir
+            user-data-dir
+            ;; Deprecated functions.
+            path-separator
+            path-separator-char
+            platform
+            platform?
+            separator
+            separator-char
+            separator-char?))
+
+
+(define %platform
+  (cond
+   ((string-contains %host-type "cygwin") '(cygwin win32))
+   ((string-contains %host-type "linux") '(linux))
+   ((string-contains %host-type "mingw") '(win32 win32-native))
+   (else '(unknown))))
+
+(define (platform)
+  "Return a list of symbols describing the host operating system.
+The symbols may include:
+- 'win32 -- Windows
+- 'win32-native -- Windows, not via Cygwin
+- 'cygwin -- Cygwin
+- 'linux -- Linux"
+  %platform)
+
+(define (platform? x)
   (member x (platform)))
 
 ; Deprecated and must be removed after version 1.10.
-(define-public separator-char
+(define separator-char
   (car (char-set->list (string->char-set file-name-separator-string))))
 
 ; Deprecated and must be removed after version 1.10.
-(define-public separator file-name-separator-string)
+(define separator file-name-separator-string)
 
-(define-public path-separator-char
+(define path-separator-char
   (if (platform? 'win32-native) #\; #\:))
 
-(define-public path-separator (string path-separator-char))
+(define path-separator (string path-separator-char))
 
-(define-public separator-char? file-name-separator?)
+(define separator-char? file-name-separator?)
 
-(define-public sys-data-dirs %sys-data-dirs)
-(define-public sys-config-dirs %sys-config-dirs)
-(define-public user-data-dir %user-data-dir)
-(define-public user-config-dir %user-config-dir)
-(define-public user-cache-dir %user-cache-dir)
+(define (c-string-array->list pointer)
+  "Returns a list of search directories for system data."
+  (let loop ((num 0)
+             (ls '()))
+    (let ((string-pointer
+           (dereference-pointer
+            (make-pointer (+ (pointer-address pointer)
+                             (* num (sizeof '*)))))))
+      (if (null-pointer? string-pointer)
+          (reverse ls)
+          (loop (1+ num)
+                (cons (pointer->string string-pointer)
+                      ls))))))
 
-(define-public expand-env-variables
+(define (sys-data-dirs)
+  "Returns a list of search directories for system data."
+  (c-string-array->list (eda_get_system_data_dirs)))
+
+(define (sys-config-dirs)
+  "Returns a list of search directories for system configuration."
+  (c-string-array->list (eda_get_system_config_dirs)))
+
+(define (user-data-dir)
+  "Returns the directory where per-user data are stored."
+  (pointer->string (eda_get_user_data_dir)))
+
+(define (user-config-dir)
+  "Returns the directory where per-user configuration information
+is stored."
+  (pointer->string (eda_get_user_config_dir)))
+
+(define (user-cache-dir)
+  "Returns the directory where per-user cache data are stored."
+  (pointer->string (eda_get_user_cache_dir)))
+
+(define expand-env-variables
   ;; Only compile regular expression once
   (let ((rx (make-regexp "\\$\\{(\\w*)\\}")))
     ;; This is the actual expand-env-variables function -- it's a
