@@ -1,5 +1,5 @@
 ;;; Lepton EDA netlister
-;;; Copyright (C) 2019-2020 Lepton EDA Contributors
+;;; Copyright (C) 2019-2021 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -187,7 +187,7 @@
    component
    (make-schematic-component-refdes*
     component
-    (gnetlist-config-ref 'mangle-refdes))))
+    (netlist-config-ref 'mangle-refdes))))
 
 
 (define* (page-list->subschematic pages #:optional name)
@@ -422,7 +422,7 @@ NAME is used as its hierarchical name."
   (let* ((id #f)
          (page #f)
          (netnames (group-hierarchical-name group
-                                            (gnetlist-config-ref
+                                            (netlist-config-ref
                                              'netname-attribute-priority)))
          (objects (merge-objects group))
          (pins (merge-pins group))
