@@ -11,6 +11,8 @@
 (let ((a (make-component "test component" '(1 . 2) 0 #t #f)))
 
   (test-equal 'complex (object-type a))
+  (test-assert (object-type? a 'complex))
+  (test-assert (not (object-type? a 'x)))
 
   (test-assert (component? a))
 
@@ -174,7 +176,7 @@
 
 ;; Set up component library, making blatant assumptions about the
 ;; directory layout.
-(component-library (string-join (list (getenv "srcdir") "../../symbols/analog") "/")
+(component-library (string-join (list (getenv "srcdir") "../../symbols/sym/analog") "/")
                    "Basic devices")
 
 (test-begin "component/library" 8)
@@ -254,6 +256,7 @@
 
 
 ;;; Test component file names.
+(test-begin "component-filename")
 (let* ((fname1  (format #f "~a.sym" (tmpnam)))
        (symdir (dirname  fname1))
        (basename1 (basename fname1))
@@ -300,7 +303,7 @@
   (let ((temp-component (make-real-component))
         (non-existing-component (make-bogus-component)))
 
-    (test-group-with-cleanup "component-filename"
+    (test-group-with-cleanup "component-filename-grp"
 
       (test-equal (component-filename temp-component) fname1)
       (test-assert (not (component-filename non-existing-component)))
@@ -308,6 +311,7 @@
       (begin
         (reset-component-library)
         (delete-file fname1)))))
+(test-end "component-filename")
 
 
 ;;; Test component-library-command().
@@ -316,6 +320,7 @@
                                        "/docs/manual/cmd-component.sh")
     read-string))
 
+(test-begin "component-library-command")
 (let* ((script-name (tmpnam))
        (get-command script-name)
        (list-command (string-append script-name " -l")))
@@ -330,9 +335,16 @@
   (let ((C1 (make-component/library "symname1.sym" '(0 . 0) 0 #f #f))
         (C2 (make-component/library "symname2.sym" '(1000 . 1000) 0 #f #f)))
 
-    (test-group-with-cleanup "component-library-command"
+    (test-group-with-cleanup "component-library-command-grp"
 
       (test-assert (component? C1))
       (test-assert (component? C2))
       ;; Clean up.
       (delete-file get-command))))
+(test-end "component-library-command")
+
+(test-begin "object-component-wrong-argument")
+
+(test-assert-thrown 'wrong-type-arg (object-component 'a))
+
+(test-end "object-component-wrong-argument")
