@@ -28,6 +28,119 @@
 
 #include "liblepton_priv.h"
 
+/*! \brief Get the upper x coordinate of a box object.
+ *
+ *  \param [in] object The box object.
+ *  \return The x coordinate of the upper corner of the box.
+ */
+int
+lepton_box_object_get_upper_x (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_box (object), 0);
+  g_return_val_if_fail (object->box != NULL, 0);
+
+  return object->box->upper_x;
+}
+
+/*! \brief Get the upper y coordinate of a box object.
+ *
+ *  \param [in] object The box object.
+ *  \return The y coordinate of the upper corner of the box.
+ */
+int
+lepton_box_object_get_upper_y (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_box (object), 0);
+  g_return_val_if_fail (object->box != NULL, 0);
+
+  return object->box->upper_y;
+}
+
+/*! \brief Get the lower x coordinate of a box object.
+ *
+ *  \param [in] object The box object.
+ *  \return The x coordinate of the lower corner of the box.
+ */
+int
+lepton_box_object_get_lower_x (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_box (object), 0);
+  g_return_val_if_fail (object->box != NULL, 0);
+
+  return object->box->lower_x;
+}
+
+/*! \brief Get the lower y coordinate of a box object.
+ *
+ *  \param [in] object The box object.
+ *  \return The y coordinate of the lower corner of the box.
+ */
+int
+lepton_box_object_get_lower_y (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_box (object), 0);
+  g_return_val_if_fail (object->box != NULL, 0);
+
+  return object->box->lower_y;
+}
+
+
+/*! \brief Set the value of the upper x coordinate of a box object.
+ *
+ *  \param [in,out] object The box object.
+ *  \param [in] x The new upper x coordinate of the box.
+ */
+void
+lepton_box_object_set_upper_x (LeptonObject *object, int val)
+{
+  g_return_if_fail (lepton_object_is_box (object));
+  g_return_if_fail (object->box != NULL);
+
+  object->box->upper_x = val;
+}
+
+/*! \brief Set the value of the upper y coordinate of a box object.
+ *
+ *  \param [in,out] object The box object.
+ *  \param [in] y The new upper y coordinate of the box.
+ */
+void
+lepton_box_object_set_upper_y (LeptonObject *object, int val)
+{
+  g_return_if_fail (lepton_object_is_box (object));
+  g_return_if_fail (object->box != NULL);
+
+  object->box->upper_y = val;
+}
+
+/*! \brief Set the value of the lower x coordinate of a box object.
+ *
+ *  \param [in,out] object The box object.
+ *  \param [in] x The new lower x coordinate of the box.
+ */
+void
+lepton_box_object_set_lower_x (LeptonObject *object, int val)
+{
+  g_return_if_fail (lepton_object_is_box (object));
+  g_return_if_fail (object->box != NULL);
+
+  object->box->lower_x = val;
+}
+
+/*! \brief Set the value of the lower y coordinate of a box object.
+ *
+ *  \param [in,out] object The box object.
+ *  \param [in] y The new lower y coordinate of the box.
+ */
+void
+lepton_box_object_set_lower_y (LeptonObject *object, int val)
+{
+  g_return_if_fail (lepton_object_is_box (object));
+  g_return_if_fail (object->box != NULL);
+
+  object->box->lower_y = val;
+}
+
 /*! \brief Create a box LeptonObject
  *  \par Function Description
  *  This function creates a new object representing a box.
@@ -107,6 +220,7 @@ LeptonObject*
 lepton_box_object_copy (LeptonObject *o_current)
 {
   LeptonObject *new_obj;
+  int upper_x, upper_y, lower_x, lower_y;
 
   /* A new box object is created with #lepton_box_object_new().
    * Values for its fields are default and need to be modified. */
@@ -117,11 +231,15 @@ lepton_box_object_copy (LeptonObject *o_current)
    * The dimensions of the new box are set with the ones of the original box.
    * The two boxes have the same line type and the same filling options.
    */
+  upper_x = lepton_box_object_get_upper_x (o_current);
+  upper_y = lepton_box_object_get_upper_y (o_current);
+  lower_x = lepton_box_object_get_lower_x (o_current);
+  lower_y = lepton_box_object_get_lower_y (o_current);
 
-  new_obj->box->upper_x = o_current->box->upper_x;
-  new_obj->box->upper_y = o_current->box->upper_y;
-  new_obj->box->lower_x = o_current->box->lower_x;
-  new_obj->box->lower_y = o_current->box->lower_y;
+  lepton_box_object_set_upper_x (new_obj, upper_x);
+  lepton_box_object_set_upper_y (new_obj, upper_y);
+  lepton_box_object_set_lower_x (new_obj, lower_x);
+  lepton_box_object_set_lower_y (new_obj, lower_y);
 
   lepton_object_set_line_options (new_obj,
                                   lepton_object_get_stroke_cap_type (o_current),
@@ -130,46 +248,16 @@ lepton_box_object_copy (LeptonObject *o_current)
                                   lepton_object_get_stroke_dash_length (o_current),
                                   lepton_object_get_stroke_space_length (o_current));
   lepton_object_set_fill_options (new_obj,
-                                  o_current->fill_type,
-                                  o_current->fill_width,
-                                  o_current->fill_pitch1,
-                                  o_current->fill_angle1,
-                                  o_current->fill_pitch2,
-                                  o_current->fill_angle2);
+                                  lepton_object_get_fill_type (o_current),
+                                  lepton_object_get_fill_width (o_current),
+                                  lepton_object_get_fill_pitch1 (o_current),
+                                  lepton_object_get_fill_angle1 (o_current),
+                                  lepton_object_get_fill_pitch2 (o_current),
+                                  lepton_object_get_fill_angle2 (o_current));
 
   return new_obj;
 }
 
-/*! \brief Modify a box LeptonObject's coordinates.
- * \par Function Description
- * Modifies the coordinates of all four corners of \a box, by setting
- * the box to the rectangle enclosed by the points (\a x1, \a y1) and
- * (\a x2, \a y2).
- *
- * \param [in,out] object   box #LeptonObject to be modified.
- * \param [in]     x1       x coordinate of first corner of box.
- * \param [in]     y1       y coordinate of first corner of box.
- * \param [in]     x2       x coordinate of second corner of box.
- * \param [in]     y2       y coordinate of second corner of box,
- */
-void
-lepton_box_object_modify_all (LeptonObject *object,
-                              int x1,
-                              int y1,
-                              int x2,
-                              int y2)
-{
-  lepton_object_emit_pre_change_notify (object);
-
-  object->box->lower_x = (x1 > x2) ? x1 : x2;
-  object->box->lower_y = (y1 > y2) ? y2 : y1;
-
-  object->box->upper_x = (x1 > x2) ? x2 : x1;
-  object->box->upper_y = (y1 > y2) ? y1 : y2;
-
-  lepton_object_emit_change_notify (object);
-}
-
 /*! \brief Modify a box LeptonObject's coordinates.
  *  \par Function Description
  *  This function modifies the coordinates of one of the four corner of
@@ -206,40 +294,48 @@ lepton_box_object_modify (LeptonObject *object,
   /* change the position of the selected corner */
   switch(whichone) {
   case BOX_UPPER_LEFT:
-    object->box->upper_x = x;
-    object->box->upper_y = y;
+    lepton_box_object_set_upper_x (object, x);
+    lepton_box_object_set_upper_y (object, y);
     break;
 
   case BOX_LOWER_LEFT:
-    object->box->upper_x = x;
-    object->box->lower_y = y;
+    lepton_box_object_set_upper_x (object, x);
+    lepton_box_object_set_lower_y (object, y);
     break;
 
   case BOX_UPPER_RIGHT:
-    object->box->lower_x = x;
-    object->box->upper_y = y;
+    lepton_box_object_set_lower_x (object, x);
+    lepton_box_object_set_upper_y (object, y);
     break;
 
   case BOX_LOWER_RIGHT:
-    object->box->lower_x = x;
-    object->box->lower_y = y;
+    lepton_box_object_set_lower_x (object, x);
+    lepton_box_object_set_lower_y (object, y);
     break;
 
   default:
     return;
   }
 
+  int upper_x, upper_y, lower_x, lower_y;
+  upper_x = lepton_box_object_get_upper_x (object);
+  upper_y = lepton_box_object_get_upper_y (object);
+  lower_x = lepton_box_object_get_lower_x (object);
+  lower_y = lepton_box_object_get_lower_y (object);
+
   /* need to update the upper left and lower right corners */
-  if(object->box->upper_x > object->box->lower_x) {
-    tmp                  = object->box->upper_x;
-    object->box->upper_x = object->box->lower_x;
-    object->box->lower_x = tmp;
+  if (upper_x > lower_x)
+  {
+    tmp = upper_x;
+    lepton_box_object_set_upper_x (object, lower_x);
+    lepton_box_object_set_lower_x (object, tmp);
   }
 
-  if(object->box->upper_y < object->box->lower_y) {
-    tmp                  = object->box->upper_y;
-    object->box->upper_y = object->box->lower_y;
-    object->box->lower_y = tmp;
+  if (upper_y < lower_y)
+  {
+    tmp = upper_y;
+    lepton_box_object_set_upper_y (object, lower_y);
+    lepton_box_object_set_lower_y (object, tmp);
   }
 
   lepton_object_emit_change_notify (object);
@@ -264,10 +360,10 @@ lepton_box_object_modify (LeptonObject *object,
  *  \return The box LeptonObject that was created, or NULL on error.
  */
 LeptonObject*
-o_box_read (const char buf[],
-            unsigned int release_ver,
-            unsigned int fileformat_ver,
-            GError **err)
+lepton_box_object_read (const char buf[],
+                        unsigned int release_ver,
+                        unsigned int fileformat_ver,
+                        GError **err)
 {
   LeptonObject *new_obj;
   char type;
@@ -401,6 +497,7 @@ lepton_box_object_to_buffer (const LeptonObject *object)
   LeptonStrokeType box_type;
   LeptonFillType box_fill;
   char *buf;
+  int upper_x, upper_y, lower_x, lower_y;
 
   /*! \note
    *  A box is internally represented by its lower right and upper left corner
@@ -408,13 +505,18 @@ lepton_box_object_to_buffer (const LeptonObject *object)
    *  its width and height.
    */
 
+  upper_x = lepton_box_object_get_upper_x (object);
+  upper_y = lepton_box_object_get_upper_y (object);
+  lower_x = lepton_box_object_get_lower_x (object);
+  lower_y = lepton_box_object_get_lower_y (object);
+
   /* calculate the width and height of the box */
-  width  = abs(object->box->lower_x - object->box->upper_x);
-  height = abs(object->box->upper_y - object->box->lower_y);
+  width  = abs (lower_x - upper_x);
+  height = abs (upper_y - lower_y);
 
   /* calculate the lower left corner of the box */
-  x1 = object->box->upper_x;
-  y1 = object->box->upper_y - height; /* move the origin to 0, 0*/
+  x1 = upper_x;
+  y1 = upper_y - height; /* move the origin to 0, 0*/
 
 #if DEBUG
   printf("box: %d %d %d %d\n", x1, y1, width, height);
@@ -428,12 +530,12 @@ lepton_box_object_to_buffer (const LeptonObject *object)
   box_space  = lepton_object_get_stroke_space_length (object);
 
   /* description of the filling of the box */
-  box_fill   = object->fill_type;
-  fill_width = object->fill_width;
-  angle1     = object->fill_angle1;
-  pitch1     = object->fill_pitch1;
-  angle2     = object->fill_angle2;
-  pitch2     = object->fill_pitch2;
+  box_fill   = lepton_object_get_fill_type (object);
+  fill_width = lepton_object_get_fill_width (object);
+  angle1     = lepton_object_get_fill_angle1 (object);
+  pitch1     = lepton_object_get_fill_pitch1 (object);
+  angle2     = lepton_object_get_fill_angle2 (object);
+  pitch2     = lepton_object_get_fill_pitch2 (object);
 
   buf = g_strdup_printf("%c %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d",
                         lepton_object_get_type (object),
@@ -461,12 +563,18 @@ lepton_box_object_translate (LeptonObject *object,
 {
   g_return_if_fail (lepton_object_is_box (object));
   g_return_if_fail (object->box != NULL);
+  int upper_x, upper_y, lower_x, lower_y;
 
   /* Do world coords */
-  object->box->upper_x = object->box->upper_x + dx;
-  object->box->upper_y = object->box->upper_y + dy;
-  object->box->lower_x = object->box->lower_x + dx;
-  object->box->lower_y = object->box->lower_y + dy;
+  upper_x = lepton_box_object_get_upper_x (object);
+  upper_y = lepton_box_object_get_upper_y (object);
+  lower_x = lepton_box_object_get_lower_x (object);
+  lower_y = lepton_box_object_get_lower_y (object);
+
+  lepton_box_object_set_upper_x (object, upper_x + dx);
+  lepton_box_object_set_upper_y (object, upper_y + dy);
+  lepton_box_object_set_lower_x (object, lower_x + dx);
+  lepton_box_object_set_lower_y (object, lower_y + dy);
 }
 
 /*! \brief Rotate box LeptonObject using WORLD coordinates.
@@ -510,36 +618,30 @@ lepton_box_object_rotate (int world_centerx,
    *  to its previous location.
    */
   /* translate object to origin */
-  object->box->upper_x -= world_centerx;
-  object->box->upper_y -= world_centery;
-  object->box->lower_x -= world_centerx;
-  object->box->lower_y -= world_centery;
+  lepton_box_object_translate (object, -world_centerx, -world_centery);
 
   /* rotate the upper left corner of the box */
-  lepton_point_rotate_90 (object->box->upper_x,
-                          object->box->upper_y,
+  lepton_point_rotate_90 (lepton_box_object_get_upper_x (object),
+                          lepton_box_object_get_upper_y (object),
                           angle,
                           &newx1,
                           &newy1);
 
   /* rotate the lower left corner of the box */
-  lepton_point_rotate_90 (object->box->lower_x,
-                          object->box->lower_y,
+  lepton_point_rotate_90 (lepton_box_object_get_lower_x (object),
+                          lepton_box_object_get_lower_y (object),
                           angle,
                           &newx2,
                           &newy2);
 
   /* reorder the corners after rotation */
-  object->box->upper_x = MIN(newx1,newx2);
-  object->box->upper_y = MAX(newy1,newy2);
-  object->box->lower_x = MAX(newx1,newx2);
-  object->box->lower_y = MIN(newy1,newy2);
+  lepton_box_object_set_upper_x (object, MIN (newx1, newx2));
+  lepton_box_object_set_upper_y (object, MAX (newy1, newy2));
+  lepton_box_object_set_lower_x (object, MAX (newx1, newx2));
+  lepton_box_object_set_lower_y (object, MIN (newy1, newy2));
 
   /* translate object back to normal position */
-  object->box->upper_x += world_centerx;
-  object->box->upper_y += world_centery;
-  object->box->lower_x += world_centerx;
-  object->box->lower_y += world_centery;
+  lepton_box_object_translate (object, world_centerx, world_centery);
 }
 
 /*! \brief Mirror box using WORLD coordinates.
@@ -559,6 +661,7 @@ lepton_box_object_mirror (int world_centerx,
                           int world_centery,
                           LeptonObject *object)
 {
+  int upper_x, upper_y, lower_x, lower_y;
   int newx1, newy1;
   int newx2, newy2;
 
@@ -566,28 +669,27 @@ lepton_box_object_mirror (int world_centerx,
   g_return_if_fail (object->box != NULL);
 
   /* translate object to origin */
-  object->box->upper_x -= world_centerx;
-  object->box->upper_y -= world_centery;
-  object->box->lower_x -= world_centerx;
-  object->box->lower_y -= world_centery;
+  lepton_box_object_translate (object, -world_centerx, -world_centery);
+
+  upper_x = lepton_box_object_get_upper_x (object);
+  upper_y = lepton_box_object_get_upper_y (object);
+  lower_x = lepton_box_object_get_lower_x (object);
+  lower_y = lepton_box_object_get_lower_y (object);
 
   /* mirror the corners */
-  newx1 = -object->box->upper_x;
-  newy1 = object->box->upper_y;
-  newx2 = -object->box->lower_x;
-  newy2 = object->box->lower_y;
+  newx1 = -upper_x;
+  newy1 = upper_y;
+  newx2 = -lower_x;
+  newy2 = lower_y;
 
   /* reorder the corners */
-  object->box->upper_x = MIN(newx1,newx2);
-  object->box->upper_y = MAX(newy1,newy2);
-  object->box->lower_x = MAX(newx1,newx2);
-  object->box->lower_y = MIN(newy1,newy2);
+  lepton_box_object_set_upper_x (object, MIN (newx1, newx2));
+  lepton_box_object_set_upper_y (object, MAX (newy1, newy2));
+  lepton_box_object_set_lower_x (object, MAX (newx1, newx2));
+  lepton_box_object_set_lower_y (object, MIN (newy1, newy2));
 
   /* translate back in position */
-  object->box->upper_x += world_centerx;
-  object->box->upper_y += world_centery;
-  object->box->lower_x += world_centerx;
-  object->box->lower_y += world_centery;
+  lepton_box_object_translate (object, world_centerx, world_centery);
 }
 
 /*! \brief Get box bounding rectangle in WORLD coordinates.
@@ -639,11 +741,13 @@ lepton_box_object_get_position (const LeptonObject *object,
   g_return_val_if_fail (object->box != NULL, FALSE);
 
   if (x != NULL) {
-    *x = MIN (object->box->lower_x, object->box->upper_x);
+    *x = MIN (lepton_box_object_get_lower_x (object),
+              lepton_box_object_get_upper_x (object));
   }
 
   if (y != NULL) {
-    *y = MIN (object->box->lower_y, object->box->upper_y);
+    *y = MIN (lepton_box_object_get_lower_y (object),
+              lepton_box_object_get_upper_y (object));
   }
 
   return TRUE;
@@ -671,7 +775,8 @@ lepton_box_object_shortest_distance (LeptonObject *object,
 
   g_return_val_if_fail (object->box != NULL, G_MAXDOUBLE);
 
-  solid = force_solid || object->fill_type != FILLING_HOLLOW;
+  solid = force_solid ||
+    lepton_object_get_fill_type (object) != FILLING_HOLLOW;
 
   return lepton_box_shortest_distance (object->box, x, y, solid);
 }
