@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 2011-2012 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #include <errno.h>
 
-#include <libgeda_priv.h>
+#include <liblepton_priv.h>
 
 enum _EdaConfigPropertyId {
   PROP_0,
