@@ -2,7 +2,7 @@
  * Copyright (C) 1998, 1999, 2000 Kazu Hirata / Ales Hvezda
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2010, 2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
 #include "config.h"
 #include "version.h"
 
-#include "libgeda_priv.h"
-#include "liblepton/libgedaguile.h"
+#include "liblepton_priv.h"
+#include "liblepton/libleptonguile.h"
 
 /*! \brief Perform runtime initialization of liblepton library.
  *
@@ -43,7 +43,6 @@ void liblepton_init(void)
   eda_paths_init();
 
   s_clib_init();
-  s_menu_init();
   s_attrib_init();
   s_color_init();
 
