@@ -95,7 +95,7 @@ o_attrib_attach (LeptonObject *attrib,
 
   if (attrib->attached_to != NULL) {
     g_warning (_("Attempt to attach attribute [%1$s] to more than one object\n"),
-                attrib->text->string);
+               lepton_text_object_get_string (attrib));
     return;
   }
 
@@ -243,7 +243,7 @@ o_read_attribs (LeptonPage *page,
         break;
 
       case(OBJ_BOX):
-        if ((new_obj = o_box_read (line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = lepton_box_object_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
         break;
@@ -268,19 +268,19 @@ o_read_attribs (LeptonPage *page,
         break;
 
       case(OBJ_PIN):
-        if ((new_obj = o_pin_read (line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = lepton_pin_object_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
         break;
 
       case(OBJ_ARC):
-        if ((new_obj = o_arc_read (line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = lepton_arc_object_read (line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
         break;
 
       case(OBJ_TEXT):
-        new_obj = o_text_read (line, tb, release_ver, fileformat_ver, err);
+        new_obj = lepton_text_object_read (line, tb, release_ver, fileformat_ver, err);
         if (new_obj == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
