@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2013 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,15 +25,16 @@
 #include <stdlib.h>
 #endif
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
-/*! \brief Returns a pointer to a new SELECTION object.
- *  \par Returns a pointer to a new SELECTION object.
- *  \return pointer to the new SELECTION object.
+/*! \brief Returns a pointer to a new LeptonSelection object.
+ *  \par Returns a pointer to a new LeptonSelection object.
+ *  \return pointer to the new LeptonSelection object.
  */
-SELECTION *o_selection_new( void )
+LeptonSelection*
+o_selection_new ()
 {
-  return (SELECTION*)geda_list_new();
+  return (LeptonSelection*) lepton_list_new ();
 }
 
 /*! \brief Selects the given object and adds it to the selection list
@@ -45,18 +46,18 @@ SELECTION *o_selection_new( void )
  *  \param [in] o_selected Object to select.
  */
 void
-o_selection_add (SELECTION *selection,
-                 OBJECT *o_selected)
+o_selection_add (LeptonSelection *selection,
+                 LeptonObject *o_selected)
 {
   if (o_selected->selected == FALSE)
   {
     o_selection_select (o_selected);
-    geda_list_add( (GedaList *)selection, o_selected );
+    lepton_list_add( (LeptonList *)selection, o_selected );
   }
 }
 
 /*! \brief Removes the given object from the selection list
- *  \par Removes the given object from the selection list and does the 
+ *  \par Removes the given object from the selection list and does the
  *  needed work to make the object visually unselected.
  *  It's ok to call this function with an object which is not necessarily
  *  selected.
@@ -65,17 +66,17 @@ o_selection_add (SELECTION *selection,
  *  \param [in] o_selected Object to unselect and remove from the list.
  */
 void
-o_selection_remove (SELECTION *selection,
-                    OBJECT *o_selected)
+o_selection_remove (LeptonSelection *selection,
+                    LeptonObject *o_selected)
 {
   if (o_selected == NULL) {
     fprintf(stderr, "Got NULL for o_selected in o_selection_remove\n");
     return;
   }
 
-  if (g_list_find( geda_list_get_glist( selection ), o_selected ) != NULL) {
+  if (g_list_find( lepton_list_get_glist( selection ), o_selected ) != NULL) {
     o_selection_unselect (o_selected);
-    geda_list_remove( (GedaList *)selection, o_selected );
+    lepton_list_remove( (LeptonList *)selection, o_selected );
   }
 }
 
@@ -85,16 +86,18 @@ o_selection_remove (SELECTION *selection,
  *  \param [in] selection Pointer to selection list to print.
  *
  */
-void o_selection_print_all(const SELECTION *selection)
+void
+o_selection_print_all (const LeptonSelection *selection)
 {
   const GList *s_current;
 
-  s_current = geda_list_get_glist( selection );
+  s_current = lepton_list_get_glist( selection );
 
   printf("START printing selection ********************\n");
   while(s_current != NULL) {
     if (s_current->data) {
-      printf("Selected object: %1$d\n", ((OBJECT *)s_current->data)->sid );
+      printf("Selected object: %1$d\n",
+             lepton_object_get_id ((LeptonObject *)s_current->data));
     }
     s_current = g_list_next( s_current );
   }
@@ -103,20 +106,20 @@ void o_selection_print_all(const SELECTION *selection)
 }
 
 /*! \brief Selects the given object.
- *  \par Sets the select flag, saves the color, and then selects the 
+ *  \par Sets the select flag, saves the color, and then selects the
  *  given object
  *
  *  \param [in] object    Object to select.
  */
 void
-o_selection_select (OBJECT *object)
+o_selection_select (LeptonObject *object)
 {
   if (object->selected == TRUE)
     return;
 
-  o_emit_pre_change_notify (object);
+  lepton_object_emit_pre_change_notify (object);
   object->selected = TRUE;
-  o_emit_change_notify (object);
+  lepton_object_emit_change_notify (object);
 }
 
 /*! \brief Unselects the given object.
@@ -127,13 +130,12 @@ o_selection_select (OBJECT *object)
  *  \param [in] object    Object to unselect.
  */
 void
-o_selection_unselect (OBJECT *object)
+o_selection_unselect (LeptonObject *object)
 {
   if (object->selected == FALSE)
     return;
 
-  o_emit_pre_change_notify (object);
+  lepton_object_emit_pre_change_notify (object);
   object->selected = FALSE;
-  o_emit_change_notify (object);
+  lepton_object_emit_change_notify (object);
 }
-
