@@ -57,6 +57,21 @@
 /*! this is modified here and in o_list.c */
 int global_sid=0;
 
+/* Deprecated variables for Scheme code. */
+char _OBJ_LINE = OBJ_LINE;
+char _OBJ_PATH = OBJ_PATH;
+char _OBJ_BOX = OBJ_BOX;
+char _OBJ_PICTURE = OBJ_PICTURE;
+char _OBJ_CIRCLE = OBJ_CIRCLE;
+char _OBJ_NET = OBJ_NET;
+char _OBJ_BUS = OBJ_BUS;
+char _OBJ_COMPONENT = OBJ_COMPONENT;
+char _OBJ_TEXT = OBJ_TEXT;
+char _OBJ_PIN = OBJ_PIN;
+char _OBJ_ARC = OBJ_ARC;
+char _OBJ_PLACEHOLDER = OBJ_PLACEHOLDER;
+
+
 
 /*! \brief Get object's unique id
  *
@@ -346,6 +361,22 @@ lepton_object_get_stroke (const LeptonObject *object)
 }
 
 
+/*! \brief Set the stroke of an object.
+ *
+ *  \param [in] object The object.
+ *  \param [in] stroke The #LeptonStroke pointer.
+ */
+void
+lepton_object_set_stroke (LeptonObject *object,
+                          LeptonStroke *stroke)
+{
+  g_return_if_fail (object != NULL);
+  g_return_if_fail (stroke != NULL);
+
+  object->stroke = stroke;
+}
+
+
 /*! \brief Get the line stroke type of an object.
  *
  *  \param [in] object The object.
@@ -506,6 +537,224 @@ lepton_object_set_stroke_space_length (LeptonObject *object,
 }
 
 
+/*! \brief Get the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \return Object's #LeptonFill pointer.
+ */
+LeptonFill*
+lepton_object_get_fill (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, NULL);
+
+  return object->fill;
+}
+
+
+/*! \brief Set the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \param [in] fill The #LeptonFill pointer.
+ */
+void
+lepton_object_set_fill (LeptonObject *object,
+                        LeptonFill *fill)
+{
+  g_return_if_fail (object != NULL);
+  g_return_if_fail (fill != NULL);
+
+  object->fill = fill;
+}
+
+
+/*! \brief Get the fill type of an object.
+ *
+ *  \param [in] object The object.
+ *  \return The fill type of the object.
+ */
+LeptonFillType
+lepton_object_get_fill_type (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, FILLING_HOLLOW);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_type (fill);
+}
+
+/*! \brief Get the fill width of an object.
+ *
+ * \note Fill width is meaningful only for some types of fill.
+ *
+ *  \param [in] object The object.
+ *  \return The fill width of the object.
+ */
+int
+lepton_object_get_fill_width (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, 0);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_width (fill);
+}
+
+/*! \brief Get the first pitch of the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \return The first pitch of the fill of the object.
+ */
+int
+lepton_object_get_fill_pitch1 (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, 0);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_pitch1 (fill);
+}
+
+/*! \brief Get the first pitch angle of the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \return The first pitch angle of the fill of the object.
+ */
+int
+lepton_object_get_fill_angle1 (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, 0);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_angle1 (fill);
+}
+
+/*! \brief Get the second pitch of the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \return The second pitch of the fill of the object.
+ */
+int
+lepton_object_get_fill_pitch2 (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, 0);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_pitch2 (fill);
+}
+
+/*! \brief Get the second pitch angle of the fill of an object.
+ *
+ *  \param [in] object The object.
+ *  \return The second pitch angle of the fill of the object.
+ */
+int
+lepton_object_get_fill_angle2 (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, 0);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  return lepton_fill_get_angle2 (fill);
+}
+
+
+void
+lepton_object_set_fill_type (LeptonObject *object,
+                             LeptonFillType fill_type)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_type (fill, fill_type);
+}
+
+void
+lepton_object_set_fill_width (LeptonObject *object,
+                              int width)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_width (fill, width);
+}
+
+void
+lepton_object_set_fill_pitch1 (LeptonObject *object,
+                               int pitch)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_pitch1 (fill, pitch);
+}
+
+void
+lepton_object_set_fill_angle1 (LeptonObject *object,
+                               int angle)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_angle1 (fill, angle);
+}
+
+void
+lepton_object_set_fill_pitch2 (LeptonObject *object,
+                               int pitch)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_pitch2 (fill, pitch);
+}
+
+void
+lepton_object_set_fill_angle2 (LeptonObject *object,
+                               int angle)
+{
+  g_return_if_fail (object != NULL);
+
+  LeptonFill *fill = lepton_object_get_fill (object);
+
+  g_return_if_fail (fill != NULL);
+
+  lepton_fill_set_angle2 (fill, angle);
+}
+
+
+/*! \brief Get object's 'whichend'.
+ *
+ *  \par Function Description
+ *  Obtains 'whichend' field of the #LeptonObject structure.  For
+ *  pins it defines which end of the pin is connectible.
+ *  \param [in] object The object to obtain the 'whichend' of.
+ *  \return The object 'whichend'.
+ */
+int
+lepton_object_get_whichend (LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, -1);
+  return object->whichend;
+}
+
+
 /*! \brief Make and return a copy of an object.
  *
  *  \par Function Description
@@ -630,14 +879,7 @@ lepton_object_delete (LeptonObject *o_current)
     lepton_picture_free (o_current->picture);
     o_current->picture = NULL;
 
-    if (o_current->text) {
-      /*printf("sdeleting text->string\n");*/
-      g_free(o_current->text->string);
-      o_current->text->string = NULL;
-      g_free(o_current->text->disp_string);
-      /* printf("sdeleting text\n");*/
-      g_free(o_current->text);
-    }
+    lepton_text_free (o_current->text);
     o_current->text = NULL;
 
     /* printf("sdeleting name\n");*/
@@ -647,6 +889,9 @@ lepton_object_delete (LeptonObject *o_current)
     lepton_stroke_free (o_current->stroke);
     o_current->stroke = NULL;
 
+    lepton_fill_free (o_current->fill);
+    o_current->fill = NULL;
+
     /* printf("sdeleting component_basename\n");*/
     g_free(o_current->component_basename);
     o_current->component_basename = NULL;
@@ -917,14 +1162,14 @@ lepton_object_set_fill_options (LeptonObject *o_current,
 
   lepton_object_emit_pre_change_notify (o_current);
 
-  o_current->fill_type = type;
-  o_current->fill_width = width;
+  lepton_object_set_fill_type (o_current, type);
+  lepton_object_set_fill_width (o_current, width);
 
-  o_current->fill_pitch1 = pitch1;
-  o_current->fill_angle1 = angle1;
+  lepton_object_set_fill_pitch1 (o_current, pitch1);
+  lepton_object_set_fill_angle1 (o_current, angle1);
 
-  o_current->fill_pitch2 = pitch2;
-  o_current->fill_angle2 = angle2;
+  lepton_object_set_fill_pitch2 (o_current, pitch2);
+  lepton_object_set_fill_angle2 (o_current, angle2);
 
   lepton_object_emit_change_notify (o_current);
 }
@@ -958,12 +1203,12 @@ lepton_object_get_fill_options (LeptonObject *object,
       && !lepton_object_is_path (object))
     return FALSE;
 
-  *type = object->fill_type;
-  *width = object->fill_width;
-  *pitch1 = object->fill_pitch1;
-  *angle1 = object->fill_angle1;
-  *pitch2 = object->fill_pitch2;
-  *angle2 = object->fill_angle2;
+  *type = lepton_object_get_fill_type (object);
+  *width = lepton_object_get_fill_width (object);
+  *pitch1 = lepton_object_get_fill_pitch1 (object);
+  *angle1 = lepton_object_get_fill_angle1 (object);
+  *pitch2 = lepton_object_get_fill_pitch2 (object);
+  *angle2 = lepton_object_get_fill_angle2 (object);
 
   return TRUE;
 }
@@ -1428,46 +1673,6 @@ lepton_object_emit_change_notify (LeptonObject *object)
   }
 }
 
-/*! \brief Query visibility of the object.
- *  \par Function Description
- *  Attribute getter for the visible field within the object.
- *
- *  \param object   The LeptonObject structure to be queried
- *  \return TRUE when VISIBLE, FALSE otherwise
- */
-gboolean
-lepton_object_is_visible (const LeptonObject *object)
-{
-  g_return_val_if_fail (object != NULL, FALSE);
-  return object->visibility == VISIBLE;
-}
-
-/*! \brief Get the visibility of an object
- *
- *  \param [in] object The LeptonObject structure to be queried
- *  \return VISIBLE or INVISIBLE
- */
-gint
-lepton_object_get_visibility (const LeptonObject *object)
-{
-  g_return_val_if_fail (object != NULL, VISIBLE);
-
-  return object->visibility;
-}
-
-/*! \brief Set visibility of the object.
- *
- *  \param object     The #LeptonObject structure to be modified
- *  \param visibility If the object should be visible
- */
-void
-lepton_object_set_visibility (LeptonObject *object,
-                              int visibility)
-{
-  g_return_if_fail (object != NULL);
-  object->visibility = visibility;
-}
-
 /*! \brief Return the bounds of the given object.
  *  \par Given an object, calculate the bounds coordinates.
  *
@@ -1497,7 +1702,7 @@ lepton_object_calculate_visible_bounds (LeptonObject *o_current,
   /* only do bounding boxes for visible or doing show_hidden_text*/
   /* you might lose some attrs though */
   if (lepton_object_is_text (o_current) &&
-      ! (lepton_object_is_visible (o_current) || include_hidden)) {
+      ! (lepton_text_object_is_visible (o_current) || include_hidden)) {
     return 0;
   }
 
@@ -1535,7 +1740,8 @@ lepton_object_calculate_visible_bounds (LeptonObject *o_current,
 
   case(OBJ_PATH):
     g_return_val_if_fail (o_current->path != NULL, 0);
-    if (o_current->path->num_sections <= 0) {
+    if (lepton_path_object_get_num_sections (o_current) <= 0)
+    {
       return 0;
     }
     lepton_path_object_calculate_bounds (o_current, &bounds);
@@ -1657,6 +1863,7 @@ lepton_object_new (int type,
   new_node->conn_list = NULL;
 
   new_node->stroke = lepton_stroke_new ();
+  new_node->fill = lepton_fill_new ();
 
   new_node->component_basename = NULL;
   new_node->parent = NULL;
@@ -1669,17 +1876,9 @@ lepton_object_new (int type,
 
   new_node->bus_ripper_direction = 0;
 
-  new_node->fill_width = 0;
-  new_node->fill_angle1 = 0;
-  new_node->fill_angle2 = 0;
-  new_node->fill_pitch1 = 0;
-  new_node->fill_pitch2 = 0;
-
   new_node->attribs = NULL;
   new_node->attached_to = NULL;
   new_node->copied_to = NULL;
-  new_node->show_name_value = SHOW_NAME_VALUE;
-  new_node->visibility = VISIBLE;
 
   new_node->pin_type = PIN_TYPE_NET;
   new_node->whichend = -1;
@@ -1688,3 +1887,31 @@ lepton_object_new (int type,
 
   return(new_node);
 }
+
+
+const char*
+lepton_object_visibility_to_string (gint visibility)
+{
+  const char *result = NULL;
+
+  switch (visibility)
+  {
+  case VISIBLE: result = "visible"; break;
+  case INVISIBLE: result = "invisible"; break;
+  default: break;
+  }
+
+  return result;
+}
+
+
+gint
+lepton_object_visibility_from_string (char *s)
+{
+  gint result = VISIBLE;
+
+  if      (strcmp (s, "visible") == 0) { result = VISIBLE; }
+  else if (strcmp (s, "invisible") == 0) { result = INVISIBLE; }
+
+  return result;
+}
