@@ -157,7 +157,6 @@ lepton_picture_object_read (const char *first_line,
   new_obj = lepton_picture_object_new (file_content,
                                        file_length,
                                        filename,
-                                       type,
                                        x1,
                                        y1+height,
                                        x1+width,
@@ -270,7 +269,6 @@ lepton_picture_object_to_buffer (const LeptonObject *object)
  *  \param [in]     file_content  Raw data of the image file, or NULL.
  *  \param [in]     file_length   Length of raw data buffer
  *  \param [in]     filename      File name backing this picture, or NULL.
- *  \param [in]     type          Must be OBJ_PICTURE.
  *  \param [in]     x1            Upper x coordinate.
  *  \param [in]     y1            Upper y coordinate.
  *  \param [in]     x2            Lower x coordinate.
@@ -284,7 +282,6 @@ LeptonObject*
 lepton_picture_object_new (const gchar *file_content,
                            gsize file_length,
                            const gchar *filename,
-                           char type,
                            int x1,
                            int y1,
                            int x2,
@@ -297,7 +294,7 @@ lepton_picture_object_new (const gchar *file_content,
   LeptonPicture *picture;
 
   /* create the object */
-  new_node = lepton_object_new (type, "picture");
+  new_node = lepton_object_new (OBJ_PICTURE, "picture");
 
   picture = lepton_picture_new ();
   new_node->picture = picture;
@@ -590,37 +587,6 @@ lepton_picture_object_modify (LeptonObject *object,
   lepton_object_emit_change_notify (object);
 }
 
-/*! \brief Modify a picture object's coordinates.
- * \par Function Description
- * Modifies the coordinates of all four corners of a picture \a
- * object.  The picture is adjusted to fit the rectangle enclosed by
- * the points (\a x1, \a y1) and (\a x2, \a y2), and scaled as large
- * as possible to still fit within that rectangle.
- *
- * \param [in,out] object   picture #LeptonObject to be modified.
- * \param [in]     x1       x coordinate of first corner of box.
- * \param [in]     y1       y coordinate of first corner of box.
- * \param [in]     x2       x coordinate of second corner of box.
- * \param [in]     y2       y coordinate of second corner of box.
- */
-void
-lepton_picture_object_modify_all (LeptonObject *object,
-                                  int x1,
-                                  int y1,
-                                  int x2,
-                                  int y2)
-{
-  lepton_object_emit_pre_change_notify (object);
-
-  /* Normalise the requested rectangle. */
-  lepton_picture_object_set_lower_x (object, (x1 > x2) ? x1 : x2);
-  lepton_picture_object_set_lower_y (object, (y1 > y2) ? y2 : y1);
-  lepton_picture_object_set_upper_x (object, (x1 > x2) ? x2 : x1);
-  lepton_picture_object_set_upper_y (object, (y1 > y2) ? y1 : y2);
-
-  lepton_object_emit_change_notify (object);
-}
-
 /*! \brief Rotate picture LeptonObject using WORLD coordinates.
  *  \par Function Description
  *  This function rotates the picture described by <B>*object</B> around
