@@ -1,6 +1,6 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@
 
 #include <time.h>
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
 /* Constant definitions
  * ===================
@@ -234,7 +234,7 @@ static gint compare_symbol_name (gconstpointer a, gconstpointer b);
 static void cache_find_oldest (gpointer key, gpointer value, gpointer user_data);
 static gchar *run_source_command (const gchar *command);
 static CLibSymbol *source_has_symbol (const CLibSource *source,
-				      const gchar *name);
+                                      const gchar *name);
 static gchar *uniquify_source_name (const gchar *name);
 static void refresh_directory (CLibSource *source);
 static void refresh_command (CLibSource *source);
@@ -511,7 +511,7 @@ GList *s_clib_get_sources (const gboolean sorted)
  *  \return The matching symbol, or \b NULL if no match was found.
  */
 static CLibSymbol *source_has_symbol (const CLibSource *source,
-				      const gchar *name)
+                                      const gchar *name)
 {
   GList *symlist;
   CLibSymbol *symbol;
@@ -630,7 +630,7 @@ static void refresh_directory (CLibSource *source)
 
   /* Now sort the list of symbols by name. */
   source->symbols = g_list_sort (source->symbols,
-				 (GCompareFunc) compare_symbol_name);
+                                 (GCompareFunc) compare_symbol_name);
 
   s_clib_flush_search_cache();
   s_clib_flush_symbol_cache();
@@ -671,7 +671,7 @@ static void refresh_command (CLibSource *source)
     if (line == NULL) break;
     if (line[0] == '.') continue;  /* TODO is this sane? */
 
-    name = geda_string_get_first_line (g_strdup(line));
+    name = lepton_str_get_first_line (g_strdup(line));
 
     /* skip symbols already known about */
     if (source_has_symbol (source, name) != NULL) {
@@ -693,7 +693,7 @@ static void refresh_command (CLibSource *source)
 
   /* Sort all symbols by name. */
   source->symbols = g_list_sort (source->symbols,
-				 (GCompareFunc) compare_symbol_name);
+                                 (GCompareFunc) compare_symbol_name);
 
   s_clib_flush_search_cache();
   s_clib_flush_symbol_cache();
@@ -754,7 +754,7 @@ static void refresh_scm (CLibSource *source)
 
   /* Now sort the list of symbols by name. */
   source->symbols = g_list_sort (source->symbols,
-				 (GCompareFunc) compare_symbol_name);
+                                 (GCompareFunc) compare_symbol_name);
 
   s_clib_flush_search_cache();
   s_clib_flush_symbol_cache();
@@ -779,16 +779,16 @@ void s_clib_refresh ()
     switch (source->type)
       {
       case CLIB_DIR:
-	refresh_directory(source);
-	break;
+        refresh_directory(source);
+        break;
       case CLIB_CMD:
-	refresh_command (source);
-	break;
+        refresh_command (source);
+        break;
       case CLIB_SCM:
-	refresh_scm (source);
-	break;
+        refresh_scm (source);
+        break;
       default:
-	g_critical("s_clib_refresh: source %1$p has bad source type %2$i\n",
+        g_critical("s_clib_refresh: source %1$p has bad source type %2$i\n",
                    source, (gint) source->type);
         break;
       }
@@ -835,7 +835,7 @@ const CLibSource *s_clib_get_source_by_name (const gchar *name)
  *  \return The #CLibSource associated with the directory.
  */
 const CLibSource *s_clib_add_directory (const gchar *directory,
-					const gchar *name)
+                                        const gchar *name)
 {
   CLibSource *source;
   gchar *intname, *realname;
@@ -882,7 +882,7 @@ const CLibSource *s_clib_add_directory (const gchar *directory,
  */
 const CLibSource *s_clib_add_command (const gchar *list_cmd,
                                       const gchar *get_cmd,
-				      const gchar *name)
+                                      const gchar *name)
 {
   CLibSource *source;
   gchar *realname;
@@ -1065,7 +1065,7 @@ static gchar *get_data_directory (const CLibSymbol *symbol)
   g_return_val_if_fail ((symbol->source->type == CLIB_DIR), NULL);
 
   filename = g_build_filename(symbol->source->directory,
-			      symbol->name, NULL);
+                              symbol->name, NULL);
 
   g_file_get_contents (filename, &data, NULL, &e);
 
@@ -1127,7 +1127,7 @@ static gchar *get_data_scm (const CLibSymbol *symbol)
   g_return_val_if_fail ((symbol->source->type == CLIB_SCM), NULL);
 
   symdata = scm_call_1 (symbol->source->get_fn,
-			scm_from_utf8_string (symbol->name));
+                        scm_from_utf8_string (symbol->name));
 
   if (!scm_is_string (symdata)) {
     g_message (_("Failed to load symbol data [%1$s] from source [%2$s]"),
@@ -1284,24 +1284,24 @@ GList *s_clib_search (const gchar *pattern, const CLibSearchMode mode)
     source = (CLibSource *) sourcelist->data;
 
     for (symlist = source->symbols;
-	 symlist != NULL;
-	 symlist = g_list_next(symlist)) {
+         symlist != NULL;
+         symlist = g_list_next(symlist)) {
 
       symbol = (CLibSymbol *) symlist->data;
 
       switch (mode)
-	{
-	case CLIB_EXACT:
-	  if (strcmp (pattern, symbol->name) == 0) {
-	    result = g_list_prepend (result, symbol);
-	  }
-	  break;
-	case CLIB_GLOB:
-	  if (g_pattern_match_string (globpattern, symbol->name)) {
-	    result = g_list_prepend (result, symbol);
-	  }
-	  break;
-	}
+        {
+        case CLIB_EXACT:
+          if (strcmp (pattern, symbol->name) == 0) {
+            result = g_list_prepend (result, symbol);
+          }
+          break;
+        case CLIB_GLOB:
+          if (g_pattern_match_string (globpattern, symbol->name)) {
+            result = g_list_prepend (result, symbol);
+          }
+          break;
+        }
     }
   }
 
@@ -1411,8 +1411,8 @@ gchar *s_clib_symbol_get_data_by_name (const gchar *name)
 /*! \brief Get a list of symbols used.
  *  \par Function Description
  *
- *  Scan a #TOPLEVEL structure's object list looking for symbols, and
- *  return them in a list.
+ *  Scan a #LeptonToplevel structure's object list looking for
+ *  symbols, and return them in a list.
  *
  *  \warning The #CLibSymbol instances in the \b GList returned belong
  *  to the component library, and should be considered constants; they
@@ -1424,15 +1424,16 @@ gchar *s_clib_symbol_get_data_by_name (const gchar *name)
  *  \bug Only includes components which are not embedded, but they
  *  should (probably) also appear in the list.
  *
- *  \param toplevel #TOPLEVEL structure to scan.
+ *  \param toplevel #LeptonToplevel structure to scan.
  *  \return GList of symbols.
  */
-GList *s_toplevel_get_symbols (const TOPLEVEL *toplevel)
+GList*
+s_toplevel_get_symbols (const LeptonToplevel *toplevel)
 {
   GList *result = NULL;
   GList *iter = NULL;
-  OBJECT *o = NULL;
-  PAGE *page;
+  LeptonObject *o = NULL;
+  LeptonPage *page;
   GList *symlist = NULL;
   CLibSymbol *sym = NULL;
   const GList *p_iter;
@@ -1440,15 +1441,15 @@ GList *s_toplevel_get_symbols (const TOPLEVEL *toplevel)
 
   g_return_val_if_fail ((toplevel != NULL), NULL);
 
-  for ( p_iter = geda_list_get_glist( toplevel->pages );
+  for ( p_iter = lepton_list_get_glist( toplevel->pages );
         p_iter != NULL;
         p_iter = g_list_next( p_iter )) {
-    page = (PAGE *)p_iter->data;
+    page = (LeptonPage *) p_iter->data;
     for (o_iter = s_page_objects (page);
          o_iter != NULL;
          o_iter = g_list_next (o_iter)) {
-      o = (OBJECT *)o_iter->data;
-      if (o->type != OBJ_COMPONENT) continue;
+      o = (LeptonObject *)o_iter->data;
+      if (!lepton_object_is_component (o)) continue;
       if (o->component_basename == NULL)  continue;
 
       /* Since we're not looking at embedded symbols, the first
