@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,21 +25,21 @@
 #include <stdlib.h>
 #endif
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
 /*! \file s_conn.c
  *  \brief The connection system
- *  
+ *
  *  The connection system stores and tracks the connections between
  *  connected <b>OBJECTS</b>. The connected OBJECTS are either
  *  <b>pins</b>, <b>nets</b> and <b>busses</b>.
- *  
+ *
  *  Each connection object with the type <b>st_conn</b> represents a
  *  single unidirectional relation to another object.
- *  
+ *
  *  The following figure with two nets and a pin shows the relations
  *  between connections and OBJECTS:
- *  
+ *
  *  \image html s_conn_overview.png
  *  \image latex s_conn_overview.pdf "Connection overview" width=14cm
  */
@@ -47,17 +47,22 @@
 
 /*! \brief create a new connection object
  *  \par Function Description
- *  create a single st_conn object and initialize it with the 
+ *  create a single st_conn object and initialize it with the
  *  given parameters.
- *  
+ *
  *  \return The new connection object
  */
-CONN *s_conn_return_new(OBJECT * other_object, int type, int x, int y,
-			int whichone, int other_whichone)
+LeptonConn*
+s_conn_return_new (LeptonObject *other_object,
+                   int type,
+                   int x,
+                   int y,
+                   int whichone,
+                   int other_whichone)
 {
-  CONN *new_conn;
+  LeptonConn *new_conn;
 
-  new_conn = (CONN *) g_malloc(sizeof(CONN));
+  new_conn = (LeptonConn *) g_malloc(sizeof(LeptonConn));
 
 #if DEBUG
   printf("** creating: %s %d %d\n", other_object->name, x, y);
@@ -79,16 +84,18 @@ CONN *s_conn_return_new(OBJECT * other_object, int type, int x, int y,
  *  in the list of connections.
  *  \param conn_list list of connection objects
  *  \param input_conn single connection object.
- *  \return TRUE if the CONN structure is unique, FALSE otherwise.
+ *  \return TRUE if the LeptonConn structure is unique, FALSE otherwise.
  */
-int s_conn_uniq(GList * conn_list, CONN * input_conn)
+int
+s_conn_uniq (GList * conn_list,
+             LeptonConn * input_conn)
 {
   GList *c_current;
-  CONN *conn;
+  LeptonConn *conn;
 
   c_current = conn_list;
   while (c_current != NULL) {
-    conn = (CONN *) c_current->data;
+    conn = (LeptonConn *) c_current->data;
 
     if (conn->other_object == input_conn->other_object &&
         conn->x == input_conn->x && conn->y == input_conn->y &&
@@ -104,84 +111,84 @@ int s_conn_uniq(GList * conn_list, CONN * input_conn)
 
 /*! \brief remove a object from the connection list of another object
  *  \par Function Description
- *  This function removes the OBJECT <b>to_remove</b> from the connection
- *  list of the OBJECT <b>other_object</b>.
+ *  This function removes the LeptonObject <b>to_remove</b> from the connection
+ *  list of the LeptonObject <b>other_object</b>.
  *
- *  \param other_object OBJECT from that the to_remove OBJECT needs to be removed
- *  \param to_remove OBJECT to remove
+ *  \param other_object LeptonObject from that the to_remove LeptonObject needs to be removed
+ *  \param to_remove LeptonObject to remove
  *  \return TRUE if a connection has been deleted, FALSE otherwise
  */
 int
-s_conn_remove_other (OBJECT *other_object,
-                     OBJECT *to_remove)
+s_conn_remove_other (LeptonObject *other_object,
+                     LeptonObject *to_remove)
 {
-    GList *c_current = NULL;
-    CONN *conn = NULL;
+  GList *c_current = NULL;
+  LeptonConn *conn = NULL;
 
-    o_emit_pre_change_notify (other_object);
+  lepton_object_emit_pre_change_notify (other_object);
 
-    c_current = other_object->conn_list;
-    while (c_current != NULL) {
-	conn = (CONN *) c_current->data;
+  c_current = other_object->conn_list;
+  while (c_current != NULL) {
+    conn = (LeptonConn *) c_current->data;
 
-	if (conn->other_object == to_remove) {
-	    other_object->conn_list =
-		g_list_remove(other_object->conn_list, conn);
+    if (conn->other_object == to_remove) {
+      other_object->conn_list =
+        g_list_remove(other_object->conn_list, conn);
 
 #if DEBUG
-	    printf("Found other_object in remove_other\n");
-	    printf("Freeing other: %s %d %d\n", conn->other_object->name,
-		   conn->x, conn->y);
+      printf("Found other_object in remove_other\n");
+      printf("Freeing other: %s %d %d\n", conn->other_object->name,
+             conn->x, conn->y);
 #endif
 
-	    /* Do not write modify c_current like this, since this will cause */
-	    /* very nasty data corruption and upset glib's memory slice */
-	    /* allocator. */
-	    /* c_current->data = NULL;   Do not comment in */
+      /* Do not write modify c_current like this, since this will cause */
+      /* very nasty data corruption and upset glib's memory slice */
+      /* allocator. */
+      /* c_current->data = NULL;   Do not comment in */
 
-	    g_free(conn);
+      g_free(conn);
 
 #if 0 /* this does not work right */
-            if (other_object->type == OBJ_BUS &&
-                other_object->conn_list == NULL) {
-              other_object->bus_ripper_direction = 0;
-            }
+      if (lepton_object_is_bus (other_object) &&
+          other_object->conn_list == NULL) {
+        other_object->bus_ripper_direction = 0;
+      }
 #endif
-            
-	    return (TRUE);
-	}
 
-	c_current = g_list_next(c_current);
+      return (TRUE);
     }
 
-    o_emit_change_notify (other_object);
+    c_current = g_list_next(c_current);
+  }
 
-    return (FALSE);
+  lepton_object_emit_change_notify (other_object);
+
+  return (FALSE);
 }
 
-/*! \brief remove an OBJECT from the connection system
+/*! \brief remove an LeptonObject from the connection system
  *  \par Function Description
- *  This function removes all connections from and to the OBJECT
+ *  This function removes all connections from and to the LeptonObject
  *  <b>to_remove</b>.
  *
- *  \param to_remove OBJECT to unconnected from all other objects
+ *  \param to_remove LeptonObject to unconnected from all other objects
  */
 void
-s_conn_remove_object_connections (OBJECT *to_remove)
+s_conn_remove_object_connections (LeptonObject *to_remove)
 {
   GList *c_iter;
-  CONN *conn;
+  LeptonConn *conn;
   GList *iter;
-  OBJECT *o_current;
+  LeptonObject *o_current;
 
-  switch (to_remove->type) {
+  switch (lepton_object_get_type (to_remove)) {
     case OBJ_PIN:
     case OBJ_NET:
     case OBJ_BUS:
       for (c_iter = to_remove->conn_list;
            c_iter != NULL;
            c_iter = g_list_next (c_iter)) {
-        conn = (CONN *) c_iter->data;
+        conn = (LeptonConn *) c_iter->data;
 
         /* keep calling this till it returns false (all refs removed) */
         /* there is NO body to this while loop */
@@ -196,85 +203,85 @@ s_conn_remove_object_connections (OBJECT *to_remove)
       break;
 
     case OBJ_COMPONENT:
-    case OBJ_PLACEHOLDER:
       for (iter = to_remove->component->prim_objs; iter != NULL; iter = g_list_next (iter)) {
-        o_current = (OBJECT*) iter->data;
+        o_current = (LeptonObject*) iter->data;
         s_conn_remove_object_connections (o_current);
       }
       break;
   }
 }
 
-/*! \brief Checks if a point is a midpoint of an OBJECT
+/*! \brief Checks if a point is a midpoint of an LeptonObject
  *  \par Function Description
- *  Checks if the point (<b>x</b>,<b>y</b>) is on the OBJECT
+ *  Checks if the point (<b>x</b>,<b>y</b>) is on the LeptonObject
  *  and between it's endpoints.
- *  \return TRUE if the point is a midpoint of the OBJECT. FALSE 
- *  if the point is not a midpoinit or if the OBJECT is not a 
- *  NET a PIN or a BUS or if the OBJECT 
- *  has neither horizontal nor vertical orientation. 
+ *  \return TRUE if the point is a midpoint of the LeptonObject. FALSE
+ *  if the point is not a midpoinit or if the LeptonObject is not a
+ *  NET a PIN or a BUS or if the LeptonObject
+ *  has neither horizontal nor vertical orientation.
  */
-OBJECT *s_conn_check_midpoint(OBJECT *o_current, int x, int y)
+LeptonObject *s_conn_check_midpoint(LeptonObject *o_current, int x, int y)
 {
   int min_x, min_y, max_x, max_y;
 
-  switch(o_current->type) {
-    case(OBJ_NET):
-    case(OBJ_PIN):
-    case(OBJ_BUS):
-      min_y = MIN(o_current->line->y[0], 
-                  o_current->line->y[1]);
-      max_y = MAX(o_current->line->y[0], 
-                  o_current->line->y[1]);
+  switch (lepton_object_get_type (o_current)) {
+  case(OBJ_NET):
+  case(OBJ_PIN):
+  case(OBJ_BUS):
+    min_y = MIN(o_current->line->y[0],
+                o_current->line->y[1]);
+    max_y = MAX(o_current->line->y[0],
+                o_current->line->y[1]);
 
-				/* vertical */
-      if ( (o_current->line->x[0] == x) &&
-           (y > min_y) && (y < max_y) &&
-           (o_current->line->x[0] ==
-            o_current->line->x[1]) ) {
+    /* vertical */
+    if ( (o_current->line->x[0] == x) &&
+         (y > min_y) && (y < max_y) &&
+         (o_current->line->x[0] ==
+          o_current->line->x[1]) ) {
 #if DEBUG
-        printf("Found vertical point\n");
+      printf("Found vertical point\n");
 #endif
-        return(o_current);
-      }
+      return(o_current);
+    }
 
-      min_x = MIN(o_current->line->x[0], 
-                  o_current->line->x[1]);
-      max_x = MAX(o_current->line->x[0], 
-                  o_current->line->x[1]);
+    min_x = MIN(o_current->line->x[0],
+                o_current->line->x[1]);
+    max_x = MAX(o_current->line->x[0],
+                o_current->line->x[1]);
 
-				/* horizontal */
-      if ( (o_current->line->y[0] == y) &&
-           (x > min_x) && (x < max_x) &&
-           (o_current->line->y[0] ==
-            o_current->line->y[1]) ) {
+    /* horizontal */
+    if ( (o_current->line->y[0] == y) &&
+         (x > min_x) && (x < max_x) &&
+         (o_current->line->y[0] ==
+          o_current->line->y[1]) ) {
 #if DEBUG
-        printf("Found horizontal point\n");
+      printf("Found horizontal point\n");
 #endif
-        return(o_current);
-      }
+      return(o_current);
+    }
 
-      break;
+    break;
   }
   return(NULL);
 }
 
-/*! \brief adds a GList of OBJECTs to the connection system
+/*! \brief adds a GList of LeptonObjects to the connection system
  *
  *  \par Function Description
  *  This function adds all connections from and to the OBJECTS
  *  of the given GList.
  *
- *  \param page      The PAGE structure
- *  \param obj_list  GList of OBJECTs to add into the connection system
+ *  \param page      The LeptonPage structure
+ *  \param obj_list  GList of LeptonObjects to add into the connection system
  */
-void s_conn_update_glist (PAGE* page, GList *obj_list)
+void s_conn_update_glist (LeptonPage* page,
+                          GList *obj_list)
 {
-  OBJECT *o_current;
+  LeptonObject *o_current;
   GList *iter;
 
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    o_current = (OBJECT*) iter->data;
+    o_current = (LeptonObject*) iter->data;
     s_conn_update_object (page, o_current);
   }
 }
@@ -285,13 +292,13 @@ void s_conn_update_glist (PAGE* page, GList *obj_list)
  *  \par Function Description
  *  Checks if an object is a bus or a bus pin
  *
- *  \param object  The OBJECT to test
+ *  \param object  The LeptonObject to test
  *  \return TRUE if the objects is a bis, or bus pin
  */
-static int is_bus_related (OBJECT *object)
+static int is_bus_related (LeptonObject *object)
 {
-  return (object->type == OBJ_BUS ||
-           (object->type == OBJ_PIN && object->pin_type == PIN_TYPE_BUS));
+  return (lepton_object_is_bus (object) ||
+          (lepton_object_is_pin (object) && object->pin_type == PIN_TYPE_BUS));
 }
 
 
@@ -300,23 +307,23 @@ static int is_bus_related (OBJECT *object)
  *  \par Function Description
  *  Checks if two objects are legal to be connected together
  *
- *  \param object1  First OBJECT
- *  \param object2  Second OBJECT
+ *  \param object1  First LeptonObject
+ *  \param object2  Second LeptonObject
  *  \return TRUE if the objects are compatible, FALSE if not
  */
-static int check_direct_compat (OBJECT *object1, OBJECT *object2)
+static int check_direct_compat (LeptonObject *object1, LeptonObject *object2)
 {
   return (is_bus_related (object1) == is_bus_related (object2));
 }
 
 
-static void add_connection (OBJECT *object, OBJECT *other_object,
+static void add_connection (LeptonObject *object, LeptonObject *other_object,
                             int type, int x, int y,
                             int whichone, int other_whichone)
 {
   /* Describe the connection */
-  CONN *new_conn = s_conn_return_new (other_object, type, x, y,
-                                      whichone, other_whichone);
+  LeptonConn *new_conn =
+    s_conn_return_new (other_object, type, x, y, whichone, other_whichone);
   /* Do uniqness check */
   if (s_conn_uniq (object->conn_list, new_conn)) {
     object->conn_list = g_list_append (object->conn_list, new_conn);
@@ -325,35 +332,37 @@ static void add_connection (OBJECT *object, OBJECT *other_object,
   }
 }
 
-/*! \brief add a line OBJECT to the connection system
+/*! \brief add a line LeptonObject to the connection system
  *  \par Function Description
- *  This function searches for all geometrical connections of the OBJECT
- *  <b>object</b> to all other connectable objects. It adds connections
- *  to the object and from all other
+ *  This function searches for all geometrical connections of the
+ *  LeptonObject <b>object</b> to all other connectable
+ *  objects. It adds connections to the object and from all other
  *  objects to this one.
- *  \param page   The PAGE structure
- *  \param object OBJECT to add into the connection system
+ *  \param page   The LeptonPage structure
+ *  \param object LeptonObject to add into the connection system
  */
-static void s_conn_update_line_object (PAGE* page, OBJECT *object)
+static void
+s_conn_update_line_object (LeptonPage* page,
+                           LeptonObject *object)
 {
   GList *object_list;
-  OBJECT *other_object;
-  OBJECT *found;
+  LeptonObject *other_object;
+  LeptonObject *found;
   int j, k;
-  OBJECT *component, *other_component;
+  LeptonObject *component, *other_component;
 
-  component = o_get_parent (object);
+  component = lepton_object_get_parent (object);
 
   /* loop over all connectible objects */
   for (object_list = page->connectible_list;
        object_list != NULL;
        object_list = g_list_next (object_list)) {
-    other_object = (OBJECT*) object_list->data;
+    other_object = (LeptonObject*) object_list->data;
 
     if (object == other_object)
       continue;
 
-    other_component = o_get_parent (other_object);
+    other_component = lepton_object_get_parent (other_object);
 
     /* An object inside a symbol can only be connected up to another
      * object if they are (a) both inside the same object, or (b)
@@ -363,16 +372,21 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
     if (component && other_component) {
       /* If inside different symbols, both must be pins to connect. */
       if (component != other_component
-          && (object->type != OBJ_PIN || other_object->type != OBJ_PIN)) {
+          && (!lepton_object_is_pin (object) ||
+              !lepton_object_is_pin (other_object))) {
         continue;
       }
 
     /* 2. Updating object is inside a symbol, but other object is not. */
-    } else if (component && !other_component) {
-      if (object->type != OBJ_PIN) continue;
+    }
+    else if (component && !other_component)
+    {
+      if (!lepton_object_is_pin (object)) continue;
     /* 3. Updating object not inside symbol, but other object is. */
-    } else if (!component && other_component) {
-      if (other_object->type != OBJ_PIN) continue;
+    }
+    else if (!component && other_component)
+    {
+      if (!lepton_object_is_pin (other_object)) continue;
     }
 
     /* Here is where you check the end points */
@@ -380,14 +394,16 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
     for (k = 0; k < 2; k++) {
 
       /* If the other object is a pin, only check the correct end */
-      if (other_object->type == OBJ_PIN && other_object->whichend != k)
+      if (lepton_object_is_pin (other_object) &&
+          other_object->whichend != k)
         continue;
 
       /* Check both end points of the object */
       for (j = 0; j < 2; j++) {
 
         /* If the object is a pin, only check the correct end */
-        if (object->type == OBJ_PIN && object->whichend != j)
+        if (lepton_object_is_pin (object) &&
+            object->whichend != j)
           continue;
 
         /* Check for coincidence and compatibility between
@@ -396,7 +412,7 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
             object->line->y[j] == other_object->line->y[k] &&
             check_direct_compat (object, other_object)) {
 
-          o_emit_pre_change_notify (other_object);
+          lepton_object_emit_pre_change_notify (other_object);
 
           add_connection (object, other_object, CONN_ENDPOINT,
                           other_object->line->x[k],
@@ -406,7 +422,7 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
                           object->line->x[j],
                           object->line->y[j], k, j);
 
-          o_emit_change_notify (other_object);
+          lepton_object_emit_change_notify (other_object);
         }
       }
     }
@@ -415,7 +431,8 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
     for (k = 0; k < 2; k++) {
 
       /* If the object is a pin, only check the correct end */
-      if (object->type == OBJ_PIN && object->whichend != k)
+      if (lepton_object_is_pin (object) &&
+          object->whichend != k)
         continue;
 
       /* check for midpoint of other object, k endpoint of current obj*/
@@ -425,9 +442,11 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
       /* Pins are not allowed midpoint connections onto them. */
       /* Allow nets to connect to the middle of buses. */
       /* Allow compatible objects to connect. */
-      if (found && other_object->type != OBJ_PIN &&
-          ((object->type == OBJ_NET && other_object->type == OBJ_BUS) ||
-            check_direct_compat (object, other_object))) {
+      if (found && !lepton_object_is_pin (other_object) &&
+          ((lepton_object_is_net (object) &&
+            lepton_object_is_bus (other_object)) ||
+           check_direct_compat (object, other_object)))
+      {
 
         add_connection (object, other_object, CONN_MIDPOINT,
                         object->line->x[k],
@@ -443,7 +462,8 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
     for (k = 0; k < 2; k++) {
 
       /* If the other object is a pin, only check the correct end */
-      if (other_object->type == OBJ_PIN && other_object->whichend != k)
+      if (lepton_object_is_pin (other_object) &&
+          other_object->whichend != k)
         continue;
 
       /* do object's endpoints cross the middle of other_object? */
@@ -454,9 +474,10 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
       /* Pins are not allowed midpoint connections onto them. */
       /* Allow nets to connect to the middle of buses. */
       /* Allow compatible objects to connect. */
-      if (found && object->type != OBJ_PIN &&
-           ((object->type == OBJ_BUS && other_object->type == OBJ_NET) ||
-             check_direct_compat (object, other_object))) {
+      if (found && !lepton_object_is_pin (object) &&
+          ((lepton_object_is_bus (object) &&
+            lepton_object_is_net (other_object)) ||
+           check_direct_compat (object, other_object))) {
 
         add_connection (object, other_object, CONN_MIDPOINT,
                         other_object->line->x[k],
@@ -474,23 +495,26 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
 #endif
 }
 
-/*! \brief add an OBJECT to the connection system
+/*! \brief add an LeptonObject to the connection system
  *
  *  \par Function Description
- *  This function searches for all geometrical connections of the OBJECT
- *  <b>object</b> to all other connectable objects. It adds connections
- *  to the object and from all other objects to this one.
+ *  This function searches for all geometrical connections of the
+ *  LeptonObject <b>object</b> to all other connectable
+ *  objects. It adds connections to the object and from all other
+ *  objects to this one.
  *
- *  \param page   The PAGE structure
- *  \param object OBJECT to add into the connection system
+ *  \param page   The LeptonPage structure
+ *  \param object LeptonObject to add into the connection system
  */
-void s_conn_update_object (PAGE* page, OBJECT *object)
+void
+s_conn_update_object (LeptonPage* page,
+                      LeptonObject *object)
 {
 
   /* Add object to the list of connectible objects */
   s_conn_add_object (page, object);
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
     case OBJ_PIN:
     case OBJ_NET:
     case OBJ_BUS:
@@ -498,7 +522,6 @@ void s_conn_update_object (PAGE* page, OBJECT *object)
       break;
 
     case OBJ_COMPONENT:
-    case OBJ_PLACEHOLDER:
       s_conn_update_glist (page, object->component->prim_objs);
       break;
   }
@@ -511,14 +534,14 @@ void s_conn_update_object (PAGE* page, OBJECT *object)
  */
 void s_conn_print(GList * conn_list)
 {
-  CONN *conn;
+  LeptonConn *conn;
   GList *cl_current;
 
   printf("\nStarting s_conn_print\n");
   cl_current = conn_list;
   while (cl_current != NULL) {
 
-    conn = (CONN *) cl_current->data;
+    conn = (LeptonConn *) cl_current->data;
     printf("-----------------------------------\n");
     printf("other object: %s\n", conn->other_object->name);
     printf("type: %d\n", conn->type);
@@ -537,42 +560,42 @@ void s_conn_print(GList * conn_list)
  *  This method searches the connection list for the first matching
  *  connection with the given x, y, and whichone endpoint.
  *
- *  \param [in] new_net    Net OBJECT to compare to.
+ *  \param [in] new_net    Net LeptonObject to compare to.
  *  \param [in] whichone   The connection number to check.
  *  \param [in] conn_list  List of existing connections to compare
  *                         <B>new_net</B> to.
- *  \return TRUE if a matching connection is found, FALSE otherwise. 
+ *  \return TRUE if a matching connection is found, FALSE otherwise.
  */
-int s_conn_net_search(OBJECT* new_net, int whichone, GList * conn_list)
+int s_conn_net_search(LeptonObject* new_net, int whichone, GList * conn_list)
 {
-  CONN *conn;
+  LeptonConn *conn;
   GList *cl_current;
 
   cl_current = conn_list;
   while (cl_current != NULL) {
 
-    conn = (CONN *) cl_current->data;
-    if (conn != NULL && conn->whichone == whichone && 
+    conn = (LeptonConn *) cl_current->data;
+    if (conn != NULL && conn->whichone == whichone &&
         conn->x == new_net->line->x[whichone] &&
-	conn->y == new_net->line->y[whichone])
+        conn->y == new_net->line->y[whichone])
     {
        return TRUE;
     }
 
     cl_current = g_list_next(cl_current);
   }
- 
+
   return FALSE;
 }
 
-/*! \brief get a list of all objects connected to a list of OBJECTs.
+/*! \brief get a list of all objects connected to a list of LeptonObjects.
  *
  *  \par Function Description
  *  This function gets all other_object from the connection
- *  list of the OBJECTs in the pased list.
+ *  list of the LeptonObjects in the pased list.
  *
- *  \param [in] input_list GList of OBJECT's or NULL
- *  \param [in] obj_list   The GList of OBJECT to get connections from
+ *  \param [in] input_list GList of LeptonObject's or NULL
+ *  \param [in] obj_list   The GList of LeptonObject to get connections from
  *  \return A GList of objects
  *
  *  \warning
@@ -583,12 +606,12 @@ static GList *s_conn_return_glist_others (GList *input_list, GList *obj_list)
 {
   GList *return_list;
   GList *iter;
-  OBJECT *o_current;
+  LeptonObject *o_current;
 
   return_list = input_list;
 
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    o_current = (OBJECT*) iter->data;
+    o_current = (LeptonObject*) iter->data;
     return_list = s_conn_return_others (return_list, o_current);
   }
 
@@ -602,28 +625,28 @@ static GList *s_conn_return_glist_others (GList *input_list, GList *obj_list)
  *  Component objects are entered, and their prim_objs processed. If an <b>input_list</b>
  *  is given, the other objects are appended to that list.
  *
- *  \param [in] input_list   GList of OBJECT's
- *  \param [in] object       OBJECT to get other OBJECTs from
- *  \return A GList of OBJECTs
+ *  \param [in] input_list   GList of LeptonObject's
+ *  \param [in] object       LeptonObject to get other LeptonObjects from
+ *  \return A GList of LeptonObjects
  *
  *  \warning
  *  Caller must g_list_free returned GList pointer.
  *  Do not free individual data items in list.
  */
-GList *s_conn_return_others(GList *input_list, OBJECT *object)
+GList *s_conn_return_others(GList *input_list, LeptonObject *object)
 {
   GList *c_iter;
   GList *return_list;
 
   return_list = input_list;
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
     case OBJ_PIN:
     case OBJ_NET:
     case OBJ_BUS:
       for (c_iter = object->conn_list;
            c_iter != NULL; c_iter = g_list_next (c_iter)) {
-        CONN *conn = (CONN *) c_iter->data;
+        LeptonConn *conn = (LeptonConn *) c_iter->data;
 
         if (conn->other_object && conn->other_object != object) {
           return_list = g_list_append(return_list, conn->other_object);
@@ -632,7 +655,6 @@ GList *s_conn_return_others(GList *input_list, OBJECT *object)
       break;
 
     case OBJ_COMPONENT:
-    case OBJ_PLACEHOLDER:
       return_list = s_conn_return_glist_others (return_list,
                                                 object->component->prim_objs);
       break;
@@ -643,10 +665,12 @@ GList *s_conn_return_others(GList *input_list, OBJECT *object)
 
 /*! \brief add a line object to the list of connectible objects
  *  \par Function Description
- *  \param page   The PAGE structure
- *  \param object The line OBJECT to add
+ *  \param page   The LeptonPage structure
+ *  \param object The line LeptonObject to add
  */
-static void s_conn_add_line_object (PAGE *page, OBJECT *object)
+static void
+s_conn_add_line_object (LeptonPage *page,
+                        LeptonObject *object)
 {
   g_return_if_fail (object != NULL);
   g_return_if_fail (object->line != NULL);
@@ -669,14 +693,16 @@ static void s_conn_add_line_object (PAGE *page, OBJECT *object)
  *  This function takes dispatches the object to the correct
  *  function, depending on its type.
  *
- *  \param page   The PAGE structure
- *  \param object The line OBJECT to add
+ *  \param page   The LeptonPage structure
+ *  \param object The line LeptonObject to add
  */
-void s_conn_add_object (PAGE *page, OBJECT *object)
+void
+s_conn_add_object (LeptonPage *page,
+                   LeptonObject *object)
 {
   GList *iter;
 
-  switch (object->type) {
+  switch (lepton_object_get_type (object)) {
     case OBJ_NET:
     case OBJ_PIN:
     case OBJ_BUS:
@@ -684,11 +710,10 @@ void s_conn_add_object (PAGE *page, OBJECT *object)
       break;
 
   case OBJ_COMPONENT:
-  case OBJ_PLACEHOLDER:
     for (iter = object->component->prim_objs;
          iter != NULL;
          iter = g_list_next (iter)) {
-      s_conn_add_object (page, (OBJECT*) iter->data);
+      s_conn_add_object (page, (LeptonObject*) iter->data);
     }
   }
 }
@@ -697,7 +722,9 @@ void s_conn_add_object (PAGE *page, OBJECT *object)
  *  \par Function Description
  *  \param object The object to remove
  */
-void s_conn_remove_object(PAGE* page, OBJECT *object)
+void
+s_conn_remove_object (LeptonPage* page,
+                      LeptonObject *object)
 {
   GList *iter;
 
@@ -706,11 +733,12 @@ void s_conn_remove_object(PAGE* page, OBJECT *object)
   }
 
   /* Correctly deal with compound objects */
-  if (object->type == OBJ_COMPONENT || object->type == OBJ_PLACEHOLDER) {
+  if (lepton_object_is_component (object))
+  {
     for (iter = object->component->prim_objs;
          iter != NULL;
          iter = g_list_next (iter)) {
-      s_conn_remove_object (page, (OBJECT*) iter->data);
+      s_conn_remove_object (page, (LeptonObject*) iter->data);
     }
   }
 
