@@ -1,6 +1,6 @@
 /* Lepton EDA library
  * Copyright (C) 2013-2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,16 +24,16 @@
 
 #include <config.h>
 
-#include "libgeda_priv.h"
-#include "libgedaguile_priv.h"
+#include "liblepton_priv.h"
+#include "libleptonguile_priv.h"
 
 SCM_SYMBOL (lambda_sym, "lambda");
 SCM_SYMBOL (args_sym, "args");
 
 static SCM marshal_proc;
 
-/*! \brief Unpack and call a C closure 
- * 
+/*! \brief Unpack and call a C closure
+ *
  * Unpack the C function pointer and user data pointer from a C
  * closure \a smob, and then make a function call of the form:
  *
@@ -99,7 +99,7 @@ edascm_c_make_closure (SCM (*func)(SCM, gpointer), gpointer user_data)
                      scm_list_3 (marshal_proc, args_sym, smob));
   result = g_scm_eval_protected (expr, scm_current_module ());
   g_warn_if_fail (scm_is_true (scm_procedure_p (result)));
-  return result; 
+  return result;
 }
 
 /*!
