@@ -45,14 +45,11 @@ edascm_init_impl (void *data)
                  SCM_UNDEFINED);
   edascm_init_smob ();
   edascm_init_toplevel ();
-  edascm_init_object ();
   edascm_init_component ();
   edascm_init_page ();
   edascm_init_attrib ();
-  edascm_init_os ();
   edascm_init_config ();
   edascm_init_closure ();
-  edascm_init_deprecated ();
   edascm_init_rc ();
   return NULL;
 }
