@@ -1,7 +1,7 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2010-2013, 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2010-2016 Lepton EDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2010-2016 gEDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,33 +25,35 @@
  * In order for Scheme code to be able to manipulate liblepton data
  * structures, it is convenient for it to be able to get handles to
  * several of the different C structures that liblepton uses, in
- * particular #TOPLEVEL, #PAGE and #OBJECT.
+ * particular #LeptonToplevel, #LeptonPage and #LeptonObject.
  *
  * A particular issue is that, in principle, Guile can stash a
  * variable somewhere and only try and access it much later, possibly
  * after the underlying C structure has already been freed.
  *
- * In order to avoid this situation causing a segmentation fault, weak
- * references are used. In the case of #PAGE and #TOPLEVEL handles,
- * the usage is quite straightforward; Scheme code can never create or
- * destroy a #TOPLEVEL; and although a #PAGE can be created by Scheme
- * code, it must explicitly be destroyed if the Scheme code doesn't
- * want the #PAGE to hang around after it returns.
+ * In order to avoid this situation causing a segmentation fault,
+ * weak references are used. In the case of #LeptonPage and
+ * #LeptonToplevel handles, the usage is quite straightforward;
+ * Scheme code can never create or destroy a #LeptonToplevel; and
+ * although a #LeptonPage can be created by Scheme code, it must
+ * explicitly be destroyed if the Scheme code doesn't want the
+ * #LeptonPage to hang around after it returns.
  *
- * #OBJECT handles are a more complex case. It's possible that Scheme
- * code may legitimately want to create an #OBJECT and do something
- * with it (or, similarly, pull an #OBJECT out of a #PAGE), without
- * needing to carefully keep track of the #OBJECT to avoid dropping it
- * on the floor. In that case, users should be able to rely on the
+ * #LeptonObject handles are a more complex case. It's possible
+ * that Scheme code may legitimately want to create an
+ * #LeptonObject and do something with it (or, similarly, pull an
+ * #LeptonObject out of a #LeptonPage), without needing to carefully
+ * keep track of the #LeptonObject to avoid dropping it on the
+ * floor. In that case, users should be able to rely on the
  * garbage collector.
  *
- * For that reason, an #OBJECT is marked to be destroyed by
+ * For that reason, an #LeptonObject is marked to be destroyed by
  * garbage-collection in two cases:
  *
  * -# If they have been created by Scheme code, but not yet added to a
- *    PAGE.
- * -# If they have been removed from a #PAGE by Scheme code, but not
- *    yet re-added to a #PAGE.
+ *    LeptonPage.
+ * -# If they have been removed from a #LeptonPage by Scheme code, but not
+ *    yet re-added to a #LeptonPage.
  *
  * The cost of allocating a Scheme value is quite high.  While a C
  * structure is not garbage-collectable, its Scheme value is protected
@@ -68,8 +70,8 @@
 
 #include <config.h>
 
-#include "libgeda_priv.h"
-#include "libgedaguile_priv.h"
+#include "liblepton_priv.h"
+#include "libleptonguile_priv.h"
 
 scm_t_bits geda_smob_tag;
 
@@ -258,18 +260,19 @@ smob_free (SCM smob)
   /* Otherwise, clear the weak reference */
   switch (EDASCM_SMOB_TYPE (smob)) {
   case GEDA_SMOB_TOPLEVEL:
-    s_toplevel_weak_unref ((TOPLEVEL *) data, smob_weakref_notify,
+    s_toplevel_weak_unref ((LeptonToplevel *) data, smob_weakref_notify,
                            unpack_as_pointer (smob));
     break;
   case GEDA_SMOB_PAGE:
-    s_page_weak_unref ((PAGE *) data, smob_weakref_notify,
+    s_page_weak_unref ((LeptonPage *) data, smob_weakref_notify,
                        unpack_as_pointer (smob));
     break;
   case GEDA_SMOB_OBJECT:
-    /* See edascm_from_object() for an explanation of why OBJECT
-     * smobs store a TOPLEVEL in the second data word */
-    s_object_weak_unref ((OBJECT *) data, smob_weakref2_notify,
-                         unpack_as_pointer (smob));
+    /* See edascm_from_object() for an explanation of why LeptonObject
+     * smobs store a LeptonToplevel in the second data word */
+    lepton_object_weak_unref ((LeptonObject *) data,
+                              smob_weakref2_notify,
+                              unpack_as_pointer (smob));
     break;
   case GEDA_SMOB_CONFIG:
     g_object_unref (G_OBJECT (data));
@@ -284,21 +287,21 @@ smob_free (SCM smob)
   /* If the smob is marked as garbage-collectable, destroy its
    * contents.
    *
-   * Because PAGEs and TOPLEVELs should never be garbage collected,
+   * Because LeptonPages and LeptonToplevels should never be garbage collected,
    * emit critical warnings if the GC tries to free them.
    */
   if (EDASCM_SMOB_GCP (smob)) {
     switch (EDASCM_SMOB_TYPE (smob)) {
     case GEDA_SMOB_TOPLEVEL:
-      g_critical ("%s: Blocked garbage-collection of TOPLEVEL %p",
+      g_critical ("%s: Blocked garbage-collection of LeptonToplevel %p",
                  __FUNCTION__, data);
       break;
     case GEDA_SMOB_PAGE:
-      g_critical ("%s: Blocked garbage-collection of PAGE %p",
+      g_critical ("%s: Blocked garbage-collection of LeptonPage %p",
                  __FUNCTION__, data);
       break;
     case GEDA_SMOB_OBJECT:
-      s_delete_object ((OBJECT *) data);
+      lepton_object_delete ((LeptonObject *) data);
       break;
     case GEDA_SMOB_CONFIG:
       /* These are reference counted, so the structure will have
@@ -387,16 +390,16 @@ smob_equalp (SCM obj1, SCM obj2)
   }
 }
 
-/*! \brief Get the smob for a TOPLEVEL.
+/*! \brief Get the smob for a LeptonToplevel.
  * \ingroup guile_c_iface
  * \par Function Description
  * Create a new smob representing \a toplevel.
  *
- * \param toplevel #TOPLEVEL to create a smob for.
+ * \param toplevel #LeptonToplevel to create a smob for.
  * \return a smob representing \a toplevel.
  */
 SCM
-edascm_from_toplevel (TOPLEVEL *toplevel)
+edascm_from_toplevel (LeptonToplevel *toplevel)
 {
   SCM smob = smob_cache_lookup (toplevel);
 
@@ -421,11 +424,11 @@ edascm_from_toplevel (TOPLEVEL *toplevel)
  * \par Function Description
  * Create a new smob representing \a page.
  *
- * \param page #PAGE to create a smob for.
+ * \param page #LeptonPage to create a smob for.
  * \return a smob representing \a page.
  */
 SCM
-edascm_from_page (PAGE *page)
+edascm_from_page (LeptonPage *page)
 {
   SCM smob = smob_cache_lookup (page);
 
@@ -448,12 +451,12 @@ edascm_from_page (PAGE *page)
 /*! \brief Get a page from a smob.
  * \ingroup guile_c_iface
  * \par Function Description
- * Return the #PAGE represented by \a smob.
+ * Return the #LeptonPage represented by \a smob.
  *
- * \param [in] smob Guile value to retrieve #PAGE from.
- * \return the #PAGE represented by \a smob.
+ * \param [in] smob Guile value to retrieve #LeptonPage from.
+ * \return the #LeptonPage represented by \a smob.
  */
-PAGE *
+LeptonPage *
 edascm_to_page (SCM smob)
 {
   g_debug ("edascm_to_page()\n");
@@ -463,7 +466,7 @@ edascm_to_page (SCM smob)
 #endif
   EDASCM_ASSERT_SMOB_VALID (smob);
 
-  return (PAGE *) SCM_SMOB_DATA (smob);
+  return (LeptonPage *) SCM_SMOB_DATA (smob);
 }
 
 /*! \brief Get a smob for a schematic object.
@@ -480,17 +483,17 @@ edascm_to_page (SCM smob)
  *   edascm_c_set_gc (x, 1);
  * \endcode
  *
- * \note We currently have to bake a TOPLEVEL pointer into the smob,
+ * \note We currently have to bake a LeptonToplevel pointer into the smob,
  * so that if the object becomes garbage-collectable we can obtain a
- * TOPLEVEL to use for deleting the smob without accessing the
- * TOPLEVEL fluid and potentially causing a race condition (see bug
+ * LeptonToplevel to use for deleting the smob without accessing the
+ * LeptonToplevel fluid and potentially causing a race condition (see bug
  * 909358).
  *
- * \param object #OBJECT to create a smob for.
+ * \param object #LeptonObject to create a smob for.
  * \return a smob representing \a object.
  */
 SCM
-edascm_from_object (OBJECT *object)
+edascm_from_object (LeptonObject *object)
 {
   SCM smob = smob_cache_lookup (object);
 
@@ -498,14 +501,15 @@ edascm_from_object (OBJECT *object)
     return smob;
   }
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
+  LeptonToplevel *toplevel = edascm_c_current_toplevel ();
 
   SCM_NEWSMOB2 (smob, geda_smob_tag, object, toplevel);
   SCM_SET_SMOB_FLAGS (smob, GEDA_SMOB_OBJECT);
 
   /* Set weak references */
-  s_object_weak_ref (object, smob_weakref2_notify,
-                     unpack_as_pointer (smob));
+  lepton_object_weak_ref (object,
+                          smob_weakref2_notify,
+                          unpack_as_pointer (smob));
 
   smob_cache_add (object, smob);
 
@@ -515,12 +519,12 @@ edascm_from_object (OBJECT *object)
 /*! \brief Get a schematic object from a smob.
  * \ingroup guile_c_iface
  * \par Function Description
- * Return the #OBJECT represented by \a smob.
+ * Return the #LeptonObject represented by \a smob.
  *
- * \param [in] smob Guile value to retrieve #OBJECT from.
- * \return the #OBJECT represented by \a smob.
+ * \param [in] smob Guile value to retrieve #LeptonObject from.
+ * \return the #LeptonObject represented by \a smob.
  */
-OBJECT *
+LeptonObject *
 edascm_to_object (SCM smob)
 {
   g_debug ("edascm_to_object()\n");
@@ -530,7 +534,7 @@ edascm_to_object (SCM smob)
 #endif
   EDASCM_ASSERT_SMOB_VALID (smob);
 
-  return (OBJECT *) SCM_SMOB_DATA (smob);
+  return (LeptonObject *) SCM_SMOB_DATA (smob);
 }
 
 /*! \brief Get a smob for a configuration context.
@@ -624,15 +628,15 @@ edascm_c_set_gc (SCM smob, int gc)
   EDASCM_SMOB_SET_GC (smob, gc);
 }
 
-/*! \brief Test whether a smob is a #OBJECT instance
+/*! \brief Test whether a smob is a #LeptonObject instance
  * \ingroup guile_c_iface
  * \par Function Description
- * If \a smob is a #OBJECT instance, returns non-zero. Otherwise,
- * returns zero.
+ * If \a smob is a #LeptonObject instance, returns
+ * non-zero. Otherwise, returns zero.
  *
  * \param [in] smob Guile value to test.
  *
- * \return non-zero iff \a smob is a #OBJECT instance.
+ * \return non-zero iff \a smob is a #LeptonObject instance.
  */
 int
 edascm_is_object (SCM smob)
@@ -640,15 +644,15 @@ edascm_is_object (SCM smob)
   return EDASCM_OBJECTP (smob);
 }
 
-/*! \brief Test whether a smob is a #PAGE instance
+/*! \brief Test whether a smob is a #LeptonPage instance
  * \ingroup guile_c_iface
  * \par Function Description
- * If \a smob is a #PAGE instance, returns non-zero. Otherwise,
+ * If \a smob is a #LeptonPage instance, returns non-zero. Otherwise,
  * returns zero.
  *
  * \param [in] smob Guile value to test.
  *
- * \return non-zero iff \a smob is a #PAGE instance.
+ * \return non-zero iff \a smob is a #LeptonPage instance.
  */
 int
 edascm_is_page (SCM smob)
@@ -671,79 +675,6 @@ edascm_is_config (SCM smob)
   return EDASCM_CONFIGP (smob);
 }
 
-/*! \brief Test whether a smob is a #PAGE instance.
- * \par Function Description
- * If \a page_smob is a #PAGE instance, returns \b SCM_BOOL_T;
- * otherwise returns \b SCM_BOOL_F.
- *
- * \note Scheme API: Implements the %page? procedure in the
- * (lepton core smob) module.
- *
- * \param [in] page_smob Guile value to test.
- *
- * \return SCM_BOOL_T iff \a page_smob is a #PAGE instance.
- */
-SCM_DEFINE (page_p, "%page?", 1, 0, 0,
-            (SCM page_smob),
-            "Test whether the value is a Lepton EDA PAGE instance.")
-{
-  return (EDASCM_PAGEP (page_smob) ? SCM_BOOL_T : SCM_BOOL_F);
-}
-
-/*! \brief Test whether a smob is an #OBJECT instance.
- * \par Function Description
- * If \a object_smob is an #OBJECT instance, returns \b SCM_BOOL_T;
- * otherwise returns \b SCM_BOOL_F.
- *
- * \note Scheme API: Implements the %object? procedure in the
- * (lepton core smob) module.
- *
- * \param [in] object_smob Guile value to test.
- *
- * \return SCM_BOOL_T iff \a object_smob is an #OBJECT instance.
- */
-SCM_DEFINE (object_p, "%object?", 1, 0, 0,
-            (SCM object_smob),
-            "Test whether the value is a Lepton EDA OBJECT instance.")
-{
-  return (EDASCM_OBJECTP (object_smob) ? SCM_BOOL_T : SCM_BOOL_F);
-}
-
-/*! \brief Test whether a smob is an #EdaConfig instance.
- * \par Function Description
- * If \a config_smob is a configuration context, returns \b
- * SCM_BOOL_T; otherwise returns \b SCM_BOOL_F.
- *
- * \note Scheme API: Implements the %config? procedure in the
- * (lepton core smob) module.
- *
- * \param [in] config_smob Guile value to test.
- *
- * \return SCM_BOOL_T iff \a config_smob is an #EdaConfig instance.
- */
-SCM_DEFINE (config_p, "%config?", 1, 0, 0,
-            (SCM config_smob),
-            "Test whether the value is a Lepton EDA configuration context.")
-{
-  return (EDASCM_CONFIGP (config_smob) ? SCM_BOOL_T : SCM_BOOL_F);
-}
-
-/*!
- * \brief Create the (lepton core smob) Scheme module.
- * \par Function Description
- * Defines procedures in the (lepton core smob) module. The module can
- * be accessed using (use-modules (lepton core smob)).
- */
-static void
-init_module_lepton_core_smob (void *unused)
-{
-  /* Register the functions. */
-  #include "scheme_smob.x"
-
-  /* Add them to the module's public definitions. */ 
-  scm_c_export (s_page_p, s_object_p, s_config_p, NULL);
-}
-
 /*!
  * \brief Initialise the basic Lepton EDA smob types.
  * \par Function Description
@@ -764,9 +695,4 @@ edascm_init_smob ()
   scm_set_smob_free (geda_smob_tag, smob_free);
   scm_set_smob_print (geda_smob_tag, smob_print);
   scm_set_smob_equalp (geda_smob_tag, smob_equalp);
-
-  /* Define the (lepton core smob) module */
-  scm_c_define_module ("lepton core smob",
-                       (void (*)(void*)) init_module_lepton_core_smob,
-                       NULL);
 }
