@@ -72,6 +72,21 @@
 int tab_in_chars = 8;
 
 
+/*! \brief Free memory associated with the text
+ *
+ *  \param [in] text The text to be freed.
+ */
+void
+lepton_text_free (LeptonText *text)
+{
+  if (text != NULL) {
+    g_free (text->string);
+    g_free (text->disp_string);
+    g_free (text);
+  }
+}
+
+
 /*! \brief calculate and return the boundaries of a text object
  *
  *  The responsibility of calculating the bounds of any object should probably
@@ -89,14 +104,14 @@ lepton_text_object_calculate_bounds (const LeptonObject *object,
                                      gboolean include_hidden,
                                      LeptonBounds *bounds)
 {
-  if (! (lepton_object_is_visible (object) || include_hidden))
+  g_return_val_if_fail (lepton_object_is_text (object), FALSE);
+  g_return_val_if_fail (object->text != NULL, FALSE);
+
+  if (! (lepton_text_object_is_visible (object) || include_hidden))
     return FALSE;
 
   lepton_bounds_init (bounds);
 
-  g_return_val_if_fail (lepton_object_is_text (object), FALSE);
-  g_return_val_if_fail (object->text != NULL, FALSE);
-
   double t, l, r, b;
   gboolean result = eda_renderer_get_text_user_bounds (object,
                                                        include_hidden,
@@ -244,6 +259,20 @@ lepton_text_object_get_y (const LeptonObject *object)
   return object->text->y;
 }
 
+/*! \brief Get the \a show field of a text object.
+ *
+ *  \param [in] object The text object.
+ *  \return The value of the field \a show.
+ */
+gint
+lepton_text_object_get_show (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), VISIBLE);
+  g_return_val_if_fail (object->text != NULL, VISIBLE);
+
+  return object->text->show;
+}
+
 /*! \brief Set the text alignment
  *
  *  In case of an invalid text alignment, the property remains unchanged.
@@ -334,12 +363,28 @@ lepton_text_object_set_y (LeptonObject *object,
   object->text->y = y;
 }
 
+
+/*! \brief Set \a show field of a text object.
+ *
+ *  \param object The #LeptonObject structure to be modified.
+ *  \param show The new value of the field \a show.
+ */
+void
+lepton_text_object_set_show (LeptonObject *object,
+                             gint show)
+{
+  g_return_if_fail (lepton_object_is_text (object));
+  g_return_if_fail (object->text != NULL);
+
+  object->text->show = show;
+}
+
 /*! \brief update the visible part of a string
  *  \par Function Description
  *  If a string is an attribute, then it is possible to hide
  *  the name or the value part of the attribute string.
  *  This functions updates the text->disp_string according
- *  to the object->show_name_value settings
+ *  to the object->text->show settings
  *
  *  \param [in] object  The LeptonObject to update
  */
@@ -353,7 +398,8 @@ update_disp_string (LeptonObject *object)
   g_free (text->disp_string);
 
   if (o_attrib_get_name_value (object, &name, &value)) {
-    switch (object->show_name_value) {
+    switch (lepton_text_object_get_show (object))
+    {
       case (SHOW_NAME_VALUE):
         text->disp_string = g_strdup (text->string);
         break;
@@ -442,8 +488,8 @@ lepton_text_object_new (gint color,
   new_node->text = text;
 
   lepton_object_set_color (new_node, color);
-  lepton_object_set_visibility (new_node, visibility);
-  new_node->show_name_value = show_name_value;
+  lepton_text_object_set_visibility (new_node, visibility);
+  lepton_text_object_set_show (new_node, show_name_value);
 
   update_disp_string (new_node);
 
@@ -464,11 +510,11 @@ lepton_text_object_new (gint color,
  *  \return The object list, or NULL on error.
  */
 LeptonObject*
-o_text_read (const char *first_line,
-             TextBuffer *tb,
-             unsigned int release_ver,
-             unsigned int fileformat_ver,
-             GError **err)
+lepton_text_object_read (const char *first_line,
+                         TextBuffer *tb,
+                         unsigned int release_ver,
+                         unsigned int fileformat_ver,
+                         GError **err)
 {
   LeptonObject *new_obj;
   char type;
@@ -633,8 +679,8 @@ lepton_text_object_to_buffer (const LeptonObject *object)
                           lepton_text_object_get_y (object),
                           lepton_object_get_color (object),
                           lepton_text_object_get_size (object),
-                          lepton_object_get_visibility (object),
-                          object->show_name_value,
+                          lepton_text_object_get_visibility (object),
+                          lepton_text_object_get_show (object),
                           lepton_text_object_get_angle (object),
                           lepton_text_object_get_alignment (object),
                           o_text_num_lines (string),
@@ -649,8 +695,11 @@ lepton_text_object_to_buffer (const LeptonObject *object)
  *  \param o_current The text object to update
  */
 void
-o_text_recreate (LeptonObject *o_current)
+lepton_text_object_recreate (LeptonObject *o_current)
 {
+  g_return_if_fail (lepton_object_is_text (o_current));
+  g_return_if_fail (o_current->text != NULL);
+
   lepton_object_emit_pre_change_notify (o_current);
   update_disp_string (o_current);
   lepton_object_emit_change_notify (o_current);
@@ -672,8 +721,8 @@ lepton_text_object_translate (LeptonObject *object,
   g_return_if_fail (lepton_object_is_text (object));
   g_return_if_fail (object->text != NULL);
 
-  object->text->x = object->text->x + dx;
-  object->text->y = object->text->y + dy;
+  lepton_text_object_set_x (object, lepton_text_object_get_x (object) + dx);
+  lepton_text_object_set_y (object, lepton_text_object_get_y (object) + dy);
 }
 
 /*! \brief create a copy of a text object
@@ -692,14 +741,14 @@ lepton_text_object_copy (const LeptonObject *object)
   g_return_val_if_fail (object->text != NULL, NULL);
 
   new_obj = lepton_text_object_new (lepton_object_get_color (object),
-                                    object->text->x,
-                                    object->text->y,
-                                    object->text->alignment,
-                                    object->text->angle,
-                                    object->text->string,
-                                    object->text->size,
-                                    lepton_object_get_visibility (object),
-                                    object->show_name_value);
+                                    lepton_text_object_get_x (object),
+                                    lepton_text_object_get_y (object),
+                                    lepton_text_object_get_alignment (object),
+                                    lepton_text_object_get_angle (object),
+                                    lepton_text_object_get_string (object),
+                                    lepton_text_object_get_size (object),
+                                    lepton_text_object_get_visibility (object),
+                                    lepton_text_object_get_show (object));
 
   return new_obj;
 }
@@ -723,24 +772,30 @@ lepton_text_object_rotate (int world_centerx,
 {
   int x, y;
   int newx, newy;
+  int current_angle;
 
   g_return_if_fail (lepton_object_is_text (object));
   g_return_if_fail (object->text != NULL);
   g_return_if_fail (lepton_angle_is_ortho (angle));
 
-  object->text->angle = lepton_angle_normalize (object->text->angle + angle);
+  current_angle = lepton_text_object_get_angle (object);
 
-  x = object->text->x + (-world_centerx);
-  y = object->text->y + (-world_centery);
+  lepton_text_object_set_angle (object,
+                                lepton_angle_normalize (current_angle + angle));
+
+  x = lepton_text_object_get_x (object) + (-world_centerx);
+  y = lepton_text_object_get_y (object) + (-world_centery);
 
   lepton_point_rotate_90 (x, y, angle, &newx, &newy);
 
   x = newx + (world_centerx);
   y = newy + (world_centery);
 
-  lepton_text_object_translate (object, x-object->text->x, y-object->text->y);
+  lepton_text_object_translate (object,
+                                x - lepton_text_object_get_x (object),
+                                y - lepton_text_object_get_y (object));
 
-  o_text_recreate (object);
+  lepton_text_object_recreate (object);
 }
 
 
@@ -764,65 +819,65 @@ lepton_text_object_mirror (int world_centerx,
   g_return_if_fail (lepton_object_is_text (object));
   g_return_if_fail (object->text != NULL);
 
-  origx = object->text->x;
-  origy = object->text->y;
+  origx = lepton_text_object_get_x (object);
+  origy = lepton_text_object_get_y (object);
 
   x = origx + (-world_centerx);
   y = origy + (-world_centery);
 
-  if ((object->text->angle%180)==0) {
-    switch(object->text->alignment) {
+  if ((lepton_text_object_get_angle (object) % 180) == 0) {
+    switch (lepton_text_object_get_alignment (object)) {
       case(LOWER_LEFT):
-        object->text->alignment=LOWER_RIGHT;
+        lepton_text_object_set_alignment (object, LOWER_RIGHT);
         break;
 
       case(MIDDLE_LEFT):
-        object->text->alignment=MIDDLE_RIGHT;
+        lepton_text_object_set_alignment (object, MIDDLE_RIGHT);
         break;
 
       case(UPPER_LEFT):
-        object->text->alignment=UPPER_RIGHT;
+        lepton_text_object_set_alignment (object, UPPER_RIGHT);
         break;
 
       case(LOWER_RIGHT):
-        object->text->alignment=LOWER_LEFT;
+        lepton_text_object_set_alignment (object, LOWER_LEFT);
         break;
 
       case(MIDDLE_RIGHT):
-        object->text->alignment=MIDDLE_LEFT;
+        lepton_text_object_set_alignment (object, MIDDLE_LEFT);
         break;
 
       case(UPPER_RIGHT):
-        object->text->alignment=UPPER_LEFT;
+        lepton_text_object_set_alignment (object, UPPER_LEFT);
         break;
 
       default:
         break;
     }
   } else {
-    switch(object->text->alignment) {
+    switch(lepton_text_object_get_alignment (object)) {
       case(LOWER_LEFT):
-      object->text->alignment=UPPER_LEFT;
+      lepton_text_object_set_alignment (object, UPPER_LEFT);
       break;
 
       case(UPPER_LEFT):
-      object->text->alignment=LOWER_LEFT;
+      lepton_text_object_set_alignment (object, LOWER_LEFT);
       break;
 
       case(LOWER_RIGHT):
-      object->text->alignment=UPPER_RIGHT;
+      lepton_text_object_set_alignment (object, UPPER_RIGHT);
       break;
 
       case(UPPER_RIGHT):
-      object->text->alignment=LOWER_RIGHT;
+      lepton_text_object_set_alignment (object, LOWER_RIGHT);
       break;
 
       case(LOWER_MIDDLE):
-      object->text->alignment=UPPER_MIDDLE;
+      lepton_text_object_set_alignment (object, UPPER_MIDDLE);
       break;
 
       case(UPPER_MIDDLE):
-      object->text->alignment=LOWER_MIDDLE;
+      lepton_text_object_set_alignment (object, LOWER_MIDDLE);
       break;
 
       default:
@@ -830,10 +885,10 @@ lepton_text_object_mirror (int world_centerx,
     }
   }
 
-  object->text->x = -x + (world_centerx);
-  object->text->y =  y + (world_centery);
+  lepton_text_object_set_x (object, -x + (world_centerx));
+  lepton_text_object_set_y (object,  y + (world_centery));
 
-  o_text_recreate (object);
+  lepton_text_object_recreate (object);
 }
 
 /*! \brief Calculates the distance between the given point and the closest
@@ -862,6 +917,7 @@ lepton_text_object_shortest_distance (LeptonObject *object,
   int left, top, right, bottom;
   double dx, dy;
 
+  g_return_val_if_fail (lepton_object_is_text (object), G_MAXDOUBLE);
   g_return_val_if_fail (object->text != NULL, G_MAXDOUBLE);
 
   if (!lepton_object_calculate_visible_bounds (object,
@@ -889,8 +945,8 @@ lepton_text_object_shortest_distance (LeptonObject *object,
  *  \param [in]  new_string            The new value.
  */
 void
-o_text_set_string (LeptonObject *obj,
-                   const gchar *new_string)
+lepton_text_object_set_string (LeptonObject *obj,
+                               const gchar *new_string)
 {
   g_return_if_fail (lepton_object_is_text (obj));
   g_return_if_fail (obj->text != NULL);
@@ -899,5 +955,123 @@ o_text_set_string (LeptonObject *obj,
   g_free (obj->text->string);
   obj->text->string = g_strdup (new_string);
 
-  o_text_recreate (obj);
+  lepton_text_object_recreate (obj);
+}
+
+
+/*! \brief Query visibility of a text object.
+ *  \par Function Description
+ *  Attribute getter for the visible field within the object.
+ *
+ *  \param object The text #LeptonObject structure to be queried.
+ *  \return TRUE when VISIBLE, FALSE otherwise.
+ */
+gboolean
+lepton_text_object_is_visible (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), FALSE);
+  g_return_val_if_fail (object->text != NULL, FALSE);
+
+  return object->text->visibility == VISIBLE;
+}
+
+/*! \brief Get the visibility of a text object.
+ *
+ *  \param [in] object The text #LeptonObject structure to be queried.
+ *  \return VISIBLE or INVISIBLE
+ */
+gint
+lepton_text_object_get_visibility (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), VISIBLE);
+  g_return_val_if_fail (object->text != NULL, VISIBLE);
+
+  return object->text->visibility;
+}
+
+/*! \brief Set visibility of a text object.
+ *
+ *  \param object     The text #LeptonObject structure to be modified.
+ *  \param visibility If the object should be visible.
+ */
+void
+lepton_text_object_set_visibility (LeptonObject *object,
+                                   int visibility)
+{
+  g_return_if_fail (lepton_object_is_text (object));
+  g_return_if_fail (object->text != NULL);
+
+  object->text->visibility = visibility;
+}
+
+
+const char*
+lepton_text_object_alignment_to_string (gint alignment)
+{
+  const char *result = NULL;
+
+  switch (alignment)
+  {
+  case LOWER_LEFT: result = "lower-left"; break;
+  case MIDDLE_LEFT: result = "middle-left"; break;
+  case UPPER_LEFT: result = "upper-left"; break;
+  case LOWER_MIDDLE: result = "lower-center"; break;
+  case MIDDLE_MIDDLE: result = "middle-center"; break;
+  case UPPER_MIDDLE: result = "upper-center"; break;
+  case LOWER_RIGHT: result = "lower-right"; break;
+  case MIDDLE_RIGHT: result = "middle-right"; break;
+  case UPPER_RIGHT: result = "upper-right"; break;
+  default: break;
+  }
+
+  return result;
+}
+
+
+gint
+lepton_text_object_alignment_from_string (char *s)
+{
+  gint result = LOWER_LEFT;
+
+  if      (strcmp (s, "lower-left") == 0) { result = LOWER_LEFT; }
+  else if (strcmp (s, "middle-left") == 0) { result = MIDDLE_LEFT; }
+  else if (strcmp (s, "upper-left") == 0) { result = UPPER_LEFT; }
+  else if (strcmp (s, "lower-center") == 0) { result = LOWER_MIDDLE; }
+  else if (strcmp (s, "middle-center") == 0) { result = MIDDLE_MIDDLE; }
+  else if (strcmp (s, "upper-center") == 0) { result = UPPER_MIDDLE; }
+  else if (strcmp (s, "lower-right") == 0) { result = LOWER_RIGHT; }
+  else if (strcmp (s, "middle-right") == 0) { result = MIDDLE_RIGHT; }
+  else if (strcmp (s, "upper-right") == 0) { result = UPPER_RIGHT; }
+
+  return result;
+}
+
+
+const char*
+lepton_text_object_show_to_string (gint show)
+{
+  const char *result = NULL;
+
+  switch (show)
+  {
+  case SHOW_NAME: result = "name"; break;
+  case SHOW_VALUE: result = "value"; break;
+  case SHOW_NAME_VALUE: result = "both"; break;
+  default: break;
+  }
+
+  return result;
+}
+
+
+gint
+lepton_text_object_show_from_string (char *s)
+{
+  gint result = SHOW_NAME;
+
+  if      (strcmp (s, "name") == 0) { result = SHOW_NAME; }
+  else if (strcmp (s, "value") == 0) { result = SHOW_VALUE; }
+  else if (strcmp (s, "both") == 0) { result = SHOW_NAME_VALUE; }
+
+  return result;
 }
