@@ -1,7 +1,7 @@
 /* Lepton EDA attribute editor
  * Copyright (C) 2003-2010 Stuart D. Brorson.
  * Copyright (C) 2005-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@ gboolean attrib_really_quit(void)
   }
 
 
-  if (sheet_head->CHANGED == TRUE) {
+  if (s_sheet_data_changed (sheet_head)) {
     x_dialog_unsaved_data();
   } else {
     attrib_quit(0);
