@@ -413,9 +413,9 @@ void s_table_add_toplevel_comp_items_to_comp_table (const GList *obj_list) {
             attrib_text = g_strdup (lepton_text_object_get_string (a_current));
             attrib_name = u_basic_breakup_string(attrib_text, '=', 0);
             attrib_value = s_misc_remaining_string(attrib_text, '=', 1);
-            old_visibility = lepton_object_is_visible (a_current)
+            old_visibility = lepton_text_object_is_visible (a_current)
               ? VISIBLE : INVISIBLE;
-            old_show_name_value = a_current->show_name_value;
+            old_show_name_value = lepton_text_object_get_show (a_current);
 
             /* Don't include "refdes" or "slot" because they form the row name. */
             /* Also don't include "net" per bug found by Steve W.  4.3.2007 -- SDB */
@@ -504,7 +504,7 @@ void s_table_add_toplevel_net_items_to_net_table(LeptonObject *start_obj) {
         if (lepton_object_is_text (a_current->object)
             && a_current->object->text != NULL) {  /* found an attribute */
           /* may need to check more thoroughly here. . . . */
-          attrib_text = g_strdup(a_current->object->text->string);
+          attrib_text = g_strdup (lepton_text_object_get_string (a_current->object));
           attrib_name = u_basic_breakup_string(attrib_text, '=', 0);
           attrib_value = s_misc_remaining_string(attrib_text, '=', 1);
           if (strcmp(attrib_name, "netname") != 0) {
