@@ -1,7 +1,7 @@
 /* Lepton EDA attribute editor
  * Copyright (C) 2003-2010 Stuart D. Brorson.
  * Copyright (C) 2003-2014 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 
 /*------------------------------------------------------------------*/
 /*! \file
- *  \brief Functions to manipulate the TOPLEVEL struct.
+ *  \brief Functions to manipulate the LeptonToplevel struct.
  *
- * This file holds functions involved in manipulating the TOPLEVEL data
- * structure.  TOPLEVEL is the data structure inherited from gEDA's
+ * This file holds functions involved in manipulating the LeptonToplevel data
+ * structure.  LeptonToplevel is the data structure inherited from gEDA's
  * other programs, and holds all info about a project in a form
  * native to gEDA.
  */
@@ -41,7 +41,7 @@
  * Gattrib specific includes
  *------------------------------------------------------------------*/
 #include <liblepton/liblepton.h>
-#include <liblepton/libgedaguile.h>
+#include <liblepton/libleptonguile.h>
 #include "../include/struct.h"     /* typdef and struct declarations */
 #include "../include/prototype.h"  /* function prototypes */
 #include "../include/globals.h"
@@ -56,18 +56,20 @@
  * Reads in a schematic page & calls f_open, which fills out the
  * toplevel structure.
  *
- *  \param toplevel TOPLEVEL structure
+ *  \param toplevel LeptonToplevel structure
  *  \param filename file to be opened
  *  \returns 1 on success, 0 on failure
  */
-int s_toplevel_read_page(TOPLEVEL *toplevel, char *filename)
+int
+s_toplevel_read_page (LeptonToplevel *toplevel,
+                      char *filename)
 {
   int file_return_code;
   GError *err = NULL;
-    
+
   /* Set the new filename */
   s_page_set_filename (toplevel->page_current, filename);
-  
+
   /* read in and fill out toplevel using f_open and its callees */
   file_return_code = f_open (toplevel, toplevel->page_current, filename, &err);
 
@@ -83,34 +85,33 @@ int s_toplevel_read_page(TOPLEVEL *toplevel, char *filename)
 
 /*! \brief Verify the entire design
  *
- * This function loops through all components in the
- * design looking for components which are placeholders.
+ * This function loops through all objects in the design looking
+ * for missing components, that is, those components for which no
+ * corresponding symbol files was found.
  *
- *  Placeholders are inserted into the object list when
- *  no symbol file is found.  If this function finds a
- *  placeholder, it warns the user.
- *
- *  \param toplevel pointer to the toplevel object to be verified
+ * \param toplevel The #LeptonToplevel object to be verified.
  */
-void s_toplevel_verify_design (TOPLEVEL *toplevel)
+void s_toplevel_verify_design (LeptonToplevel *toplevel)
 {
   GList *p_iter;
   const GList *o_iter;
 
   int missing_sym_flag = 0;
 
-  for (p_iter = geda_list_get_glist (toplevel->pages);
+  for (p_iter = lepton_list_get_glist (toplevel->pages);
        p_iter != NULL;
        p_iter = g_list_next (p_iter)) {
-    PAGE *p_current = (PAGE*) p_iter->data;
+    LeptonPage *p_current = (LeptonPage*) p_iter->data;
 
     for (o_iter = s_page_objects (p_current);
          o_iter != NULL;
          o_iter = g_list_next (o_iter)) {
-      OBJECT *o_current = (OBJECT*) o_iter->data;
+      LeptonObject *o_current = (LeptonObject*) o_iter->data;
 
       /* --- look for object, and verify that it has a symbol file attached. ---- */
-      if (o_current->type == OBJ_PLACEHOLDER) {
+      if (lepton_object_is_component (o_current) &&
+          lepton_component_object_get_missing (o_current))
+      {
         missing_sym_flag = 1;  /* flag to signal that problem exists.  */
       }
     }
@@ -122,24 +123,25 @@ void s_toplevel_verify_design (TOPLEVEL *toplevel)
 }
 
 
-/*! \brief Saves all the pages of a TOPLEVEL object.
+/*! \brief Saves all the pages of a LeptonToplevel object.
  *  \par Function Description
  *  Saves all the pages in the <B>toplevel</B> parameter.
  *
- *  \param [in] toplevel  The TOPLEVEL to save pages from.
+ *  \param [in] toplevel  The LeptonToplevel to save pages from.
  *  \return The number of failed tries to save a page.
  */
-gint s_page_save_all (TOPLEVEL *toplevel)
+gint
+s_page_save_all (LeptonToplevel *toplevel)
 {
   const GList *iter;
-  PAGE *p_current;
+  LeptonPage *p_current;
   gint status = 0;
 
-  for ( iter = geda_list_get_glist( toplevel->pages );
+  for ( iter = lepton_list_get_glist( toplevel->pages );
         iter != NULL;
         iter = g_list_next( iter ) ) {
 
-    p_current = (PAGE *)iter->data;
+    p_current = (LeptonPage *)iter->data;
 
     if (f_save (p_current, s_page_get_filename (p_current), NULL)) {
       g_message (_("Saved [%1$s]"),
@@ -161,7 +163,7 @@ gint s_page_save_all (TOPLEVEL *toplevel)
 
 
 /*------------------------------------------------------------------*/
-/*! \brief Copy data from gtksheet into TOPLEVEL struct
+/*! \brief Copy data from gtksheet into LeptonToplevel struct
  *
  * Called when the user invokes "save".  It first
  * places all data from gtksheet into SHEET_DATA.  Then it
@@ -171,11 +173,11 @@ void
 s_toplevel_save_sheet ()
 {
   GList *iter;
-  PAGE *p_current;
+  LeptonPage *p_current;
 
   g_debug ("==== Enter s_toplevel_gtksheet_to_toplevel()\n");
 
-  TOPLEVEL *toplevel = x_window_get_toplevel ();
+  LeptonToplevel *toplevel = x_window_get_toplevel ();
 
   g_return_if_fail (toplevel != NULL);
 
@@ -184,11 +186,11 @@ s_toplevel_save_sheet ()
            "Done writing stuff from gtksheet into SHEET_DATA.\n");
 
   /* must iterate over all pages in design */
-  for ( iter = geda_list_get_glist( toplevel->pages );
+  for ( iter = lepton_list_get_glist( toplevel->pages );
         iter != NULL;
         iter = g_list_next( iter ) ) {
 
-    p_current = (PAGE *)iter->data;
+    p_current = (LeptonPage *)iter->data;
     /* only traverse pages which are toplevel */
     if (p_current->page_control == 0) {
       s_toplevel_sheetdata_to_toplevel (toplevel, p_current);    /* adds all objects from page */
@@ -200,7 +202,7 @@ s_toplevel_save_sheet ()
 
   /* Save all pages in design. */
   s_page_save_all (toplevel);
-  sheet_head->CHANGED = FALSE;
+  s_sheet_data_set_changed (sheet_head, FALSE);
 
   return;
 }
@@ -236,28 +238,28 @@ void s_toplevel_add_new_attrib(gchar *new_attrib_name) {
   switch (cur_page) {
   case 0:  /* component attribute  */
 
-    /*  Eventually, I want to just resize the table to accomodate the 
+    /*  Eventually, I want to just resize the table to accomodate the
      *  new attrib.  However, that is difficult.  Therefore, I will just
      *  destroy the old table and recreate it for now. */
 
-    /* 
-    s_table_destroy(sheet_head->component_table, 
-		    sheet_head->comp_count, sheet_head->comp_attrib_count);
+    /*
+    s_table_destroy(sheet_head->component_table,
+                    sheet_head->comp_count, sheet_head->comp_attrib_count);
     */
     old_comp_attrib_count = sheet_head->comp_attrib_count;
     g_debug ("s_toplevel_add_new_attrib: "
              "Before adding new comp attrib: comp_attrib_count = %d\n",
              old_comp_attrib_count);
 
-    s_string_list_add_item(sheet_head->master_comp_attrib_list_head, 
-			   &(sheet_head->comp_attrib_count), 
-			   new_attrib_name);
+    s_string_list_add_item(sheet_head->master_comp_attrib_list_head,
+                           &(sheet_head->comp_attrib_count),
+                           new_attrib_name);
     s_string_list_sort_master_comp_attrib_list();
 
     /* Now, determine what index the new attrib ended up at
      * This is necessary to tell gtk_sheet_insert_columns
      * where the data should be shifted                    */
-    new_index = s_string_list_find_in_list(sheet_head->master_comp_attrib_list_head, 
+    new_index = s_string_list_find_in_list(sheet_head->master_comp_attrib_list_head,
                                            (char*)new_attrib_name);
 
     g_debug ("s_toplevel_add_new_attrib: "
@@ -265,23 +267,23 @@ void s_toplevel_add_new_attrib(gchar *new_attrib_name) {
             sheet_head->comp_attrib_count);
 
     /* Now create new table */
-    /*     sheet_head->component_table = s_table_new(sheet_head->comp_count, 
-					      sheet_head->comp_attrib_count);
+    /*     sheet_head->component_table = s_table_new(sheet_head->comp_count,
+                                              sheet_head->comp_attrib_count);
     */
 
     /* resize table to accomodate new attrib col */
-    sheet_head->component_table = 
-      s_table_resize(sheet_head->component_table, 
-		     sheet_head->comp_count, 
-		     old_comp_attrib_count, sheet_head->comp_attrib_count);
+    sheet_head->component_table =
+      s_table_resize(sheet_head->component_table,
+                     sheet_head->comp_count,
+                     old_comp_attrib_count, sheet_head->comp_attrib_count);
 
     g_debug ("s_toplevel_add_new_attrib: Resized component table.\n");
 
     /* Fill out new sheet with new stuff from gtksheet */
     gtk_sheet_insert_columns(GTK_SHEET(sheets[0]), new_index, 1);
-    x_gtksheet_add_col_labels(GTK_SHEET(sheets[0]), 
-			      sheet_head->comp_attrib_count, 
-			      sheet_head->master_comp_attrib_list_head);
+    x_gtksheet_add_col_labels(GTK_SHEET(sheets[0]),
+                              sheet_head->comp_attrib_count,
+                              sheet_head->master_comp_attrib_list_head);
 
     g_debug ("s_toplevel_add_new_attrib: Updated gtksheet.\n");
 
@@ -290,7 +292,7 @@ void s_toplevel_add_new_attrib(gchar *new_attrib_name) {
   case 1:  /* net attribute  */
     /* insert into net attribute list  */
     break;
-    
+
   case 2:  /* pin attribute  */
     /* insert into pin attribute list  */
     break;
@@ -341,7 +343,7 @@ void s_toplevel_delete_attrib_col() {
 
     /*  Get name (label) of the col to delete from the gtk sheet */
     attrib_name = g_strdup( gtk_sheet_column_button_get_label(sheet, mincol) );
-    
+
     if (attrib_name != NULL) {
       g_debug ("s_toplevel_delete_attrib_col: Attrib to delete = %s\n",
                attrib_name);
@@ -357,7 +359,7 @@ void s_toplevel_delete_attrib_col() {
                               mincol,
                               sheet_head->comp_count,
                               sheet_head->comp_attrib_count);
-    
+
     /* Destroy the current TABLE array:
     */
     s_table_destroy(sheet_head->component_table,
@@ -368,12 +370,12 @@ void s_toplevel_delete_attrib_col() {
             sheet_head->comp_attrib_count);
 
     s_string_list_delete_item(&(sheet_head->master_comp_attrib_list_head),
-			      &(sheet_head->comp_attrib_count), 
-			      attrib_name);
+                              &(sheet_head->comp_attrib_count),
+                              attrib_name);
     s_string_list_sort_master_comp_attrib_list(); /* this renumbers list also */
 
     g_free(attrib_name);
-    
+
     g_debug ("s_toplevel_delete_attrib_col: "
             "Just updated comp_attrib string list: new comp_attrib_count = %d\n",
             sheet_head->comp_attrib_count);
@@ -388,7 +390,7 @@ void s_toplevel_delete_attrib_col() {
   case 1:  /* net attribute  */
     /* insert into net attribute list  */
     break;
-    
+
   case 2:  /* pin attribute  */
     /* insert into pin attribute list  */
     break;
@@ -400,7 +402,8 @@ void s_toplevel_delete_attrib_col() {
   gtk_sheet_delete_columns (sheet, mincol, 1);
   g_debug ("s_toplevel_delete_attrib_col: Done deleting col in gtksheet.\n");
 
-  sheet_head->CHANGED = TRUE;  /* Set changed flag so user is prompted when exiting */
+  /* Set changed flag so user is prompted when exiting */
+  s_sheet_data_set_changed (sheet_head, TRUE);
 
   return;
 }
@@ -412,20 +415,21 @@ void s_toplevel_delete_attrib_col() {
 /*! \brief Copy SHEET_DATA content to TOP_LEVEL
  *
  * This function
- * loops through all objects on (PAGE page)->(OBJECT *start_obj).
- * It takes the updated SHEET_DATA->TABLE data and then updates the 
+ * loops through all objects on (LeptonPage page)->(LeptonObject *start_obj).
+ * It takes the updated SHEET_DATA->TABLE data and then updates the
  * objects with the new attribs & attrib values.
- * For each component, it updates the attached 
- * attrib values using the updated values held in the SHEET_DATA->TABLE 
+ * For each component, it updates the attached
+ * attrib values using the updated values held in the SHEET_DATA->TABLE
  * structure.  It does so in three steps:
  * -# First find and update component attribs.
  * -# Then find and update net attribs.
  * -# Finally find and update pin attribs.
- * \param toplevel TOPLEVEL structure
+ * \param toplevel LeptonToplevel structure
  * \param page schematic page to copy
  */
 void
-s_toplevel_sheetdata_to_toplevel (TOPLEVEL *toplevel, PAGE *page)
+s_toplevel_sheetdata_to_toplevel (LeptonToplevel *toplevel,
+                                  LeptonPage *page)
 {
   GList *copy_list;
   GList *o_iter, *prim_iter;
@@ -449,10 +453,11 @@ s_toplevel_sheetdata_to_toplevel (TOPLEVEL *toplevel, PAGE *page)
   for (o_iter = g_list_last (copy_list);
        o_iter != NULL;
        o_iter = g_list_previous (o_iter)) {
-    OBJECT *o_current = (OBJECT*) o_iter->data;
+    LeptonObject *o_current = (LeptonObject*) o_iter->data;
 
     /* ------- Object is a component.  Handle component attributes. ------- */
-    if (o_current->type == OBJ_COMPONENT) {    /* Note that OBJ_COMPONENT = component + attribs */
+    if (lepton_object_is_component (o_current)) /* Note that OBJ_COMPONENT = component + attribs */
+    {
 
 #if 0
       if (o_attrib_search_object_attribs_by_name (o_current, "graphical", 0)) {
@@ -462,28 +467,28 @@ s_toplevel_sheetdata_to_toplevel (TOPLEVEL *toplevel, PAGE *page)
 
       temp_uref = s_attrib_get_refdes(o_current);
       if (temp_uref != NULL) {
-	/* Must create a name=value pair list for each particular component
-	 * which we can pass to function updating o_current.  This function
+        /* Must create a name=value pair list for each particular component
+         * which we can pass to function updating o_current.  This function
          * places all attribs
-	 * found in the row into new_comp_attrib_pair_list.  */
-	new_comp_attrib_pair_list = s_table_create_attrib_pair(temp_uref,
-							       sheet_head->component_table, 
-							       sheet_head->master_comp_list_head,
-							       sheet_head->comp_attrib_count);
+         * found in the row into new_comp_attrib_pair_list.  */
+        new_comp_attrib_pair_list = s_table_create_attrib_pair(temp_uref,
+                                                               sheet_head->component_table,
+                                                               sheet_head->master_comp_list_head,
+                                                               sheet_head->comp_attrib_count);
 
 
-	/* Now update attribs in toplevel using this list.  */
-	s_toplevel_update_component_attribs_in_toplevel(toplevel,
-							o_current,
-							new_comp_attrib_pair_list);
+        /* Now update attribs in toplevel using this list.  */
+        s_toplevel_update_component_attribs_in_toplevel(toplevel,
+                                                        o_current,
+                                                        new_comp_attrib_pair_list);
 
-	g_free(temp_uref);
+        g_free(temp_uref);
       } else {
         g_debug ("s_toplevel_sheetdata_to_toplevel: "
                  "Found component with no refdes. name = %s\n",
                  o_current->name);
       }
-    }  /* if (o_current->type == OBJ_COMPONENT) */
+    }  /* if (lepton_object_is_component (o_current)) */
 
   }
 
@@ -509,19 +514,20 @@ s_toplevel_sheetdata_to_toplevel (TOPLEVEL *toplevel, PAGE *page)
   for (o_iter = g_list_last (copy_list);
        o_iter != NULL;
        o_iter = g_list_previous (o_iter)) {
-    OBJECT *o_current = (OBJECT*) o_iter->data;
+    LeptonObject *o_current = (LeptonObject*) o_iter->data;
 
     /* ------- Object is a component.  Handle pins by looking ------ */
     /* ------- for all pins attached to a component.        ------ */
-    if (o_current->type == OBJ_COMPONENT) {
+    if (lepton_object_is_component (o_current))
+    {
       /*  Upon finding a component, here's what to do:
        *  0.  Get refdes of component.
        *  1.  Loop over prim_objects, looking for pins.
        *  2.  When a pin is found, create refdes:pinnumber pair
        *      used in searching TABLE.
-       *  3.  Search TABLE using refdes:pinnumber as key, and get list of 
+       *  3.  Search TABLE using refdes:pinnumber as key, and get list of
        *      attribs corresponding to this refdes:pinnumber
-       *  4.  Stick the attribs into the TOPLEVEL data structure.
+       *  4.  Stick the attribs into the LeptonToplevel data structure.
        */
       temp_uref =  s_attrib_get_refdes(o_current);
       if ( (temp_uref != NULL) && (o_current->component->prim_objs) ) {    /* make sure object component has a refdes  */
@@ -529,19 +535,20 @@ s_toplevel_sheetdata_to_toplevel (TOPLEVEL *toplevel, PAGE *page)
         for (prim_iter = o_current->component->prim_objs;
              prim_iter != NULL;
              prim_iter = g_list_next (prim_iter)) {
-          OBJECT *comp_prim_obj = (OBJECT*) prim_iter->data;
+          LeptonObject *comp_prim_obj = (LeptonObject*) prim_iter->data;
 
-          if (comp_prim_obj->type == OBJ_PIN) {
+          if (lepton_object_is_pin (comp_prim_obj))
+          {
             new_pin_attrib_list =
               s_toplevel_get_pin_attribs_in_sheet (temp_uref, comp_prim_obj);
            s_toplevel_update_pin_attribs_in_toplevel (toplevel,
                                                       temp_uref,
                                                       comp_prim_obj,
                                                       new_pin_attrib_list);
-         }
+          }
         }
       }     /* if(temp_uref  */
-      
+
       g_free(temp_uref);
     }
   }
@@ -596,7 +603,7 @@ STRING_LIST *s_toplevel_get_component_attribs_in_sheet(char *refdes)
     if ( ((sheet_head->component_table)[row][i]).attrib_value ) {
       new_attrib_value = g_strdup( ((sheet_head->component_table)[row][i]).attrib_value );
       name_value_pair = g_strconcat(new_attrib_name, "=", new_attrib_value, NULL);
-      g_free(new_attrib_value);      
+      g_free(new_attrib_value);
     } else {
       name_value_pair = g_strconcat(new_attrib_name, "=", NULL);  /* empty attrib */
     }
@@ -616,7 +623,7 @@ STRING_LIST *s_toplevel_get_component_attribs_in_sheet(char *refdes)
     i++;
     local_attrib_list = local_attrib_list->next;
   } /* while (local_attrib_list != NULL)  */
-  
+
   return new_attrib_list;
 }
 
@@ -640,16 +647,15 @@ STRING_LIST *s_toplevel_get_component_attribs_in_sheet(char *refdes)
  * -# If the attribs doesn't exist on o_current, but is non-null in
  *    the name=value pair, create an attrib object and add it to the part
  *    on o_current.
- * \param toplevel TOPLEVEL structure
+ * \param toplevel LeptonToplevel structure
  * \param o_current Component to be updated.
  * \param new_comp_attrib_list list of name=value attribute pairs
  *                             from SHEET_DATA.
  */
 void
-s_toplevel_update_component_attribs_in_toplevel (
-                                        TOPLEVEL *toplevel,
-                                        OBJECT *o_current,
-                                        STRING_LIST *new_comp_attrib_list)
+s_toplevel_update_component_attribs_in_toplevel (LeptonToplevel *toplevel,
+                                                 LeptonObject *o_current,
+                                                 STRING_LIST *new_comp_attrib_list)
 {
   STRING_LIST *local_list;
   STRING_LIST *complete_comp_attrib_list;
@@ -660,7 +666,7 @@ s_toplevel_update_component_attribs_in_toplevel (
   char *old_attrib_value;
   gchar *refdes;
   GList *a_iter;
-  OBJECT *a_current;
+  LeptonObject *a_current;
   int count = 0;  /* This is to fake out a function called later */
   gint row, col;
   gint visibility = 0;
@@ -670,11 +676,11 @@ s_toplevel_update_component_attribs_in_toplevel (
 
   g_debug ("==== Enter s_toplevel_update_component_attribs_in_toplevel()\n");
 
-  /* 
-   * To remove dead attribs from o_current, we need to form a complete list of unique 
-   * attribs by taking the union of the new attribs from the SHEET_DATA, and 
+  /*
+   * To remove dead attribs from o_current, we need to form a complete list of unique
+   * attribs by taking the union of the new attribs from the SHEET_DATA, and
    * the old attribs living on o_current.  That's what we're doing here.
-   * Later, we can delete those attribs in o_current which don't apear in 
+   * Later, we can delete those attribs in o_current which don't apear in
    * new_comp_attrib_list.
    */
   /* First duplicate new_comp_attrib_list */
@@ -684,36 +690,36 @@ s_toplevel_update_component_attribs_in_toplevel (
   *  the loop below when updating attributes.  */
   a_iter = o_current->attribs;
   while (a_iter != NULL) {
-    a_current = (OBJECT*) a_iter->data;
-    if (a_current->type == OBJ_TEXT
-	&& a_current->text != NULL) {  /* found a name=value attribute pair. */
+    a_current = (LeptonObject*) a_iter->data;
+    if (lepton_object_is_text (a_current)
+        && a_current->text != NULL) {  /* found a name=value attribute pair. */
       /* may need to check more thoroughly here. . . . */
-      old_name_value_pair = g_strdup(geda_text_object_get_string (a_current));
+      old_name_value_pair = g_strdup (lepton_text_object_get_string (a_current));
 
       /* Else clause is suggestion from Ales */
 #if 1
       old_attrib_name = u_basic_breakup_string(old_name_value_pair, '=', 0);
       if ( (strcmp(old_attrib_name, "refdes") != 0) &&
-	   (strcmp(old_attrib_name, "net") != 0) &&
-	   (strcmp(old_attrib_name, "slot") != 0) &&
-	   (s_attrib_name_in_list(new_comp_attrib_list, old_attrib_name) == FALSE) ) {
-	s_string_list_add_item(complete_comp_attrib_list, &count, old_name_value_pair);
+           (strcmp(old_attrib_name, "net") != 0) &&
+           (strcmp(old_attrib_name, "slot") != 0) &&
+           (s_attrib_name_in_list(new_comp_attrib_list, old_attrib_name) == FALSE) ) {
+        s_string_list_add_item(complete_comp_attrib_list, &count, old_name_value_pair);
       }
 #else
       /* might now compile now, but this #if'd out branch isn't being built */
-      gint status;  
+      gint status;
       status = o_attrib_get_name_value (a_current, &old_attrib_name, &old_attrib_value);
       if (status == 0) {
         /* Don't put "refdes" or "slot" into list.  Don't put old name=value pair into list if a new
          * one is already in there. */
         if ( (strcmp(old_attrib_name, "refdes") != 0) &&
-	     (strcmp(old_attrib_name, "net") != 0) &&
-	     (strcmp(old_attrib_name, "slot") != 0) &&
-	     (s_attrib_name_in_list(new_comp_attrib_list, old_attrib_name) == FALSE) ) {
-	  s_string_list_add_item(complete_comp_attrib_list, &count, old_name_value_pair);
+             (strcmp(old_attrib_name, "net") != 0) &&
+             (strcmp(old_attrib_name, "slot") != 0) &&
+             (s_attrib_name_in_list(new_comp_attrib_list, old_attrib_name) == FALSE) ) {
+          s_string_list_add_item(complete_comp_attrib_list, &count, old_name_value_pair);
         }
-	g_free (old_attrib_name);
-	g_free (old_attrib_value);
+        g_free (old_attrib_name);
+        g_free (old_attrib_value);
       }
  #endif
      g_free(old_name_value_pair);
@@ -723,14 +729,14 @@ s_toplevel_update_component_attribs_in_toplevel (
   }  /* while (a_current != NULL) */
 
 
-  /* 
+  /*
    *Now the main business of this function:  updating the attribs attached to this o_current.
    * Loop on name=value pairs held in complete_comp_attrib_list , and then use this to get the
    * name=value pairs out of new_comp_attrib_list and from o_current.
    */
 
   /* First handle a special case: the component has no attribs (beside refdes). */
-  if (complete_comp_attrib_list->data == NULL) 
+  if (complete_comp_attrib_list->data == NULL)
     return;
 
   /* Now the normal case. . . . */
@@ -741,9 +747,9 @@ s_toplevel_update_component_attribs_in_toplevel (
              "Handling entry in complete list %s.\n",
              local_list->data);
 
-  /*  Now get the old attrib name & value from complete_comp_attrib_list 
+  /*  Now get the old attrib name & value from complete_comp_attrib_list
    *  and value from o_current  */
-  old_attrib_name = u_basic_breakup_string(local_list->data, '=', 0); 
+  old_attrib_name = u_basic_breakup_string(local_list->data, '=', 0);
   old_attrib_value = o_attrib_search_attached_attribs_by_name (o_current, old_attrib_name, 0);
 
   g_debug ("s_toplevel_update_component_attribs_in_toplevel: "
@@ -755,7 +761,7 @@ s_toplevel_update_component_attribs_in_toplevel (
   /*  Next try to get this attrib from new_comp_attrib_list  */
   new_attrib_name = u_basic_breakup_string(local_list->data, '=', 0);
   if (s_string_list_in_list(new_comp_attrib_list, local_list->data)) {
-    new_attrib_value = s_misc_remaining_string(local_list->data, '=', 1);      
+    new_attrib_value = s_misc_remaining_string(local_list->data, '=', 1);
   } else {
     new_attrib_value = NULL;
   }
@@ -765,7 +771,7 @@ s_toplevel_update_component_attribs_in_toplevel (
            new_attrib_name,
            new_attrib_value);
 
-  /* Now get row and col where this new attrib lives.  Then get 
+  /* Now get row and col where this new attrib lives.  Then get
    * visibility of the new attrib stored in the component table */
   /* We'll need this later */
   refdes = g_strdup(s_attrib_get_refdes(o_current));
@@ -830,7 +836,7 @@ s_toplevel_update_component_attribs_in_toplevel (
     }
 
     /* Toggle attribute visibility and name/value setting */
-    
+
 
     /* free everything and iterate */
     g_free(new_attrib_name);
@@ -858,8 +864,8 @@ STRING_LIST *s_toplevel_get_net_attribs_in_sheet(char *netname)
 /*!
  * \todo Function doesn't do anything - candidate for removal?
  */
-void s_toplevel_update_net_attribs_in_toplevel(OBJECT *o_current, 
-				   STRING_LIST *new_net_attrib_list)
+void s_toplevel_update_net_attribs_in_toplevel(LeptonObject *o_current,
+                                   STRING_LIST *new_net_attrib_list)
 {
   /* must be filled in */
   return;
@@ -869,9 +875,10 @@ void s_toplevel_update_net_attribs_in_toplevel(OBJECT *o_current,
 /*------------------------------------------------------------------*/
 /*! \brief Get pin attributes
  *
- * This function takes a pointer to the OBJECT pin, and returns a list
- * of attribs found attached to the pin.  The returned list is a 
- * STRING_LIST where the ->data holds a name=value string.
+ * This function takes a pointer to the LeptonObject pin, and
+ * returns a list of attribs found attached to the pin.  The
+ * returned list is a STRING_LIST where the ->data holds a
+ * name=value string.
  * The algorithm is as follows:
  * -# Form refdes:pinnumber label for this pin.
  * -# Get row number of this refdes:pinnumber
@@ -883,7 +890,7 @@ void s_toplevel_update_net_attribs_in_toplevel(OBJECT *o_current,
  * \param pin Pin object
  * \returns name=value pair as a STRING_LIST
  */
-STRING_LIST *s_toplevel_get_pin_attribs_in_sheet(char *refdes, OBJECT *pin)
+STRING_LIST *s_toplevel_get_pin_attribs_in_sheet(char *refdes, LeptonObject *pin)
 {
   STRING_LIST *new_attrib_list;
   STRING_LIST *local_attrib_list;
@@ -932,7 +939,7 @@ STRING_LIST *s_toplevel_get_pin_attribs_in_sheet(char *refdes, OBJECT *pin)
     if ( ((sheet_head->pin_table)[row][i]).attrib_value ) {
       new_attrib_value = g_strdup( ((sheet_head->pin_table)[row][i]).attrib_value );
       name_value_pair = g_strconcat(new_attrib_name, "=", new_attrib_value, NULL);
-      g_free(new_attrib_value);      
+      g_free(new_attrib_value);
     } else {
       name_value_pair = g_strconcat(new_attrib_name, "=", NULL);  /* empty attrib */
     }
@@ -952,7 +959,7 @@ STRING_LIST *s_toplevel_get_pin_attribs_in_sheet(char *refdes, OBJECT *pin)
     i++;
     local_attrib_list = local_attrib_list->next;
   } /* while (local_attrib_list != NULL)  */
-  
+
   return new_attrib_list;
 }
 
@@ -971,15 +978,15 @@ STRING_LIST *s_toplevel_get_pin_attribs_in_sheet(char *refdes, OBJECT *pin)
  *    delete the attrib.
  * -# If the attribs doesn't exist on pin, but is non-null in
  *    the name=value pair, create an attrib object and add it to the pin.
- * \param toplevel TOPLEVEL structure
+ * \param toplevel LeptonToplevel structure
  * \param refdes Unused - needs refactored out
  * \param [in,out] o_pin pin to update
  * \param [in] new_pin_attrib_list New pin attribute list to apply
  */
 void
-s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
+s_toplevel_update_pin_attribs_in_toplevel (LeptonToplevel *toplevel,
                                            char *refdes,
-                                           OBJECT *o_pin,
+                                           LeptonObject *o_pin,
                                            STRING_LIST *new_pin_attrib_list)
 {
   STRING_LIST *local_list;
@@ -1004,11 +1011,11 @@ s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
   new_attrib_value = u_basic_breakup_string(new_name_value_pair, '=', 1);
 
   if (strlen(new_attrib_value) == 0) {
-    g_free(new_attrib_value);   
+    g_free(new_attrib_value);
     new_attrib_value = NULL;  /* s_misc_remaining_string doesn't return NULL for empty substring. */
   }
   old_attrib_value = o_attrib_search_attached_attribs_by_name (o_pin, new_attrib_name, 0);
-                                                                                                       
+
     /* -------  Four cases to consider: Case 1: old and new attribs exist ----- */
     if ( (old_attrib_value != NULL) && (new_attrib_value != NULL) && (strlen(new_attrib_value) != 0) ) {
       /* simply write new attrib into place of old one. */
@@ -1022,7 +1029,7 @@ s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
                                          LEAVE_VISIBILITY_ALONE,
                                          LEAVE_NAME_VALUE_ALONE);
     }
-                                                                                                       
+
     /* -------  Four cases to consider: Case 2: old attrib exists, new one doesn't ----- */
     else if ( (old_attrib_value != NULL) && (new_attrib_value == NULL) ) {
       /* remove attrib from pin */
@@ -1032,11 +1039,11 @@ s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
                old_attrib_value);
       s_object_remove_attrib_in_object (toplevel, o_pin, new_attrib_name);
     }
-                                                                                                       
+
     /* -------  Four cases to consider: Case 3: No old attrib, new one exists. ----- */
     else if ( (old_attrib_value == NULL) && (new_attrib_value != NULL) ) {
       /* add new attrib to pin. */
-                                                                                                       
+
       g_debug ("s_toplevel_update_pin_attribs_in_toplevel: "
                "About to add new attrib with name= %s, value= %s\n",
                new_attrib_name,
@@ -1053,7 +1060,7 @@ s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
       g_debug ("s_toplevel_update_pin_attribs_in_toplevel: "
                "Nothing needs to be done.\n");
     }
-                                                                                                       
+
     /* free everything and iterate */
     g_free(new_name_value_pair);
     g_free(new_attrib_name);
@@ -1064,7 +1071,3 @@ s_toplevel_update_pin_attribs_in_toplevel (TOPLEVEL *toplevel,
 
   return;
 }
-
-
-
-
