@@ -23,12 +23,15 @@
   ; Import C procedures
   #:use-module (schematic core window)
 
+  #:use-module (schematic ffi)
+
   #:use-module (lepton page)
   #:re-export (close-page!))
 
 (define-public active-page %active-page)
 (define-public set-active-page! %set-active-page!)
 (define-public pointer-position %pointer-position)
+(define-public current-window %current-window)
 
 (define-public (snap-point point)
   (%snap-point (car point) (cdr point)))
