@@ -24,172 +24,6 @@
 #include <gdk/gdkkeysyms.h>
 
 
-#define DEFINE_G_KEYS(name)				\
-SCM g_keys_ ## name(SCM rest)				\
-{							\
-   GschemToplevel *w_current = g_current_window ();	\
-   i_callback_ ## name(w_current, 0, NULL);                   \
-   return SCM_BOOL_T;				\
-}
-
-/*! \brief test-comment
- * test-comment
- */
-DEFINE_G_KEYS(file_new)
-
-DEFINE_G_KEYS(file_new_window)
-
-/* don't use the widget parameter on this function, or do some checking... */
-/* since there is a call: widget = NULL, data = 0 (will be w_current) */
-/* This should be renamed to page_open perhaps... */
-DEFINE_G_KEYS(file_open)
-
-/* don't use the widget parameter on this function, or do some checking... */
-/* since there is a call: widget = NULL, data = 0 (will be w_current) */
-DEFINE_G_KEYS(file_script)
-
-/* don't use the widget parameter on this function, or do some checking... */
-/* since there is a call: widget = NULL, data = 0 (will be w_current) */
-DEFINE_G_KEYS(file_save)
-DEFINE_G_KEYS(file_save_as)
-DEFINE_G_KEYS(file_save_all)
-DEFINE_G_KEYS(file_print)
-DEFINE_G_KEYS(file_write_png)
-
-/* don't use the widget parameter on this function, or do some checking... */
-/* since there is a call: widget = NULL, data = 0 (will be w_current) */
-/* this function closes a window */
-DEFINE_G_KEYS(file_close)
-DEFINE_G_KEYS(file_quit)
-
-/* Select also does not update the middle button shortcut */
-DEFINE_G_KEYS(edit_undo)
-DEFINE_G_KEYS(edit_redo)
-DEFINE_G_KEYS(edit_select)
-DEFINE_G_KEYS(edit_select_all)
-DEFINE_G_KEYS(edit_deselect)
-DEFINE_G_KEYS(edit_copy)
-DEFINE_G_KEYS(edit_mcopy)
-DEFINE_G_KEYS(edit_move)
-DEFINE_G_KEYS(edit_delete)
-DEFINE_G_KEYS(edit_rotate_90)
-DEFINE_G_KEYS(edit_mirror)
-DEFINE_G_KEYS(edit_slot)
-DEFINE_G_KEYS(edit_object_properties)
-DEFINE_G_KEYS(edit_edit)
-DEFINE_G_KEYS(edit_text)
-DEFINE_G_KEYS(edit_lock)
-DEFINE_G_KEYS(edit_unlock)
-DEFINE_G_KEYS(edit_translate)
-DEFINE_G_KEYS(edit_invoke_macro)
-DEFINE_G_KEYS(edit_embed)
-DEFINE_G_KEYS(edit_unembed)
-DEFINE_G_KEYS(edit_update)
-DEFINE_G_KEYS(edit_show_hidden)
-DEFINE_G_KEYS(edit_find)
-DEFINE_G_KEYS(edit_show_text)
-DEFINE_G_KEYS(edit_hide_text)
-DEFINE_G_KEYS(edit_autonumber_text)
-
-DEFINE_G_KEYS(clipboard_copy)
-DEFINE_G_KEYS(clipboard_cut)
-DEFINE_G_KEYS(clipboard_paste)
-
-DEFINE_G_KEYS(buffer_copy1)
-DEFINE_G_KEYS(buffer_copy2)
-DEFINE_G_KEYS(buffer_copy3)
-DEFINE_G_KEYS(buffer_copy4)
-DEFINE_G_KEYS(buffer_copy5)
-DEFINE_G_KEYS(buffer_cut1)
-DEFINE_G_KEYS(buffer_cut2)
-DEFINE_G_KEYS(buffer_cut3)
-DEFINE_G_KEYS(buffer_cut4)
-DEFINE_G_KEYS(buffer_cut5)
-DEFINE_G_KEYS(buffer_paste1)
-DEFINE_G_KEYS(buffer_paste2)
-DEFINE_G_KEYS(buffer_paste3)
-DEFINE_G_KEYS(buffer_paste4)
-DEFINE_G_KEYS(buffer_paste5)
-
-DEFINE_G_KEYS(view_sidebar)
-DEFINE_G_KEYS(view_status)
-DEFINE_G_KEYS(view_find_text_state)
-
-/* repeat middle shortcut doesn't make sense on redraw, just hit right
- * button */
-DEFINE_G_KEYS(view_redraw)
-
-/* for these functions, repeat middle shortcut would get into the way
- * of what user is try to do */
-DEFINE_G_KEYS(view_zoom_full)
-DEFINE_G_KEYS(view_zoom_extents)
-DEFINE_G_KEYS(view_zoom_in)
-DEFINE_G_KEYS(view_zoom_out)
-
-DEFINE_G_KEYS(view_zoom_box)
-DEFINE_G_KEYS(view_pan)
-DEFINE_G_KEYS(view_pan_left)
-DEFINE_G_KEYS(view_pan_right)
-DEFINE_G_KEYS(view_pan_up)
-DEFINE_G_KEYS(view_pan_down)
-DEFINE_G_KEYS(view_dark_colors)
-DEFINE_G_KEYS(view_light_colors)
-DEFINE_G_KEYS(view_bw_colors)
-DEFINE_G_KEYS(view_color_edit)
-DEFINE_G_KEYS(page_manager)
-DEFINE_G_KEYS(page_next)
-DEFINE_G_KEYS(page_prev)
-DEFINE_G_KEYS(page_close)
-DEFINE_G_KEYS(page_next_tab)
-DEFINE_G_KEYS(page_prev_tab)
-DEFINE_G_KEYS(page_revert)
-DEFINE_G_KEYS(page_print)
-DEFINE_G_KEYS(add_component)
-DEFINE_G_KEYS(add_attribute)
-DEFINE_G_KEYS(add_net)
-DEFINE_G_KEYS(add_bus)
-DEFINE_G_KEYS(add_text)
-DEFINE_G_KEYS(add_line)
-DEFINE_G_KEYS(add_path)
-DEFINE_G_KEYS(add_box)
-DEFINE_G_KEYS(add_picture)
-DEFINE_G_KEYS(add_circle)
-DEFINE_G_KEYS(add_arc)
-DEFINE_G_KEYS(add_pin)
-DEFINE_G_KEYS(hierarchy_down_schematic)
-DEFINE_G_KEYS(hierarchy_down_symbol)
-DEFINE_G_KEYS(hierarchy_up)
-DEFINE_G_KEYS(attributes_show_name)
-DEFINE_G_KEYS(attributes_show_value)
-DEFINE_G_KEYS(attributes_show_both)
-DEFINE_G_KEYS(attributes_visibility_toggle)
-
-/* i_callback_script_console is not currently implemented */
-DEFINE_G_KEYS(script_console)
-
-/* repeat last command doesn't make sense on options either??? (does
- * it?) */
-DEFINE_G_KEYS(options_afeedback)
-DEFINE_G_KEYS(options_grid)
-DEFINE_G_KEYS(options_snap)
-DEFINE_G_KEYS(options_snap_size)
-DEFINE_G_KEYS(options_scale_up_snap_size)
-DEFINE_G_KEYS(options_scale_down_snap_size)
-DEFINE_G_KEYS(options_rubberband)
-DEFINE_G_KEYS(options_magneticnet)
-DEFINE_G_KEYS(options_show_log_window)
-DEFINE_G_KEYS(options_show_coord_window)
-DEFINE_G_KEYS(options_select_font)
-DEFINE_G_KEYS(options_draw_grips)
-
-DEFINE_G_KEYS(help_about)
-DEFINE_G_KEYS(help_hotkeys)
-
-/* be sure that you don't use the widget parameter in this one, since it is
-being called with a null, I suppose we should call it with the right param.
-hack */
-DEFINE_G_KEYS(cancel)
-
 /*! Contains the smob tag for key smobs */
 static scm_t_bits g_key_smob_tag;
 #define G_SCM_IS_KEY(x) SCM_SMOB_PREDICATE (g_key_smob_tag, (x))
@@ -612,4 +446,3 @@ g_init_keys ()
                        (void (*)(void*)) init_module_schematic_core_keymap,
                        NULL);
 }
-
