@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -193,17 +194,18 @@ finalize (GObject *object)
  */
 void find_text_dialog (GschemToplevel *w_current)
 {
-  OBJECT *object;
+  LeptonObject *object;
 
   g_return_if_fail (w_current != NULL);
   g_return_if_fail (w_current->toplevel != NULL);
 
   object = o_select_return_first_object(w_current);
 
-  if ((object != NULL) && (object->type == OBJ_TEXT)) {
+  if (lepton_object_is_text (object))
+  {
     gschem_find_text_widget_set_find_text_string(
             GSCHEM_FIND_TEXT_WIDGET (w_current->find_text_widget),
-            geda_text_object_get_string (object)
+            lepton_text_object_get_string (object)
             );
   }
 
