@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -321,7 +321,6 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->embed_component = 0;
   w_current->include_component = 0;
   w_current->scrollbars_flag = 0;
-  w_current->log_window = 0;
   w_current->third_button = 0;
   w_current->third_button_cancel = TRUE;
   w_current->middle_button = 0;
@@ -632,7 +631,7 @@ gschem_toplevel_get_text_size_list_store (GschemToplevel *w_current)
  *  \param [in] w_current This gschem toplevel
  *  \return The libgeda toplevel
  */
-TOPLEVEL*
+LeptonToplevel*
 gschem_toplevel_get_toplevel (GschemToplevel *w_current)
 {
   g_return_val_if_fail (w_current != NULL, NULL);
@@ -685,7 +684,8 @@ gschem_toplevel_page_changed (GschemToplevel *w_current)
  *  \param [in] page      The page that underwent changes.
  */
 void
-gschem_toplevel_page_content_changed (GschemToplevel *w_current, PAGE *page)
+gschem_toplevel_page_content_changed (GschemToplevel *w_current,
+                                      LeptonPage *page)
 {
   g_return_if_fail (page != NULL);
   g_return_if_fail (w_current != NULL);
@@ -702,7 +702,8 @@ gschem_toplevel_page_content_changed (GschemToplevel *w_current, PAGE *page)
  *  \param [in] toplevel The libgeda toplevel
  */
 void
-gschem_toplevel_set_toplevel (GschemToplevel *w_current, TOPLEVEL *toplevel)
+gschem_toplevel_set_toplevel (GschemToplevel *w_current,
+                              LeptonToplevel *toplevel)
 {
   g_return_if_fail (w_current != NULL);
 
@@ -716,7 +717,7 @@ gschem_toplevel_set_toplevel (GschemToplevel *w_current, TOPLEVEL *toplevel)
 static void
 handle_undo (GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel;
+  LeptonToplevel *toplevel;
 
   g_return_if_fail (w_current != NULL);
 
