@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 
 #define INVALIDATE_MARGIN 1
 
-extern GedaColorMap display_colors;
-extern GedaColorMap display_outline_colors;
+extern LeptonColorMap display_colors;
+extern LeptonColorMap display_outline_colors;
 
 /*! \todo Lots of Gross code... needs lots of cleanup - mainly
  * readability issues
@@ -40,18 +40,18 @@ extern GedaColorMap display_outline_colors;
 void
 o_redraw_rect (GschemToplevel *w_current,
                GtkWidget *widget,
-               PAGE *page,
+               LeptonPage *page,
                GschemPageGeometry *geometry,
                cairo_t *cr)
 #else
 void o_redraw_rect (GschemToplevel *w_current,
                     GdkDrawable *drawable,
-                    PAGE *page,
+                    LeptonPage *page,
                     GschemPageGeometry *geometry,
                     GdkRectangle *rectangle)
 #endif
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   gboolean draw_selected;
   int grip_half_size;
   double cue_half_size;
@@ -59,7 +59,7 @@ void o_redraw_rect (GschemToplevel *w_current,
   double dummy = 0.0;
   GList *obj_list;
   GList *iter;
-  BOX *world_rect;
+  LeptonBox *world_rect;
   EdaRenderer *renderer;
   int render_flags;
   GArray *render_color_map = NULL;
@@ -89,7 +89,7 @@ void o_redraw_rect (GschemToplevel *w_current,
   bloat = MAX (grip_half_size, (int)cue_half_size);
 
 
-  world_rect = g_new (BOX, 1);
+  world_rect = g_new (LeptonBox, 1);
 
 #ifdef ENABLE_GTK3
   gint wx, wy;
@@ -143,14 +143,14 @@ void o_redraw_rect (GschemToplevel *w_current,
 
   /* This color map is used for "normal" rendering. */
   render_color_map =
-    g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), colors_count());
+    g_array_sized_new (FALSE, FALSE, sizeof(LeptonColor), colors_count());
   render_color_map =
     g_array_append_vals (render_color_map, display_colors, colors_count());
 
   /* This color map is used for rendering rubberbanding nets and
      buses, and objects which are in the process of being placed. */
   render_outline_color_map =
-    g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), colors_count());
+    g_array_sized_new (FALSE, FALSE, sizeof(LeptonColor), colors_count());
   render_outline_color_map =
     g_array_append_vals (render_outline_color_map, display_outline_colors,
                          colors_count());
@@ -165,13 +165,13 @@ void o_redraw_rect (GschemToplevel *w_current,
                 NULL);
 
   /* Paint background */
-  GedaColor *color = x_color_lookup (BACKGROUND_COLOR);
+  LeptonColor *color = x_color_lookup (BACKGROUND_COLOR);
 
   cairo_set_source_rgba (cr,
-                         geda_color_get_red_double (color),
-                         geda_color_get_green_double (color),
-                         geda_color_get_blue_double (color),
-                         geda_color_get_alpha_double (color));
+                         lepton_color_get_red_double (color),
+                         lepton_color_get_green_double (color),
+                         lepton_color_get_blue_double (color),
+                         lepton_color_get_alpha_double (color));
 
 #ifdef ENABLE_GTK3
   double cx=wx, cy=wy;
@@ -197,7 +197,7 @@ void o_redraw_rect (GschemToplevel *w_current,
 
   /* First pass -- render non-selected objects */
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    OBJECT *o_current = (OBJECT*) iter->data;
+    LeptonObject *o_current = (LeptonObject*) iter->data;
 
     if (!(o_current->dont_redraw || o_current->selected)) {
       eda_renderer_draw (renderer, o_current);
@@ -206,7 +206,7 @@ void o_redraw_rect (GschemToplevel *w_current,
 
   /* Second pass -- render cues */
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    OBJECT *o_current = (OBJECT*) iter->data;
+    LeptonObject *o_current = (LeptonObject*) iter->data;
 
     if (!(o_current->dont_redraw || o_current->selected)) {
       eda_renderer_draw_cues (renderer, o_current);
@@ -220,9 +220,9 @@ void o_redraw_rect (GschemToplevel *w_current,
     g_object_set (G_OBJECT (renderer),
                   "override-color", SELECT_COLOR,
                   NULL);
-    for (iter = geda_list_get_glist (page->selection_list);
+    for (iter = lepton_list_get_glist (page->selection_list);
          iter != NULL; iter = g_list_next (iter)) {
-      OBJECT *o_current = (OBJECT*) iter->data;
+      LeptonObject *o_current = (LeptonObject*) iter->data;
       if (!o_current->dont_redraw) {
         eda_renderer_draw (renderer, o_current);
         eda_renderer_draw_cues (renderer, o_current);
@@ -366,7 +366,7 @@ int o_invalidate_rubber (GschemToplevel *w_current)
  */
 int o_redraw_cleanstates(GschemToplevel *w_current)
 {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   /* returns FALSE if the function was'nt nessecary */
   if (w_current->inside_action == 0) {
     return FALSE;
@@ -412,7 +412,7 @@ int o_redraw_cleanstates(GschemToplevel *w_current)
       /* Free the place list and its contents. If we were in a move
        * action, the list (refering to objects on the page) would
        * already have been cleared in o_move_cancel(), so this is OK. */
-      geda_object_list_delete (toplevel->page_current->place_list);
+      lepton_object_list_delete (toplevel->page_current->place_list);
       toplevel->page_current->place_list = NULL;
 
       i_action_stop (w_current);
@@ -482,19 +482,19 @@ void o_invalidate_rect (GschemToplevel *w_current,
  *
  *  \par Function Description
  *  This function calls o_invalidate_rect() with the bounds of the
- *  passed OBJECT, converted to screen coordinates.
+ *  passed LeptonObject, converted to screen coordinates.
  *
  *  \param [in] w_current  The GschemToplevel object.
- *  \param [in] object     The OBJECT invalidated on screen.
+ *  \param [in] object     The LeptonObject invalidated on screen.
  */
-void o_invalidate (GschemToplevel *w_current, OBJECT *object)
+void o_invalidate (GschemToplevel *w_current, LeptonObject *object)
 {
   if (w_current == NULL || w_current->dont_invalidate) return;
 
   int left, top, bottom, right;
 
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   gboolean show_hidden_text =
     gschem_toplevel_get_show_hidden_text (w_current);
 
@@ -503,12 +503,13 @@ void o_invalidate (GschemToplevel *w_current, OBJECT *object)
     return;
   }
 
-  if (geda_object_calculate_visible_bounds (object,
-                                            show_hidden_text,
-                                            &left,
-                                            &top,
-                                            &right,
-                                            &bottom)) {
+  if (lepton_object_calculate_visible_bounds (object,
+                                              show_hidden_text,
+                                              &left,
+                                              &top,
+                                              &right,
+                                              &bottom))
+  {
     gschem_page_view_invalidate_world_rect (page_view,
                                             left,
                                             top,
@@ -534,7 +535,7 @@ void o_invalidate_glist (GschemToplevel *w_current, GList *list)
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
   gboolean show_hidden_text =
