@@ -273,34 +273,37 @@ LeptonObject *o_grips_search_arc_world(GschemToplevel *w_current, LeptonObject *
 LeptonObject *o_grips_search_box_world(GschemToplevel *w_current, LeptonObject *o_current,
                                  int x, int y, int size, int *whichone)
 {
+  int upper_x, upper_y, lower_x, lower_y;
+
+  upper_x = lepton_box_object_get_upper_x (o_current);
+  upper_y = lepton_box_object_get_upper_y (o_current);
+  lower_x = lepton_box_object_get_lower_x (o_current);
+  lower_y = lepton_box_object_get_lower_y (o_current);
+
   /* inside upper left grip ? */
-  if (inside_grip(x, y,
-                  o_current->box->upper_x,
-                  o_current->box->upper_y, size)) {
+  if (inside_grip (x, y, upper_x, upper_y, size))
+  {
     *whichone = BOX_UPPER_LEFT;
     return(o_current);
   }
 
   /* inside lower right grip ? */
-  if (inside_grip(x, y,
-                  o_current->box->lower_x,
-                  o_current->box->lower_y, size)) {
+  if (inside_grip (x, y, lower_x, lower_y, size))
+  {
     *whichone = BOX_LOWER_RIGHT;
     return(o_current);
   }
 
   /* inside upper right grip ? */
-  if (inside_grip(x, y,
-                  o_current->box->lower_x,
-                  o_current->box->upper_y, size)) {
+  if (inside_grip (x, y, lower_x, upper_y, size))
+  {
     *whichone = BOX_UPPER_RIGHT;
     return(o_current);
   }
 
   /* inside lower left grip ? */
-  if (inside_grip(x, y,
-                  o_current->box->upper_x,
-                  o_current->box->lower_y, size)) {
+  if (inside_grip (x, y, upper_x, lower_y, size))
+  {
     *whichone = BOX_LOWER_LEFT;
     return(o_current);
   }
@@ -342,8 +345,9 @@ LeptonObject *o_grips_search_path_world(GschemToplevel *w_current, LeptonObject
   int i;
   int grip_no = 0;
 
-  for (i = 0; i <  o_current->path->num_sections; i++) {
-    section = &o_current->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (o_current); i++)
+  {
+    section = lepton_path_object_get_section (o_current, i);
 
     switch (section->code) {
     case PATH_CURVETO:
@@ -601,34 +605,41 @@ static void o_grips_start_arc(GschemToplevel *w_current, LeptonObject *o_current
 static void o_grips_start_box(GschemToplevel *w_current, LeptonObject *o_current,
                               int x, int y, int whichone)
 {
+  int upper_x, upper_y, lower_x, lower_y;
+
   w_current->last_drawb_mode = LAST_DRAWB_MODE_NONE;
 
+  upper_x = lepton_box_object_get_upper_x (o_current);
+  upper_y = lepton_box_object_get_upper_y (o_current);
+  lower_x = lepton_box_object_get_lower_x (o_current);
+  lower_y = lepton_box_object_get_lower_y (o_current);
+
   /* (second_wx, second_wy) is the selected corner */
   /* (first_wx, first_wy) is the opposite corner */
   switch(whichone) {
     case BOX_UPPER_LEFT:
-      w_current->second_wx = o_current->box->upper_x;
-      w_current->second_wy = o_current->box->upper_y;
-      w_current->first_wx = o_current->box->lower_x;
-      w_current->first_wy = o_current->box->lower_y;
+      w_current->second_wx = upper_x;
+      w_current->second_wy = upper_y;
+      w_current->first_wx  = lower_x;
+      w_current->first_wy  = lower_y;
       break;
     case BOX_LOWER_RIGHT:
-      w_current->second_wx = o_current->box->lower_x;
-      w_current->second_wy = o_current->box->lower_y;
-      w_current->first_wx = o_current->box->upper_x;
-      w_current->first_wy = o_current->box->upper_y;
+      w_current->second_wx = lower_x;
+      w_current->second_wy = lower_y;
+      w_current->first_wx  = upper_x;
+      w_current->first_wy  = upper_y;
       break;
     case BOX_UPPER_RIGHT:
-      w_current->second_wx = o_current->box->lower_x;
-      w_current->second_wy = o_current->box->upper_y;
-      w_current->first_wx = o_current->box->upper_x;
-      w_current->first_wy = o_current->box->lower_y;
+      w_current->second_wx = lower_x;
+      w_current->second_wy = upper_y;
+      w_current->first_wx  = upper_x;
+      w_current->first_wy  = lower_y;
       break;
     case BOX_LOWER_LEFT:
-      w_current->second_wx = o_current->box->upper_x;
-      w_current->second_wy = o_current->box->lower_y;
-      w_current->first_wx = o_current->box->lower_x;
-      w_current->first_wy = o_current->box->upper_y;
+      w_current->second_wx = upper_x;
+      w_current->second_wy = lower_y;
+      w_current->first_wx  = lower_x;
+      w_current->first_wy  = upper_y;
       break;
     default:
       return; /* error */
@@ -672,8 +683,9 @@ static void o_grips_start_path(GschemToplevel *w_current, LeptonObject *o_curren
 
   w_current->last_drawb_mode = -1;
 
-  for (i = 0; i <  o_current->path->num_sections; i++) {
-    section = &o_current->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (o_current); i++)
+  {
+    section = lepton_path_object_get_section (o_current, i);
 
     switch (section->code) {
     case PATH_CURVETO:
