@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ void o_net_guess_direction(GschemToplevel *w_current,
   int xmin, ymin, xmax, ymax;
   int orientation;
   GList *object_list, *iter1, *iter2;
-  OBJECT *o_current;
+  LeptonObject *o_current;
 
   int *current_rules;
   /* badness values       {OVERWRITE, ORTHO, CONTINUE} */
@@ -98,19 +98,19 @@ void o_net_guess_direction(GschemToplevel *w_current,
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
   object_list = g_list_append (NULL, page->connectible_list);
 
   for (iter1 = object_list; iter1 != NULL; iter1 = g_list_next(iter1)) {
     for (iter2 = (GList*) iter1->data; iter2 != NULL; iter2 = g_list_next(iter2)) {
-      o_current = (OBJECT*) iter2->data;
+      o_current = (LeptonObject*) iter2->data;
 
-      if ((orientation = geda_net_object_orientation (o_current)) == NEITHER)
+      if ((orientation = lepton_net_object_orientation (o_current)) == NEITHER)
         continue;
 
-      switch (o_current->type) {
+      switch (lepton_object_get_type (o_current)) {
       case OBJ_NET:
         current_rules = (int*) net_rules;
         break;
@@ -214,14 +214,14 @@ void o_net_find_magnetic(GschemToplevel *w_current,
   double mindist, minbest, dist1, dist2;
   double weight, min_weight;
   int magnetic_reach = 0;
-  OBJECT *o_current;
-  OBJECT *o_magnetic = NULL;
+  LeptonObject *o_current;
+  LeptonObject *o_magnetic = NULL;
   GList *object_list, *iter1, *iter2;
 
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
   minbest = min_x = min_y = 0;
@@ -236,18 +236,19 @@ void o_net_find_magnetic(GschemToplevel *w_current,
   for (iter1 = object_list; iter1 != NULL; iter1 = g_list_next(iter1)) {
     for (iter2 = (GList*) iter1->data; iter2 != NULL; iter2 = g_list_next(iter2)) {
       int left, top, right, bottom;
-      o_current = (OBJECT*) iter2->data;
+      o_current = (LeptonObject*) iter2->data;
 
-      if (!geda_object_calculate_visible_bounds (o_current,
-                                                 FALSE,
-                                                 &left,
-                                                 &top,
-                                                 &right,
-                                                 &bottom) ||
+      if (!lepton_object_calculate_visible_bounds (o_current,
+                                                   FALSE,
+                                                   &left,
+                                                   &top,
+                                                   &right,
+                                                   &bottom) ||
           !visible (w_current, left, top, right, bottom))
         continue; /* skip invisible objects */
 
-      if (o_current->type == OBJ_PIN) {
+      if (lepton_object_is_pin (o_current))
+      {
         min_x = o_current->line->x[o_current->whichend];
         min_y = o_current->line->y[o_current->whichend];
 
@@ -255,8 +256,9 @@ void o_net_find_magnetic(GschemToplevel *w_current,
         weight = mindist / MAGNETIC_PIN_WEIGHT;
       }
 
-      else if (o_current->type == OBJ_NET
-               || o_current->type == OBJ_BUS) {
+      else if (lepton_object_is_net (o_current)
+               || lepton_object_is_bus (o_current))
+      {
         /* we have 3 possible points to connect:
            2 endpoints and 1 midpoint point */
         x1 = o_current->line->x[0];
@@ -297,7 +299,7 @@ void o_net_find_magnetic(GschemToplevel *w_current,
           }
         }
 
-        if (o_current->type == OBJ_BUS)
+        if (lepton_object_is_bus (o_current))
           weight = mindist / MAGNETIC_BUS_WEIGHT;
         else /* OBJ_NET */
           weight = mindist / MAGNETIC_NET_WEIGHT;
@@ -319,7 +321,7 @@ void o_net_find_magnetic(GschemToplevel *w_current,
 
   /* check whether we found an object and if it's close enough */
   if (o_magnetic != NULL) {
-    switch (o_magnetic->type) {
+    switch (lepton_object_get_type (o_magnetic)) {
     case (OBJ_PIN): magnetic_reach = MAGNETIC_PIN_REACH; break;
     case (OBJ_NET): magnetic_reach = MAGNETIC_NET_REACH; break;
     case (OBJ_BUS): magnetic_reach = MAGNETIC_BUS_REACH; break;
@@ -460,7 +462,7 @@ void o_net_start(GschemToplevel *w_current, int w_x, int w_y)
  * position.
  *
  * The rubber nets are removed, the nets and cues are drawn and the
- * net is added to the TOPLEVEL structure.
+ * net is added to the LeptonToplevel structure.
  *
  * The function returns TRUE if it has drawn a net, FALSE otherwise.
  */
@@ -471,7 +473,7 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
   int save_wx, save_wy;
 
   GList *prev_conn_objects;
-  OBJECT *new_net = NULL;
+  LeptonObject *new_net = NULL;
 
   /* Save a list of added objects to run the %add-objects-hook later */
   GList *added_objects = NULL;
@@ -481,7 +483,7 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_if_fail (page != NULL);
 
   o_net_invalidate_rubber (w_current);
@@ -515,9 +517,11 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
 
   if (!primary_zero_length ) {
   /* create primary net */
-      new_net = geda_net_object_new (OBJ_NET, NET_COLOR,
-                                     w_current->first_wx, w_current->first_wy,
-                                     w_current->second_wx, w_current->second_wy);
+    new_net = lepton_net_object_new (NET_COLOR,
+                                     w_current->first_wx,
+                                     w_current->first_wy,
+                                     w_current->second_wx,
+                                     w_current->second_wy);
       s_page_append (page, new_net);
 
       added_objects = g_list_prepend (added_objects, new_net);
@@ -550,9 +554,11 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
   if (!secondary_zero_length && !found_primary_connection) {
 
       /* Add secondary net */
-      new_net = geda_net_object_new (OBJ_NET, NET_COLOR,
-                                     w_current->second_wx, w_current->second_wy,
-                                     w_current->third_wx, w_current->third_wy);
+    new_net = lepton_net_object_new (NET_COLOR,
+                                     w_current->second_wx,
+                                     w_current->second_wy,
+                                     w_current->third_wx,
+                                     w_current->third_wy);
       s_page_append (page, new_net);
 
       added_objects = g_list_prepend (added_objects, new_net);
@@ -754,14 +760,14 @@ void o_net_invalidate_rubber (GschemToplevel *w_current)
  *  \par Function Description
  *
  */
-int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
+int o_net_add_busrippers(GschemToplevel *w_current, LeptonObject *net_obj,
                          GList *prev_conn_objects)
 
 {
-  OBJECT *new_obj;
+  LeptonObject *new_obj;
   GList *cl_current = NULL;
-  OBJECT *bus_object = NULL;
-  CONN *found_conn = NULL;
+  LeptonObject *bus_object = NULL;
+  LeptonConn *found_conn = NULL;
   int done;
   int otherone;
   BUS_RIPPER rippers[2];
@@ -779,10 +785,10 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_val_if_fail (page_view != NULL, FALSE);
 
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   g_return_val_if_fail (page != NULL, FALSE);
 
-  length = geda_line_object_length (net_obj);
+  length = lepton_line_object_length (net_obj);
 
   if (!prev_conn_objects) {
     return(FALSE);
@@ -796,17 +802,18 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   cl_current = prev_conn_objects;
   while (cl_current != NULL) {
 
-    bus_object = (OBJECT *) cl_current->data;
-    if (bus_object && bus_object->type == OBJ_BUS) {
+    bus_object = (LeptonObject *) cl_current->data;
+    if (lepton_object_is_bus (bus_object))
+    {
       /* yes, using the net routine is okay */
-      int bus_orientation = geda_net_object_orientation (bus_object);
-      int net_orientation = geda_net_object_orientation (net_obj);
+      int bus_orientation = lepton_net_object_orientation (bus_object);
+      int net_orientation = lepton_net_object_orientation (net_obj);
 
-      /* find the CONN structure which is associated with this object */
+      /* find the LeptonConn structure which is associated with this object */
       GList *cl_current2 = net_obj->conn_list;
       done = FALSE;
       while (cl_current2 != NULL && !done) {
-        CONN *tmp_conn = (CONN *) cl_current2->data;
+        LeptonConn *tmp_conn = (LeptonConn *) cl_current2->data;
 
         if (tmp_conn && tmp_conn->other_object &&
             tmp_conn->other_object == bus_object) {
@@ -829,7 +836,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
         /* printf("found horiz bus %s %d!\n", bus_object->name,
            found_conn->whichone);*/
 
-        sign = geda_bus_object_get_ripper_direction (bus_object);
+        sign = lepton_bus_object_get_ripper_direction (bus_object);
         if (!sign) {
           if (bus_object->line->x[0] < bus_object->line->x[1]) {
             first = 0;
@@ -849,7 +856,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           } else {
             sign = -1;
           }
-          geda_bus_object_set_ripper_direction (bus_object, sign);
+          lepton_bus_object_set_ripper_direction (bus_object, sign);
         }
         /* printf("hor sign: %d\n", sign); */
 
@@ -934,7 +941,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
         /* printf("found vert bus %s %d!\n", bus_object->name,
            found_conn->whichone); */
 
-        sign = geda_bus_object_get_ripper_direction (bus_object);
+        sign = lepton_bus_object_get_ripper_direction (bus_object);
         if (!sign) {
           if (bus_object->line->y[0] < bus_object->line->y[1]) {
             first = 0;
@@ -954,7 +961,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           } else {
             sign = -1;
           }
-          geda_bus_object_set_ripper_direction (bus_object, sign);
+          lepton_bus_object_set_ripper_direction (bus_object, sign);
         }
         /* printf("ver sign: %d\n", sign); */
 
@@ -1051,9 +1058,11 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
 
     for (i = 0; i < ripper_count; i++) {
       if (w_current->bus_ripper_type == NET_BUS_RIPPER) {
-        new_obj = geda_net_object_new (OBJ_NET, NET_COLOR,
-                                       rippers[i].x[0], rippers[i].y[0],
-                                       rippers[i].x[1], rippers[i].y[1]);
+        new_obj = lepton_net_object_new (NET_COLOR,
+                                         rippers[i].x[0],
+                                         rippers[i].y[0],
+                                         rippers[i].x[1],
+                                         rippers[i].y[1]);
         s_page_append (page, new_obj);
       } else {
 
