@@ -401,7 +401,10 @@ void o_select_box_search(GschemToplevel *w_current)
   while (iter != NULL) {
     o_current = (LeptonObject*) iter->data;
     /* only select visible objects */
-    if (lepton_object_is_visible (o_current) || show_hidden_text) {
+    if (!lepton_object_is_text (o_current) ||
+        lepton_text_object_is_visible (o_current) ||
+        show_hidden_text)
+    {
       int cleft, ctop, cright, cbottom;
 
       if (lepton_object_calculate_visible_bounds (o_current,
@@ -611,8 +614,10 @@ o_select_visible_unlocked (GschemToplevel *w_current)
        iter = g_list_next (iter)) {
     LeptonObject *obj = (LeptonObject *) iter->data;
 
-    /* Skip invisible objects. */
-    if (!lepton_object_is_visible (obj) && !show_hidden_text)
+    /* Skip invisible text objects. */
+    if (lepton_object_is_text (obj) &&
+        !lepton_text_object_is_visible (obj) &&
+        !show_hidden_text)
       continue;
 
     /* Skip locked objects. */
