@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,7 +103,7 @@ x_compselect_callback_response (GtkDialog *dialog,
 {
   Compselect *compselect = (Compselect*)dialog;
   GschemToplevel *w_current = (GschemToplevel *)user_data;
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
 
   switch (arg1) {
       case COMPSELECT_RESPONSE_PLACE: {
@@ -134,7 +134,7 @@ x_compselect_callback_response (GtkDialog *dialog,
           if (w_current->rubber_visible)
             o_place_invalidate_rubber (w_current, FALSE);
           w_current->rubber_visible = 0;
-          geda_object_list_delete (toplevel->page_current->place_list);
+          lepton_object_list_delete (toplevel->page_current->place_list);
           toplevel->page_current->place_list = NULL;
         } else {
           /* Cancel whatever other action is currently in progress */
@@ -418,10 +418,10 @@ tree_row_activated (GtkTreeView       *tree_view,
 /*! \brief GCompareFunc to sort an text object list by the object strings
  */
 static gint
-sort_object_text (OBJECT *a, OBJECT *b)
+sort_object_text (LeptonObject *a, LeptonObject *b)
 {
-  return strcmp (geda_text_object_get_string (a),
-                 geda_text_object_get_string (b));
+  return strcmp (lepton_text_object_get_string (a),
+                 lepton_text_object_get_string (b));
 }
 
 enum {
@@ -438,14 +438,15 @@ enum {
  *  \param [in] preview_toplevel The toplevel of the preview widget
  */
 void
-update_attributes_model (Compselect *compselect, TOPLEVEL *preview_toplevel)
+update_attributes_model (Compselect *compselect,
+                         LeptonToplevel *preview_toplevel)
 {
   GtkListStore *model;
   GtkTreeIter iter;
   GtkTreeViewColumn *column;
   GList *o_iter, *o_attrlist;
   gchar *name, *value;
-  OBJECT *o_current;
+  LeptonObject *o_current;
   EdaConfig *cfg;
   gchar **filter_list;
   guint i;
@@ -483,7 +484,7 @@ update_attributes_model (Compselect *compselect, TOPLEVEL *preview_toplevel)
     /* display all attributes in alphabetical order */
     o_attrlist = g_list_sort (o_attrlist, (GCompareFunc) sort_object_text);
     for (o_iter = o_attrlist; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-      o_current = (OBJECT*) o_iter->data;
+      o_current = (LeptonObject*) o_iter->data;
       o_attrib_get_name_value (o_current, &name, &value);
       gtk_list_store_append (model, &iter);
       gtk_list_store_set (model, &iter, 0, name, 1, value, -1);
@@ -494,7 +495,7 @@ update_attributes_model (Compselect *compselect, TOPLEVEL *preview_toplevel)
     /* display only attribute that are in the filter list */
     for (i = 0; i < n; i++) {
       for (o_iter = o_attrlist; o_iter != NULL; o_iter = g_list_next (o_iter)) {
-        o_current = (OBJECT*) o_iter->data;
+        o_current = (LeptonObject*) o_iter->data;
         if (o_attrib_get_name_value (o_current, &name, &value)) {
           if (strcmp (name, filter_list[i]) == 0) {
             gtk_list_store_append (model, &iter);
@@ -683,10 +684,12 @@ compselect_callback_filter_button_clicked (GtkButton *button,
  *  that the requested behavior for the next adding of a component has
  *  been changed.
  *
+ *  \param [in] optionmenu The behavior option menu.
  *  \param [in] user_data  The component selection dialog.
  */
 static void
-compselect_callback_behavior_changed (gpointer user_data)
+compselect_callback_behavior_changed (GtkComboBox *widget,
+                                      gpointer user_data)
 {
   Compselect *compselect = (Compselect*)user_data;
 
@@ -848,7 +851,7 @@ create_lib_tree_model (Compselect *compselect)
 {
   GtkTreeStore *store;
   GList *srchead, *srclist;
-  PAGE *page = GSCHEM_DIALOG(compselect)->w_current->toplevel->page_current;
+  LeptonPage *page = GSCHEM_DIALOG(compselect)->w_current->toplevel->page_current;
   EdaConfig *cfg = eda_config_get_context_for_path (s_page_get_filename (page));
   gboolean sort = eda_config_get_boolean (cfg, "schematic.library", "sort", NULL);
 
