@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ x_event_expose (GschemPageView *view,
 gint
 x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemToplevel *w_current)
 {
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   int w_x, w_y;
   int unsnapped_wx, unsnapped_wy;
 
@@ -124,7 +124,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
      * allow resetting of the inside_action flag so we do it
      * manually here before processing the double-click event. */
     i_action_stop (w_current);
-    o_edit(w_current, geda_list_get_glist( page->selection_list ));
+    o_edit(w_current, lepton_list_get_glist( page->selection_list ));
     scm_dynwind_end ();
     return(0);
   }
@@ -188,9 +188,9 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
 
     switch(w_current->event_state) {
       case(ROTATEMODE):   o_rotate_world_update(w_current, w_x, w_y, 90,
-                            geda_list_get_glist(page->selection_list)); break;
+                            lepton_list_get_glist(page->selection_list)); break;
       case(MIRRORMODE):   o_mirror_world_update(w_current, w_x, w_y,
-                            geda_list_get_glist(page->selection_list)); break;
+                            lepton_list_get_glist(page->selection_list)); break;
 
       case(PAN):
         gschem_page_view_pan (page_view, w_x, w_y);
@@ -207,7 +207,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
             w_current->event_state == COPYMODE  ||
             w_current->event_state == MCOPYMODE ||
             w_current->event_state == PASTEMODE )) {
-        i_callback_cancel(w_current, 0, NULL);
+        i_callback_cancel (NULL, w_current);
       }
       goto end_button_pressed;
     }
@@ -286,7 +286,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
 
           case (ARCMODE)    : o_arc_invalidate_rubber     (w_current); break;
           case (BOXMODE)    : o_box_invalidate_rubber     (w_current); break;
-          case (BUSMODE)    : o_bus_invalidate_rubber     (w_current); break;
+          case (BUSMODE)    : o_bus_reset                 (w_current); break;
           case (CIRCLEMODE) : o_circle_invalidate_rubber  (w_current); break;
           case (LINEMODE)   : o_line_invalidate_rubber    (w_current); break;
           case (NETMODE)    : o_net_reset                 (w_current); break;
@@ -295,7 +295,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
           case (PINMODE)    : o_pin_invalidate_rubber     (w_current); break;
 
           default:
-            i_callback_cancel(w_current, 0, NULL);
+            i_callback_cancel (NULL, w_current);
             break;
         }
       }
@@ -316,7 +316,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
 gint
 x_event_button_released (GschemPageView *page_view, GdkEventButton *event, GschemToplevel *w_current)
 {
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   int unsnapped_wx, unsnapped_wy;
   int w_x, w_y;
 
@@ -444,7 +444,7 @@ x_event_button_released (GschemPageView *page_view, GdkEventButton *event, Gsche
 gint
 x_event_motion (GschemPageView *page_view, GdkEventMotion *event, GschemToplevel *w_current)
 {
-  PAGE *page = gschem_page_view_get_page (page_view);
+  LeptonPage *page = gschem_page_view_get_page (page_view);
   int w_x, w_y;
   int unsnapped_wx, unsnapped_wy;
   int skip_event=0;
@@ -568,7 +568,7 @@ x_event_configure (GschemPageView    *page_view,
 {
   GtkAllocation current_allocation;
   GList *iter;
-  PAGE *p_current = gschem_page_view_get_page (page_view);
+  LeptonPage *p_current = gschem_page_view_get_page (page_view);
 
   if (p_current == NULL) {
     /* don't want to call this if the current page isn't setup yet */
@@ -607,12 +607,12 @@ x_event_configure (GschemPageView    *page_view,
   }
 
 
-  /* re-pan each page of the TOPLEVEL */
-  for ( iter = geda_list_get_glist (p_current->toplevel->pages);
+  /* re-pan each page of the LeptonToplevel */
+  for ( iter = lepton_list_get_glist (p_current->toplevel->pages);
         iter != NULL;
         iter = g_list_next (iter) ) {
 
-    gschem_page_view_set_page (page_view, (PAGE *)iter->data);
+    gschem_page_view_set_page (page_view, (LeptonPage *)iter->data);
 
     if (page_view->configured) {
       gschem_page_view_pan_mouse (page_view, 0, 0);
@@ -727,7 +727,7 @@ gint x_event_scroll (GtkWidget *widget, GdkEventScroll *event,
   int pan_direction = 1;
   int zoom_direction = ZOOM_IN;
   GschemPageView *view = NULL;
-  PAGE *page = NULL;
+  LeptonPage *page = NULL;
 
   g_return_val_if_fail ((w_current != NULL), 0);
 
