@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -322,7 +322,7 @@ x_fileselect_add_preview (GtkFileChooser *filechooser)
 void
 x_fileselect_open(GschemToplevel *w_current)
 {
-  PAGE *page = NULL;
+  LeptonPage *page = NULL;
   GtkWidget *dialog;
   gchar *cwd;
 
@@ -335,9 +335,9 @@ x_fileselect_open(GschemToplevel *w_current)
 
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
-					  GTK_RESPONSE_ACCEPT,
-					  GTK_RESPONSE_CANCEL,
-					  -1);
+                                          GTK_RESPONSE_ACCEPT,
+                                          GTK_RESPONSE_CANCEL,
+                                          -1);
 
   if (w_current->file_preview)
   {
@@ -403,7 +403,9 @@ x_fileselect_open(GschemToplevel *w_current)
  *  \return                    TRUE if dialog was closed with ACCEPT response.
  */
 gboolean
-x_fileselect_save (GschemToplevel *w_current, PAGE* page, gboolean* result)
+x_fileselect_save (GschemToplevel *w_current,
+                   LeptonPage* page,
+                   gboolean* result)
 {
   g_return_val_if_fail (w_current != NULL, FALSE);
   g_return_val_if_fail (page != NULL, FALSE);
@@ -425,9 +427,9 @@ x_fileselect_save (GschemToplevel *w_current, PAGE* page, gboolean* result)
   /* Set the alternative button order (ok, cancel, help) for other systems:
   */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
-					  GTK_RESPONSE_ACCEPT,
-					  GTK_RESPONSE_CANCEL,
-					  -1);
+                                          GTK_RESPONSE_ACCEPT,
+                                          GTK_RESPONSE_CANCEL,
+                                          -1);
 
   /* set default response signal. This is usually triggered by the
    * "Return" key:
@@ -516,6 +518,7 @@ x_fileselect_save (GschemToplevel *w_current, PAGE* page, gboolean* result)
                                 filename);
 
       gtk_window_set_title (GTK_WINDOW (checkdialog), _("Overwrite file?"));
+      gtk_dialog_set_default_response (GTK_DIALOG (checkdialog), GTK_RESPONSE_NO);
 
       if (gtk_dialog_run (GTK_DIALOG (checkdialog)) != GTK_RESPONSE_YES)
       {
@@ -560,9 +563,9 @@ x_fileselect_save (GschemToplevel *w_current, PAGE* page, gboolean* result)
  *  if load the backup or the original file.
  *
  *  \todo Make this a registered callback function with user data,
- *        as we'd rather be passed a GschemToplevel than a TOPLEVEL.
+ *        as we'd rather be passed a GschemToplevel than a LeptonToplevel.
  *
- *  \param [in] user_data The TOPLEVEL object.
+ *  \param [in] user_data The GschemToplevel object.
  *  \param [in] message   Message to display to user.
  *  \return TRUE if the user wants to load the backup file, FALSE otherwise.
  */
@@ -585,11 +588,12 @@ x_fileselect_load_backup (GschemToplevel *w_current,
                                    GTK_BUTTONS_YES_NO,
                                    "%s", message->str);
 
+  gtk_window_set_title (GTK_WINDOW (dialog), "Load Backup");
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
-					  GTK_RESPONSE_YES,
-					  GTK_RESPONSE_NO,
-					  -1);
+                                          GTK_RESPONSE_YES,
+                                          GTK_RESPONSE_NO,
+                                          -1);
 
   gtk_widget_show (dialog);
   if (gtk_dialog_run ((GtkDialog*)dialog) == GTK_RESPONSE_YES) {
@@ -605,7 +609,7 @@ x_fileselect_load_backup (GschemToplevel *w_current,
 
 gboolean
 schematic_file_open (GschemToplevel *w_current,
-                     PAGE *page,
+                     LeptonPage *page,
                      const gchar *filename,
                      GError **err)
 {
