@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include "gschem.h"
 
 
-extern GedaColorMap display_colors;
+extern LeptonColorMap display_colors;
 
 #define X_IMAGE_DEFAULT_SIZE "800x600"
 #define X_IMAGE_DEFAULT_TYPE "PNG"
@@ -289,7 +289,7 @@ x_image_get_type_from_description (const char *description)
 static void
 x_image_update_dialog_filename (GtkComboBoxText *combo,
                                 GschemToplevel *w_current) {
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
+  LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   char* image_type_descr = NULL;
   gchar *image_type = NULL;
   const char *old_image_filename = NULL;
@@ -709,13 +709,13 @@ GdkPixbuf
 {
   GdkPixbuf *pixbuf;
   GschemPageView *page_view;
-  PAGE *page;
+  LeptonPage *page;
   int origin_x, origin_y, bottom, right;
   GschemPageGeometry *old_geometry, *new_geometry;
 
   GList *obj_list;
   GList *iter;
-  BOX *world_rect;
+  LeptonBox *world_rect;
   EdaRenderer *renderer;
   int render_flags;
   GArray *render_color_map = NULL;
@@ -756,7 +756,7 @@ GdkPixbuf
 
   cairo_set_matrix (cr, gschem_page_geometry_get_world_to_screen_matrix (new_geometry));
 
-  world_rect = g_new (BOX, 1);
+  world_rect = g_new (LeptonBox, 1);
 
   double lower_x = 0;
   double lower_y = height;
@@ -789,7 +789,7 @@ GdkPixbuf
 
   /* This color map is used for "normal" rendering. */
   render_color_map =
-    g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), colors_count());
+    g_array_sized_new (FALSE, FALSE, sizeof(LeptonColor), colors_count());
   render_color_map =
     g_array_append_vals (render_color_map, display_colors, colors_count());
 
@@ -802,19 +802,19 @@ GdkPixbuf
                 NULL);
 
   /* Paint background */
-  GedaColor *color = x_color_lookup (BACKGROUND_COLOR);
+  LeptonColor *color = x_color_lookup (BACKGROUND_COLOR);
 
   cairo_set_source_rgba (cr,
-                         geda_color_get_red_double (color),
-                         geda_color_get_green_double (color),
-                         geda_color_get_blue_double (color),
-                         geda_color_get_alpha_double (color));
+                         lepton_color_get_red_double (color),
+                         lepton_color_get_green_double (color),
+                         lepton_color_get_blue_double (color),
+                         lepton_color_get_alpha_double (color));
 
   cairo_paint (cr);
   cairo_destroy (cr);
 
   for (iter = obj_list; iter != NULL; iter = g_list_next (iter)) {
-    OBJECT *o_current = (OBJECT*) iter->data;
+    LeptonObject *o_current = (LeptonObject*) iter->data;
 
     if (!o_current->dont_redraw) {
       eda_renderer_draw (renderer, o_current);
@@ -849,7 +849,7 @@ GdkPixbuf
   int origin_x, origin_y, bottom, right;
   GschemToplevel new_w_current;
   GschemOptions options;
-  TOPLEVEL toplevel;
+  LeptonToplevel toplevel;
   GdkRectangle rect;
   GschemPageGeometry *old_geometry, *new_geometry;
   GdkPixmap *window = NULL;
@@ -863,7 +863,7 @@ GdkPixbuf
   /* Do a copy of the options struct and work with it */
   memcpy(&options, w_current->options, sizeof(GschemOptions));
   /* Do a copy of the toplevel struct and work with it */
-  memcpy(&toplevel, w_current->toplevel, sizeof(TOPLEVEL));
+  memcpy(&toplevel, w_current->toplevel, sizeof(LeptonToplevel));
 
   new_w_current.toplevel = &toplevel;
   new_w_current.options = &options;
