@@ -640,8 +640,8 @@ multiattrib_action_duplicate_attributes (Multiattrib *multiattrib,
     /* create a new attribute and link it */
     o_attrib_add_attrib (w_current,
                          lepton_text_object_get_string (o_attrib),
-                         lepton_object_is_visible (o_attrib),
-                         o_attrib->show_name_value,
+                         lepton_text_object_is_visible (o_attrib),
+                         lepton_text_object_get_show (o_attrib),
                          o_attrib->attached_to);
   }
 
@@ -668,12 +668,12 @@ multiattrib_action_promote_attributes (Multiattrib *multiattrib,
        iter = g_list_next (iter)) {
     LeptonObject *o_attrib = (LeptonObject *)iter->data;
 
-    if (lepton_object_is_visible (o_attrib)) {
+    if (lepton_text_object_is_visible (o_attrib)) {
       /* If the attribute we're promoting is visible, don't clone its location */
       o_attrib_add_attrib (w_current,
                            lepton_text_object_get_string (o_attrib),
                            VISIBLE,
-                           o_attrib->show_name_value,
+                           lepton_text_object_get_show (o_attrib),
                            o_attrib->parent);
     } else {
         /* make a copy of the attribute object */
@@ -747,14 +747,14 @@ multiattrib_action_copy_attribute_to_all (Multiattrib *multiattrib,
       /* Pick the first instance to copy from */
       LeptonObject *attrib_to_copy = (LeptonObject*) attr_list->data;
 
-      int visibility = lepton_object_is_visible (attrib_to_copy)
+      int visibility = lepton_text_object_is_visible (attrib_to_copy)
           ? VISIBLE : INVISIBLE;
 
       /* create a new attribute and link it */
       o_attrib_add_attrib (w_current,
                            lepton_text_object_get_string (attrib_to_copy),
                            visibility,
-                           attrib_to_copy->show_name_value,
+                           lepton_text_object_get_show (attrib_to_copy),
                            object);
     }
   }
@@ -1003,12 +1003,15 @@ multiattrib_callback_edited_name (GtkCellRendererText *cellrenderertext,
        a_iter = g_list_next (a_iter)) {
     o_attrib = (LeptonObject*) a_iter->data;
 
-    visibility = lepton_object_is_visible (o_attrib)
+    visibility = lepton_text_object_is_visible (o_attrib)
         ? VISIBLE : INVISIBLE;
 
     /* actually modifies the attribute */
-    o_text_change (w_current, o_attrib,
-                   newtext, visibility, o_attrib->show_name_value);
+    o_text_change (w_current,
+                   o_attrib,
+                   newtext,
+                   visibility,
+                   lepton_text_object_get_show (o_attrib));
   }
 
   g_object_unref (attr_list);
@@ -1090,12 +1093,15 @@ multiattrib_callback_edited_value (GtkCellRendererText *cell_renderer,
        a_iter = g_list_next (a_iter)) {
     o_attrib = (LeptonObject *)a_iter->data;
 
-    visibility = lepton_object_is_visible (o_attrib)
+    visibility = lepton_text_object_is_visible (o_attrib)
         ? VISIBLE : INVISIBLE;
 
     /* actually modifies the attribute */
-    o_text_change (w_current, o_attrib,
-                   newtext, visibility, o_attrib->show_name_value);
+    o_text_change (w_current,
+                   o_attrib,
+                   newtext,
+                   visibility,
+                   lepton_text_object_get_show (o_attrib));
   }
 
   g_object_unref (attr_list);
@@ -1152,8 +1158,8 @@ multiattrib_callback_toggled_visible (GtkCellRendererToggle *cell_renderer,
 
     /* actually modifies the attribute */
     o_invalidate (w_current, o_attrib);
-    lepton_object_set_visibility (o_attrib, new_visibility ? VISIBLE : INVISIBLE);
-    o_text_recreate (o_attrib);
+    lepton_text_object_set_visibility (o_attrib, new_visibility ? VISIBLE : INVISIBLE);
+    lepton_text_object_recreate (o_attrib);
   }
 
   g_object_unref (attr_list);
@@ -1205,7 +1211,7 @@ multiattrib_callback_toggled_show_name (GtkCellRendererToggle *cell_renderer,
        a_iter = g_list_next (a_iter)) {
     LeptonObject *o_attrib = (LeptonObject *)a_iter->data;
 
-    gboolean value_visible = snv_shows_value (o_attrib->show_name_value);
+    gboolean value_visible = snv_shows_value (lepton_text_object_get_show (o_attrib));
 
     /* If we switch off the name visibility, but the value was not previously visible, make it so now */
     if (new_name_visible)
@@ -1216,8 +1222,8 @@ multiattrib_callback_toggled_show_name (GtkCellRendererToggle *cell_renderer,
     o_invalidate (w_current, o_attrib);
 
     /* actually modifies the attribute */
-    o_attrib->show_name_value = new_snv;
-    o_text_recreate (o_attrib);
+    lepton_text_object_set_show (o_attrib, new_snv);
+    lepton_text_object_recreate (o_attrib);
   }
 
   g_object_unref (attr_list);
@@ -1269,7 +1275,7 @@ multiattrib_callback_toggled_show_value (GtkCellRendererToggle *cell_renderer,
        a_iter = g_list_next (a_iter)) {
     LeptonObject *o_attrib = (LeptonObject *)a_iter->data;
 
-    gboolean name_visible = snv_shows_name (o_attrib->show_name_value);
+    gboolean name_visible = snv_shows_name (lepton_text_object_get_show (o_attrib));
 
     /* If we switch off the name visibility, but the value was not previously visible, make it so now */
     if (new_value_visible)
@@ -1280,8 +1286,8 @@ multiattrib_callback_toggled_show_value (GtkCellRendererToggle *cell_renderer,
     o_invalidate (w_current, o_attrib);
 
     /* actually modifies the attribute */
-    o_attrib->show_name_value = new_snv;
-    o_text_recreate (o_attrib);
+    lepton_text_object_set_show (o_attrib, new_snv);
+    lepton_text_object_recreate (o_attrib);
   }
 
   g_object_unref (attr_list);
@@ -2063,7 +2069,11 @@ multiattrib_init (Multiattrib *multiattrib)
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
   GtkTreeSelection *selection;
+#ifdef ENABLE_GTK3
+  GtkStyleContext *stylectx;
+#else
   GtkStyle *style;
+#endif
 
   /* dialog initialization */
   g_object_set (G_OBJECT (multiattrib),
@@ -2340,6 +2350,27 @@ multiattrib_init (Multiattrib *multiattrib)
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), textview);
 
+#ifdef ENABLE_GTK3
+  /* Save the GTK_STATE_FLAG_NORMAL color so we can work around
+   * GtkTextView's stubborn refusal to draw with
+   * GTK_STATE_FLAG_INSENSITIVE later on */
+  stylectx = gtk_widget_get_style_context (textview);
+  gtk_style_context_get_color (stylectx,
+                               GTK_STATE_FLAG_NORMAL,
+                               &multiattrib->value_normal_text_color);
+  /* Save this one so we can pick it as a sensible colour to show the
+   * inherited attributes dimmed.
+   */
+  stylectx = gtk_widget_get_style_context (treeview);
+  gtk_style_context_get_color (stylectx,
+                               GTK_STATE_FLAG_INSENSITIVE,
+                               &multiattrib->insensitive_text_color);
+
+  gdk_rgba_parse (&multiattrib->not_identical_value_text_color, "grey");
+  gdk_rgba_parse (&multiattrib->not_present_in_all_text_color, "red");
+
+#else /* GTK2 */
+
   /* Save the GTK_STATE_NORMAL color so we can work around GtkTextView's
    * stubborn refusal to draw with GTK_STATE_INSENSITIVE later on */
   style = gtk_widget_get_style (textview);
@@ -2353,6 +2384,7 @@ multiattrib_init (Multiattrib *multiattrib)
 
   gdk_color_parse ("grey", &multiattrib->not_identical_value_text_color);
   gdk_color_parse ("red",  &multiattrib->not_present_in_all_text_color);
+#endif
 
   gtk_container_add (GTK_CONTAINER (scrolled_win), textview);
   multiattrib->textview_value = GTK_TEXT_VIEW (textview);
@@ -2531,8 +2563,8 @@ object_attributes_to_model_rows (Multiattrib *multiattrib, LeptonObject *object)
 
     m_row->inherited = o_attrib_is_inherited (a_current);
     o_attrib_get_name_value (a_current, &m_row->name, &m_row->value);
-    m_row->visibility = lepton_object_is_visible (a_current);
-    m_row->show_name_value = a_current->show_name_value;
+    m_row->visibility = lepton_text_object_is_visible (a_current);
+    m_row->show_name_value = lepton_text_object_get_show (a_current);
     m_row->nth_with_name = 0; /* Provisional value until we check below */
 
     /* The following fields are always true for a single LeptonObject */
@@ -2603,8 +2635,8 @@ lone_attributes_to_model_rows (Multiattrib *multiattrib)
     m_row = g_new0 (MODEL_ROW, 1);
     m_row->inherited = o_attrib_is_inherited (object);
     o_attrib_get_name_value (object, &m_row->name, &m_row->value);
-    m_row->visibility = lepton_object_is_visible (object);
-    m_row->show_name_value = object->show_name_value;
+    m_row->visibility = lepton_text_object_is_visible (object);
+    m_row->show_name_value = lepton_text_object_get_show (object);
     m_row->nth_with_name = 0; /* All selected attributes are treated individually */
 
     /* The following fields are always true for a single attribute */
@@ -2759,7 +2791,6 @@ static void
 multiattrib_update (Multiattrib *multiattrib)
 {
   GList *o_iter;
-  GtkStyle *style;
   gboolean show_inherited;
   gboolean list_sensitive;
   gboolean add_sensitive;
@@ -2900,9 +2931,17 @@ multiattrib_update (Multiattrib *multiattrib)
 
   /* Work around GtkTextView's stubborn indifference
    * to GTK_STATE_INSENSITIVE when rendering its text. */
-  style = gtk_widget_get_style (GTK_WIDGET (multiattrib->textview_value));
+#ifdef ENABLE_GTK3
+  gtk_widget_override_color (GTK_WIDGET (multiattrib->textview_value),
+                             GTK_STATE_FLAG_NORMAL,
+                             add_sensitive ?
+                             &multiattrib->value_normal_text_color :
+                             &multiattrib->insensitive_text_color);
+#else
+  GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (multiattrib->textview_value));
   gtk_widget_modify_text (GTK_WIDGET (multiattrib->textview_value),
                           GTK_STATE_NORMAL,
                           add_sensitive ? &multiattrib->value_normal_text_color
                                         : &style->text[GTK_STATE_INSENSITIVE]);
+#endif
 }
