@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,15 +55,16 @@
  * be LANDSCAPE, PORTRAIT or AUTOLAYOUT.  If \a AUTOLAYOUT is chosen,
  * the page orientation that best fits the page contents is chosen.
  *
- * \param toplevel A #TOPLEVEL structure.
- * \param page     The #PAGE to generate a page setup for.
+ * \param toplevel A #LeptonToplevel structure.
+ * \param page     The #LeptonPage to generate a page setup for.
  * \param paper_size_name   The name of the paper size to use.
  * \param orientation       The paper orientation to use.
  *
  * \returns A newly-created page setup.
  */
 static GtkPageSetup *
-x_print_default_page_setup (TOPLEVEL *toplevel, PAGE *page)
+x_print_default_page_setup (LeptonToplevel *toplevel,
+                            LeptonPage *page)
 {
   GtkPageSetup *setup = gtk_page_setup_new ();
   GtkPaperSize *papersize;
@@ -117,8 +118,8 @@ x_print_default_page_setup (TOPLEVEL *toplevel, PAGE *page)
  * is_raster should be set if drawing to a raster surface such as an
  * image.
  *
- * \param toplevel A #TOPLEVEL structure.
- * \param page     The #PAGE to be rendered.
+ * \param toplevel A #LeptonToplevel structure.
+ * \param page     The #LeptonPage to be rendered.
  * \param cr       The Cairo context to render to.
  * \param pc       A Pango context for text rendering, or NULL.
  * \param cr_width The width of the drawing area.
@@ -127,10 +128,14 @@ x_print_default_page_setup (TOPLEVEL *toplevel, PAGE *page)
  * \param is_raster TRUE if drawing to a raster image surface; FALSE otherwise.
  */
 static void
-x_print_draw_page (TOPLEVEL *toplevel, PAGE *page,
-                   cairo_t *cr, PangoContext *pc,
-                   double cr_width, double cr_height,
-                   gboolean is_color, gboolean is_raster)
+x_print_draw_page (LeptonToplevel *toplevel,
+                   LeptonPage *page,
+                   cairo_t *cr,
+                   PangoContext *pc,
+                   double cr_width,
+                   double cr_height,
+                   gboolean is_color,
+                   gboolean is_raster)
 {
   EdaRenderer *renderer;
   cairo_matrix_t mtx;
@@ -165,12 +170,12 @@ x_print_draw_page (TOPLEVEL *toplevel, PAGE *page,
    * transform the print color map into a black-and-white color map by
    * making the background color transparent and replacing all other
    * enabled colors with solid black. */
-  color_map = g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), colors_count());
-  GedaColor *print_colors = print_colors_array ();
+  color_map = g_array_sized_new (FALSE, FALSE, sizeof(LeptonColor), colors_count());
+  LeptonColor *print_colors = print_colors_array ();
   color_map = g_array_append_vals (color_map, print_colors, colors_count());
   if (!is_color) {
     for (size_t i = 0; i < colors_count(); i++) {
-      GedaColor *c = &g_array_index (color_map, GedaColor, i);
+      LeptonColor *c = &g_array_index (color_map, LeptonColor, i);
       if (!c->enabled) continue;
 
       /* Disable background color & fully-transparent colors */
@@ -215,12 +220,12 @@ x_print_draw_page (TOPLEVEL *toplevel, PAGE *page,
   for (iter = (GList *) s_page_objects (page);
        iter != NULL;
        iter = g_list_next (iter)) {
-    eda_renderer_draw (renderer, (OBJECT *) iter->data);
+    eda_renderer_draw (renderer, (LeptonObject *) iter->data);
   }
   for (iter = (GList *) s_page_objects (page);
        iter != NULL;
        iter = g_list_next (iter)) {
-    eda_renderer_draw_cues (renderer, (OBJECT *) iter->data);
+    eda_renderer_draw_cues (renderer, (LeptonObject *) iter->data);
   }
 
   cairo_restore (cr);
@@ -237,7 +242,7 @@ draw_page__print_operation (GtkPrintOperation *print,
                             gpointer user_data)
 {
   GschemToplevel *w_current = (GschemToplevel *) user_data;
-  PAGE *page;
+  LeptonPage *page;
   cairo_t *cr;
   PangoContext *pc;
   double width, height;
@@ -283,7 +288,7 @@ gboolean
 x_print_export_pdf_page (GschemToplevel *w_current,
                          const gchar *filename)
 {
-  PAGE *page;
+  LeptonPage *page;
   cairo_surface_t *surface;
   cairo_status_t status;
   cairo_t *cr;
@@ -438,7 +443,7 @@ x_print (GschemToplevel *w_current)
 
   /* derive output file name from the file name of the current page:
   */
-  PAGE* page = w_current->toplevel->page_current;
+  LeptonPage* page = w_current->toplevel->page_current;
   if (page != NULL)
   {
     const gchar* path = s_page_get_filename (page);
