@@ -36,8 +36,9 @@ exec @GUILE@ -s "$0" "$@"
 ;;;   defined by the greater number of pins at the top or at the
 ;;;   bottom of the symbol, and the width requested.
 
-(unless (getenv "LIBLEPTON")
-  (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@"))
+(eval-when (expand load eval)
+  (unless (getenv "LIBLEPTON")
+    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")))
 
 (use-modules (ice-9 getopt-long)
              (ice-9 match)
